@@ -256,7 +256,7 @@ POINT_T *make_points(int *numpoints, char *msg)
 
    bmp = create_bitmap_ex(8, text_length(font, msg), text_height(font));
    clear_bitmap(bmp);
-   textout_ex(bmp, font, msg, 0, 0, 1, -1);
+   textout(bmp, font, msg, 0, 0, 1);
 
    /* first, count how much memory we will need to reserve */
    n = 0;
@@ -276,7 +276,7 @@ POINT_T *make_points(int *numpoints, char *msg)
 	 if (getpixel(bmp, x, y)) {
 	    points[n].x = itofix(x - bmp->w/2) * 6;
 	    points[n].y = itofix(y - bmp->h/2) * 12;
-	    points[n].c = AL_RAND() % 4;
+	    points[n].c = rand() % 4;
 	    n++;
 	 }
       }
@@ -320,8 +320,7 @@ int main(int argc, char *argv[])
    POINT_T *points;
    MATRIX m;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_keyboard();
 
    /* first set your graphics mode as normal, except twice as wide because
@@ -387,8 +386,9 @@ int main(int argc, char *argv[])
    xangle = yangle = zangle = 0;
 
    /* put a message in the top-left corner */
-   textprintf_ex(rgbpic, font, 3, 3, makecol12(255, 255, 255), -1, "%ix%i 12-bit colour on an 8-bit card", GFXW, GFXH);
-   textprintf_ex(rgbpic, font, 3, 13, makecol12(255, 255, 255), -1, "(3840 colours at once!)");
+   text_mode(-1);
+   textprintf(rgbpic, font, 3, 3, makecol12(255, 255, 255), "%ix%i 12-bit colour on an 8-bit card", GFXW, GFXH);
+   textprintf(rgbpic, font, 3, 13, makecol12(255, 255, 255), "(3840 colours at once!)");
 
    while (!keypressed()) {
       /* first, draw some vector balls moving in a circle round the edge */
