@@ -7,7 +7,7 @@
  */
 
 
-#include <allegro.h>
+#include "allegro.h"
 
 
 
@@ -16,19 +16,15 @@ int main(void)
    BITMAP *buffer;
    int c;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_timer();
-
-   if (set_gfx_mode(GFX_AUTODETECT, 320, 200, 0, 0) != 0) {
-      if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
-	 set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
-	 allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
-	 return 1;
-      }
+   if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
+      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
+      allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
+      return 1;
    }
-
    set_palette(desktop_palette);
+   text_mode(-1);
 
    /* allocate the memory buffer */
    buffer = create_bitmap(SCREEN_W, SCREEN_H);
@@ -42,8 +38,8 @@ int main(void)
       acquire_screen();
       clear_to_color(screen, makecol(255, 255, 255));
       circlefill(screen, (retrace_count-c)*SCREEN_W/320, SCREEN_H/2, 32, makecol(0, 0, 0));
-      textprintf_ex(screen, font, 0, 0, makecol(0, 0, 0), -1, "No buffering (%s)",
-		    gfx_driver->name);
+      textprintf(screen, font, 0, 0, makecol(0, 0, 0), "No buffering (%s)",
+		 gfx_driver->name);
       release_screen();
    }
 
@@ -52,8 +48,8 @@ int main(void)
    while (retrace_count-c <= 320+32) {
       clear_to_color(buffer, makecol(255, 255, 255));
       circlefill(buffer, (retrace_count-c)*SCREEN_W/320, SCREEN_H/2, 32, makecol(0, 0, 0));
-      textprintf_ex(buffer, font, 0, 0, makecol(0, 0, 0), -1, "Double buffered (%s)",
-		    gfx_driver->name);
+      textprintf(buffer, font, 0, 0, makecol(0, 0, 0), "Double buffered (%s)",
+		 gfx_driver->name);
       blit(buffer, screen, 0, 0, 0, 0, SCREEN_W, SCREEN_H);
    }
 
@@ -62,4 +58,4 @@ int main(void)
    return 0;
 }
 
-END_OF_MAIN()
+END_OF_MAIN();
