@@ -42,7 +42,7 @@ void draw_bottom_line_of_fire(void)
 	    temp[c2] = MIN(temp[c2] + 20-ABS(hotspot[c]-c2), 192);
 
       /* move the hotspots */
-      hotspot[c] += (AL_RAND() & 7) - 3; 
+      hotspot[c] += (rand() & 7) - 3; 
       if (hotspot[c] < 0)
 	 hotspot[c] += SCREEN_W;
       else
@@ -63,8 +63,7 @@ int main(void)
    unsigned long address;
    int x, y, c;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_keyboard(); 
    if (set_gfx_mode(GFX_AUTODETECT, 320, 200, 0, 0) != 0) {
       if (set_gfx_mode(GFX_AUTODETECT, 640, 480, 0, 0) != 0) {
@@ -82,7 +81,7 @@ int main(void)
    }
 
    for (c=0; c<FIRE_HOTSPOTS; c++)
-      hotspot[c] = AL_RAND() % SCREEN_W;
+      hotspot[c] = rand() % SCREEN_W;
 
    /* fill our palette with a gradually altering sequence of colors */
    for (c=0; c<64; c++) {
@@ -108,7 +107,7 @@ int main(void)
 
    set_palette(palette);
 
-   textout_ex(screen, font, "Using get/putpixel()", 0, 0, makecol(255,255,255), makecol(0, 0, 0));
+   textout(screen, font, "Using get/putpixel()", 0, 0, makecol(255,255,255));
 
    /* using getpixel() and putpixel() is slow :-) */
    while (!keypressed()) {
@@ -131,7 +130,7 @@ int main(void)
    }
 
    clear_keybuf();
-   textout_ex(screen, font, "Using direct memory writes", 0, 0, makecol(255,255,255), makecol(0, 0, 0));
+   textout(screen, font, "Using direct memory writes", 0, 0, makecol(255,255,255));
 
    /* It is much faster if we access the screen memory directly. This
     * time we read an entire line of the screen into our own buffer,
@@ -173,7 +172,7 @@ int main(void)
    }
 
    clear_keybuf();
-   textout_ex(screen, font, "Using block data transfers", 0, 0, makecol(255,255,255), makecol(0, 0, 0));
+   textout(screen, font, "Using block data transfers", 0, 0, makecol(255,255,255));
 
    /* It is even faster if we transfer the data in 32 bit chunks, rather
     * than only one pixel at a time. This method may not work on really
