@@ -16,18 +16,13 @@ int main(void)
    BITMAP *memory_bitmap;
    int x, y;
 
-   if (allegro_init() != 0)
+   allegro_init();
+   install_keyboard(); 
+   if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
+      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
+      allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
       return 1;
-   install_keyboard();
-
-   if (set_gfx_mode(GFX_AUTODETECT, 320, 200, 0, 0) != 0) {
-      if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
-	 set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
-	 allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
-	 return 1;
-      }
    }
-
    set_palette(desktop_palette);
 
    /* make a memory bitmap sized 20x20 */
