@@ -18,7 +18,7 @@ void draw_pattern(BITMAP *bitmap, char *message, int color)
    /* create a pattern bitmap */
    pattern = create_bitmap(text_length(font, message), text_height(font));
    clear_to_color(pattern, bitmap_mask_color(pattern));
-   textout_ex(pattern, font, message, 0, 0, palette_color[255], bitmap_mask_color(screen));
+   textout(pattern, font, message, 0, 0, palette_color[255]);
 
    /* cover the bitmap with the pattern */
    drawing_mode(DRAW_MODE_MASKED_PATTERN, pattern, 0, 0);
@@ -37,21 +37,17 @@ int main(void)
 {
    BITMAP *bitmap;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_keyboard();
-
-   if (set_gfx_mode(GFX_AUTODETECT, 320, 200, 0, 0) != 0) {
-      if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
-	 set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
-	 allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
-	 return 1;
-      }
+   if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
+      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
+      allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
+      return 1;
    }
-
    set_palette(desktop_palette);
    clear_to_color(screen, makecol(255, 255, 255));
-
+   text_mode(bitmap_mask_color(screen));
+   
    /* first cover the whole screen with a pattern */
    draw_pattern(screen, "<screen>", 255);
 
