@@ -7,7 +7,7 @@
  */
 
 
-#include <allegro.h>
+#include "allegro.h"
 
 
 
@@ -17,16 +17,12 @@ int main(int argc, char *argv[])
    BITMAP *scr_buffer;
    char pcx_name[256];
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_keyboard();
-
-   if (set_gfx_mode(GFX_AUTODETECT, 320, 200, 0, 0) != 0) {
-      if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
-	 set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
-	 allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
-	 return 1;
-      }
+   if (set_gfx_mode(GFX_SAFE, 320, 200, 0, 0) != 0) {
+      set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
+      allegro_message("Unable to set any graphic mode\n%s\n", allegro_error);
+      return 1;
    }
 
    replace_filename(pcx_name, argv[0], "mysha.pcx", sizeof(pcx_name));
@@ -41,9 +37,9 @@ int main(int argc, char *argv[])
    blit(scr_buffer, screen, 0, 0, 0, 0, scr_buffer->w, scr_buffer->h);
 
    while (!keypressed()) {
-      stretch_blit(scr_buffer, screen, 0, 0, AL_RAND()%scr_buffer->w,
-		   AL_RAND()%scr_buffer->h, AL_RAND()%SCREEN_W, AL_RAND()%SCREEN_H,
-		   AL_RAND()%SCREEN_W, AL_RAND()%SCREEN_H);
+      stretch_blit(scr_buffer, screen, 0, 0, rand()%scr_buffer->w,
+		   rand()%scr_buffer->h, rand()%SCREEN_W, rand()%SCREEN_H,
+		   rand()%SCREEN_W, rand()%SCREEN_H);
       vsync();
    }
 
@@ -51,4 +47,4 @@ int main(int argc, char *argv[])
    return 0;
 }
 
-END_OF_MAIN()
+END_OF_MAIN();
