@@ -1,22 +1,14 @@
 /*
  *    Example program for the Allegro library, by Shawn Hargreaves.
  *
- *    This program demonstrates how to support double buffering,
- *    page flipping, and triple buffering as options within a single
- *    program, and how to make things run at a constant rate no
- *    matter what the speed of your computer. You have to use this
- *    example from the commandline to specify as first parameter a
- *    number which represents the type of video update you want: 1
- *    for double buffering with memory bitmaps, 2 for page flipping,
- *    3 for triple buffering and 4 for double buffering with system
- *    bitmaps. After this, a dialog allows you to select a screen
- *    resolution and finally you will see a kaleidoscopic animation,
- *    along with a frames per second counter on the top left of
- *    the screen.
+ *    This program demonstrates how to support double buffering, page
+ *    flipping, and triple buffering as options within a single program,
+ *    and how to make things run at a constant rate no matter what the
+ *    speed of your computer.
  */
 
 
-#include <allegro.h>
+#include "allegro.h"
 
 
 
@@ -44,7 +36,7 @@ void timer_proc(void)
    update_count++;
 }
 
-END_OF_FUNCTION(timer_proc)
+END_OF_FUNCTION(timer_proc);
 
 
 
@@ -55,7 +47,7 @@ void fps_proc(void)
    frame_count = 0;
 }
 
-END_OF_FUNCTION(fps_proc)
+END_OF_FUNCTION(fps_proc);
 
 
 
@@ -68,17 +60,12 @@ fixed r4 = 0;
 
 
 /* helper to draw four mirrored versions of a triangle */
-void kalid(BITMAP *bmp, int x1, int y1, int x2, int y2, int x3, int y3,
-	   int r, int g, int b)
+void kalid(BITMAP *bmp, int x1, int y1, int x2, int y2, int x3, int y3, int r, int g, int b)
 {
-   triangle(bmp, SCREEN_W/2+x1, SCREEN_H/2+y1, SCREEN_W/2+x2, SCREEN_H/2+y2,
-	    SCREEN_W/2+x3, SCREEN_H/2+y3, makecol(r, g, b));
-   triangle(bmp, SCREEN_W/2-x1, SCREEN_H/2+y1, SCREEN_W/2-x2, SCREEN_H/2+y2,
-	    SCREEN_W/2-x3, SCREEN_H/2+y3, makecol(r, g, b));
-   triangle(bmp, SCREEN_W/2-x1, SCREEN_H/2-y1, SCREEN_W/2-x2, SCREEN_H/2-y2,
-	    SCREEN_W/2-x3, SCREEN_H/2-y3, makecol(r, g, b));
-   triangle(bmp, SCREEN_W/2+x1, SCREEN_H/2-y1, SCREEN_W/2+x2, SCREEN_H/2-y2,
-	    SCREEN_W/2+x3, SCREEN_H/2-y3, makecol(r, g, b));
+   triangle(bmp, SCREEN_W/2+x1, SCREEN_H/2+y1, SCREEN_W/2+x2, SCREEN_H/2+y2, SCREEN_W/2+x3, SCREEN_H/2+y3, makecol(r, g, b));
+   triangle(bmp, SCREEN_W/2-x1, SCREEN_H/2+y1, SCREEN_W/2-x2, SCREEN_H/2+y2, SCREEN_W/2-x3, SCREEN_H/2+y3, makecol(r, g, b));
+   triangle(bmp, SCREEN_W/2-x1, SCREEN_H/2-y1, SCREEN_W/2-x2, SCREEN_H/2-y2, SCREEN_W/2-x3, SCREEN_H/2-y3, makecol(r, g, b));
+   triangle(bmp, SCREEN_W/2+x1, SCREEN_H/2-y1, SCREEN_W/2+x2, SCREEN_H/2-y2, SCREEN_W/2+x3, SCREEN_H/2-y3, makecol(r, g, b));
 }
 
 
@@ -118,24 +105,22 @@ void draw_screen(BITMAP *bmp)
 
    xor_mode(FALSE);
 
+   text_mode(-1);
+
    if (num_pages == 1) {
       if (use_system_bitmaps)
-	 textout_ex(bmp, font, "Double buffered (system bitmap)", 0, 0,
-		    makecol(255, 255, 255), -1);
+	 textout(bmp, font, "Double buffered (system bitmap)", 0, 0, makecol(255, 255, 255));
       else
-	 textout_ex(bmp, font, "Double buffered (memory bitmap)", 0, 0,
-		    makecol(255, 255, 255), -1);
+	 textout(bmp, font, "Double buffered (memory bitmap)", 0, 0, makecol(255, 255, 255));
    }
    else if (num_pages == 2)
-      textout_ex(bmp, font, "Page flipping (two pages of vram)", 0, 0,
-		 makecol(255, 255, 255), -1);
+      textout(bmp, font, "Page flipping (two pages of vram)", 0, 0, makecol(255, 255, 255));
    else
-      textout_ex(bmp, font, "Triple buffered (three pages of vram)", 0, 0,
-		 makecol(255, 255, 255), -1);
+      textout(bmp, font, "Triple buffered (three pages of vram)", 0, 0, makecol(255, 255, 255));
 
-   textout_ex(bmp, font, gfx_driver->name, 0, 16, makecol(255, 255, 255), -1);
+   textout(bmp, font, gfx_driver->name, 0, 16, makecol(255, 255, 255));
 
-   textprintf_ex(bmp, font, 0, 32, makecol(255, 255, 255), -1, "FPS: %d", fps);
+   textprintf(bmp, font, 0, 32, makecol(255, 255, 255), "FPS: %d", fps);
 
    release_bitmap(bmp);
 }
@@ -160,8 +145,7 @@ int main(int argc, char *argv[])
    int card = GFX_AUTODETECT;
    int w, h, bpp, page, i;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
 
    /* check command line arguments */
    if (argc == 2)
@@ -186,11 +170,12 @@ int main(int argc, char *argv[])
 		      "    + avoids the need for a memory to screen blit of the completed image\n"
 		      "    + can use hardware acceleration when it is available\n"
 		      "    - drawing directly to vram can be slower than using a memory bitmap\n"
-		      "    - requires a card with enough video memory for two screen pages\n\n"
+		      "    - requires a card with enough video memory for two screen pages\n"
+		      "    - some VESA drivers have nasty bugs in the scrolling functions\n\n"
 		      "3 = triple buffered (three pages of video memory)\n\n"
 		      "    + like page flipping, but faster and smoother\n"
 		      "    - requires a card with enough video memory for three screen pages\n"
-		      "    - only possible with some graphics drivers\n\n"
+		      "    - only possible in mode-X (not win95), or with VBE 3.0 or VBE/AF\n\n"
 		      "4 = double buffered (system bitmap)\n\n"
 		      "    + as easy as normal double buffering\n"
 		      "    + system bitmaps can be hardware accelerated on some platforms\n"
@@ -217,11 +202,7 @@ int main(int argc, char *argv[])
 
    set_color_depth(bpp);
 
-#ifdef ALLEGRO_VRAM_SINGLE_SURFACE
-   if (set_gfx_mode(card, w, h, w, num_pages*h) != 0) {
-#else
    if (set_gfx_mode(card, w, h, 0, 0) != 0) {
-#endif
       set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
       allegro_message("Error setting graphics mode\n%s\n", allegro_error);
       return 1;
@@ -256,11 +237,9 @@ int main(int argc, char *argv[])
 	    set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
 
 	    #ifdef ALLEGRO_DOS
-	    allegro_message("This driver does not support triple buffering\n"
-			    "\nTry using mode-X in clean DOS mode (not under "
-			    "Windows)\n");
+	       allegro_message("This driver does not support triple buffering\n\nTry using mode-X in clean DOS mode (not under Windows)\n");
 	    #else
-	    allegro_message("This driver does not support triple buffering\n");
+	       allegro_message("This driver does not support triple buffering\n");
 	    #endif
 
 	    return 1;
@@ -275,8 +254,7 @@ int main(int argc, char *argv[])
    for (i=0; i<num_pages; i++) {
       if (!bmp[i]) {
 	 set_gfx_mode(GFX_TEXT, 0, 0, 0, 0);
-	 allegro_message("Unable to create %d video memory pages\n",
-			 num_pages);
+	 allegro_message("Unable to create %d video memory pages\n", num_pages);
 	 return 1;
       }
    }
@@ -340,4 +318,4 @@ int main(int argc, char *argv[])
    return 0;
 }
 
-END_OF_MAIN()
+END_OF_MAIN();
