@@ -27,40 +27,25 @@
    #include <stddef.h>
    #include <stdlib.h>
    #include <time.h>
-   #include <string.h>
 #endif
 
-#if (defined DEBUGMODE) && (defined FORTIFY)
-   #include <fortify/fortify.h>
-#endif
-
-#if (defined DEBUGMODE) && (defined DMALLOC)
-   #include <dmalloc.h>
-#endif
-
-#include "internal/alconfig.h"
-
 #ifdef __cplusplus
    extern "C" {
 #endif
 
+#include "internal/alconfig.h"
+
 #define ALLEGRO_VERSION          4
-#define ALLEGRO_SUB_VERSION      4
-#define ALLEGRO_WIP_VERSION      0
-#define ALLEGRO_VERSION_STR      "4.4.0"
-#define ALLEGRO_DATE_STR         "2009"
-#define ALLEGRO_DATE             20091230    /* yyyymmdd */
+#define ALLEGRO_SUB_VERSION      0
+#define ALLEGRO_WIP_VERSION      3
+#define ALLEGRO_VERSION_STR      "4.0.3"
+#define ALLEGRO_DATE_STR         "2003"
+#define ALLEGRO_DATE             20030419    /* yyyymmdd */
 
 /*******************************************/
 /************ Some global stuff ************/
 /*******************************************/
 
-
-/* Asm build disabled as of 4.3.10+. */
-#ifndef ALLEGRO_NO_ASM
-   #define ALLEGRO_NO_ASM
-#endif
-
 #ifndef TRUE 
    #define TRUE         -1
    #define FALSE        0
@@ -72,14 +57,7 @@
      
 #define MIN(x,y)     (((x) < (y)) ? (x) : (y))
 #define MAX(x,y)     (((x) > (y)) ? (x) : (y))
-
-/* Returns the median of x, y, z */
-#define MID(x,y,z)   ((x) > (y) ? ((y) > (z) ? (y) : ((x) > (z) ?    \
-                       (z) : (x))) : ((y) > (z) ? ((z) > (x) ? (z) : \
-                       (x)): (y)))
-
-/* Optimized version of MID for when x <= z. */
-#define CLAMP(x,y,z) MAX((x), MIN((y), (z)))
+#define MID(x,y,z)   MAX((x), MIN((y), (z)))
      
 #undef ABS
 #define ABS(x)       (((x) >= 0) ? (x) : (-(x)))
