@@ -230,7 +230,7 @@ typedef struct BITMAP            /* a bitmap structure */
    int x_ofs;                    /* horizontal offset (for sub-bitmaps) */
    int y_ofs;                    /* vertical offset (for sub-bitmaps) */
    int seg;                      /* bitmap segment */
-   unsigned char *line[ZERO_SIZE];
+   ZERO_SIZE_ARRAY(unsigned char *, line);
 } BITMAP;
 
 
