@@ -310,11 +310,27 @@ AL_VAR(int, _color_conv);
 AL_FUNC(BITMAP *, _fixup_loaded_bitmap, (BITMAP *bmp, PALETTE pal, int bpp));
 
 
+/* default truecolor pixel format */
+#define DEFAULT_RGB_R_SHIFT_15  0
+#define DEFAULT_RGB_G_SHIFT_15  5
+#define DEFAULT_RGB_B_SHIFT_15  10
+#define DEFAULT_RGB_R_SHIFT_16  0
+#define DEFAULT_RGB_G_SHIFT_16  5
+#define DEFAULT_RGB_B_SHIFT_16  11
+#define DEFAULT_RGB_R_SHIFT_24  0
+#define DEFAULT_RGB_G_SHIFT_24  8
+#define DEFAULT_RGB_B_SHIFT_24  16
+#define DEFAULT_RGB_R_SHIFT_32  0
+#define DEFAULT_RGB_G_SHIFT_32  8
+#define DEFAULT_RGB_B_SHIFT_32  16
+#define DEFAULT_RGB_A_SHIFT_32  24
+
+
 /* console switching support */
 AL_FUNC(void, _register_switch_bitmap, (BITMAP *bmp, BITMAP *parent));
 AL_FUNC(void, _unregister_switch_bitmap, (BITMAP *bmp));
 AL_FUNC(void, _save_switch_state, (int switch_mode));
-AL_FUNC(void, _restore_switch_state, ());
+AL_FUNC(void, _restore_switch_state, (void));
 
 AL_VAR(int, _dispsw_status);
 
@@ -1087,7 +1103,7 @@ typedef struct DATAFILE_TYPE
 {
    int type;
    AL_METHOD(void *, load, (PACKFILE *f, long size));
-   AL_METHOD(void, destroy, ());
+   AL_METHOD(void, destroy, (void *));
 } DATAFILE_TYPE;
 
 
@@ -1124,7 +1140,7 @@ AL_VAR(struct _AL_LINKER_MOUSE *, _al_linker_mouse);
 
 
 /* dynamic driver lists */
-AL_FUNC(_DRIVER_INFO *, _create_driver_list, ());
+AL_FUNC(_DRIVER_INFO *, _create_driver_list, (void));
 AL_FUNC(void, _destroy_driver_list, (_DRIVER_INFO *drvlist));
 AL_FUNC(void, _driver_list_append_driver, (_DRIVER_INFO **drvlist, int id, void *driver, int autodetect));
 AL_FUNC(void, _driver_list_prepend_driver, (_DRIVER_INFO **drvlist, int id, void *driver, int autodetect));
