@@ -26,8 +26,6 @@
 
 /* a static auto config */
 #define HAVE_DIRENT_H
-#define HAVE_INTTYPES_H		/* TODO: check this */
-#define HAVE_STDINT_H		/* TODO: check this */
 #define HAVE_SYS_DIR_H
 #define HAVE_SYS_TIME_H
 #define TIME_WITH_SYS_TIME
@@ -37,7 +35,6 @@
 #define ALLEGRO_LITTLE_ENDIAN
 #define ALLEGRO_CONSOLE_OK
 #define ALLEGRO_USE_CONSTRUCTOR
-#define ALLEGRO_MULTITHREADED
 
 /* arrange for other headers to be included later on */
 #define ALLEGRO_EXTRA_HEADER     "allegro/platform/albeos.h"
