@@ -37,10 +37,8 @@
 #define ALLEGRO_WINDOWS
 #define ALLEGRO_I386
 #define ALLEGRO_LITTLE_ENDIAN
-#define ALLEGRO_GUESS_INTTYPES_OK
-#define ALLEGRO_MULTITHREADED
 
-#ifdef ALLEGRO_USE_CONSOLE
+#ifdef USE_CONSOLE
    #define ALLEGRO_CONSOLE_OK
    #define ALLEGRO_NO_MAGIC_MAIN
 #endif
