@@ -25,8 +25,6 @@
 
 
 /* a static auto config */
-#define HAVE_INTTYPES_H		/* TODO: check this */
-#define HAVE_STDINT_H		/* TODO: check this */
 #define HAVE_STRICMP
 #define HAVE_STRLWR
 #define HAVE_STRUPR
@@ -48,7 +46,6 @@
 #define ALLEGRO_CONSOLE_OK
 #define ALLEGRO_USE_SCHED_YIELD
 #define ALLEGRO_USE_CONSTRUCTOR
-#undef ALLEGRO_MULTITHREADED  /* FIXME */
 
 /* arrange for other headers to be included later on */
 #define ALLEGRO_EXTRA_HEADER     "allegro/platform/alqnx.h"
