@@ -1,13 +1,8 @@
 #! /bin/sh
 
-# Usage: deplexe.sh libraries sources ...
-
 # Generate dependencies and rules for building simple programs
 # from one source file and library.
 
-libs=$1
-shift
-
 missing=
 symbols=
 for file in .. $*; do
@@ -60,19 +55,13 @@ for file in .. $*; do
 
     # Program.
     echo "$dir/$name\$(EXE): \$(OBJDIR)/$name\$(OBJ) \$(LIBALLEG)"
-    if test "$libs" = "--"; then
-      echo "	\$(LINK) -o $dir/$name\$(EXE) \$(OBJDIR)/$name\$(OBJ) \$(LINK_LIBALLEG)"
-    else
-      echo "	\$(LINK) -o $dir/$name\$(EXE) \$(OBJDIR)/$name\$(OBJ) \$(LINK_LIBALLEG) $libs"
-    fi
+    echo "	\$(LINK) -o $dir/$name\$(EXE) \$(OBJDIR)/$name\$(OBJ) \$(LINK_LIBALLEG)"
     echo ""
 
     # Object file.
     echo "\$(OBJDIR)/$name\$(OBJ): \$(srcdir)/$file$includes"
     if test "$ext" = "c"; then
       echo "	\$(COMPILE_PROGRAM) -c \$(srcdir)/$file -o \$(OBJDIR)/$name\$(OBJ)"
-    elif test "$ext" = "cpp"; then
-      echo "	\$(COMPILE_CXX_PROGRAM) -c \$(srcdir)/$file -o \$(OBJDIR)/$name\$(OBJ)"
     else
       echo "	\$(COMPILE_S_PROGRAM) -c \$(srcdir)/$file -o \$(OBJDIR)/$name\$(OBJ)"
     fi
