@@ -38,7 +38,7 @@ fi
 # Error reporter
 
 error() {
-	echo "Error occured, aborting" ; rm -rf $dir ; exit 1
+	echo "Error occured, aborting" ; exit 1
 }
 
 
@@ -50,7 +50,7 @@ mkdir $dir || error
 echo "Unzipping $1 to $dir"
 	unzip -qq $1 -d $dir || error
 echo "Running 'fix.sh unix'"
-	(cd $dir/allegro && rm -f makefile && . fix.sh unix >/dev/null) || error
+	(cd $dir/allegro && . fix.sh unix >/dev/null) || error
 echo "Checking version number"
 	basename=$(sed -n -e 's/shared_version = /allegro-/p' $dir/allegro/makefile.ver)
 	basename2=$(sed -n -e 's/shared_version = /allegro-enduser-/p' $dir/allegro/makefile.ver)
