@@ -25,12 +25,6 @@
 
 
 
-#define PREFIX_I                "al-main INFO: "
-#define PREFIX_W                "al-main WARNING: "
-#define PREFIX_E                "al-main ERROR: "
-
-
-
 /* in case you want to report version numbers */
 char allegro_id[] = "Allegro " ALLEGRO_VERSION_STR ", " ALLEGRO_PLATFORM_STR;
 
@@ -51,14 +45,6 @@ int *allegro_errno = NULL;
 int _allegro_count = 0;
 
 
-/* flag to know whether we are being called by the exit mechanism */
-int _allegro_in_exit = FALSE;
-
-
-/* flag to decide whether to disable the screensaver */
-int _screensaver_policy = FULLSCREEN_DISABLED;
-
-
 /* the graphics driver currently in use */
 GFX_DRIVER *gfx_driver = NULL;
 
@@ -66,6 +52,8 @@ GFX_DRIVER *gfx_driver = NULL;
 /* abilities of the current graphics driver */
 int gfx_capabilities = 0;
 
+/* pointer to list of valid video modes */
+GFX_MODE_LIST *gfx_mode_list = NULL;
 
 /* a bitmap structure for accessing the physical screen */
 BITMAP *screen = NULL;
@@ -193,7 +181,7 @@ int os_multitasking = FALSE;
 
 
 /* processor information */
-char cpu_vendor[_AL_CPU_VENDOR_SIZE] = EMPTY_STRING;
+char cpu_vendor[32] = EMPTY_STRING;
 int cpu_family = 0;
 int cpu_model = 0;
 int cpu_capabilities = 0;
@@ -207,7 +195,7 @@ static FILE *assert_file = NULL;
 static FILE *trace_file = NULL;
 
 static int (*assert_handler)(AL_CONST char *msg) = NULL;
-int (*_al_trace_handler)(AL_CONST char *msg) = NULL;
+static int (*trace_handler)(AL_CONST char *msg) = NULL;
 
 
 /* Module linking system stuff: if an object file is linked in, then its
@@ -223,7 +211,6 @@ struct _AL_LINKER_MOUSE *_al_linker_mouse = NULL;
 /* dynamic registration system for cleanup code */
 struct al_exit_func {
    void (*funcptr)(void);
-   AL_CONST char *desc;
    struct al_exit_func *next;
 };
 
@@ -231,28 +218,10 @@ static struct al_exit_func *exit_func_list = NULL;
 
 
 
-/* _get_allegro_version:
- *  Retrieves the library version.  This is an obsolete definition which should
- *  only be used by Allegro 4.2.0 binaries, which have a call to this function
- *  embedded.
- */
-int _get_allegro_version(void)
-{
-#if ALLEGRO_VERSION == 4 && ALLEGRO_SUB_VERSION == 2
-   return MAKE_VERSION(ALLEGRO_VERSION, ALLEGRO_SUB_VERSION, 0);
-#else
-#error _get_allegro_version should not exist in other versions of Allegro
-#endif
-}
-
-
-
 /* _add_exit_func:
  *  Adds a function to the list that need to be called by allegro_exit().
- *  `desc' should point to a statically allocated string to help with
- *  debugging.
  */
-void _add_exit_func(void (*func)(void), AL_CONST char *desc)
+void _add_exit_func(void (*func)(void))
 {
    struct al_exit_func *n;
 
@@ -260,13 +229,12 @@ void _add_exit_func(void (*func)(void), AL_CONST char *desc)
       if (n->funcptr == func)
 	 return;
 
-   n = _AL_MALLOC(sizeof(struct al_exit_func));
+   n = malloc(sizeof(struct al_exit_func));
    if (!n)
       return;
 
    n->next = exit_func_list;
    n->funcptr = func;
-   n->desc = desc;
    exit_func_list = n;
 }
 
@@ -285,7 +253,7 @@ void _remove_exit_func(void (*func)(void))
 	    prev->next = iter->next;
 	 else
 	    exit_func_list = iter->next;
-	 _AL_FREE(iter);
+	 free(iter);
 	 return;
       }
       prev = iter;
@@ -295,25 +263,10 @@ void _remove_exit_func(void (*func)(void))
 
 
 
-/* allegro_exit_stub:
- *  Stub function registered by the library via atexit.
- */
-static void allegro_exit_stub(void)
-{
-   _allegro_in_exit = TRUE;
-
-   allegro_exit();
-}
-
-
-
-/* _install_allegro:
+/* install_allegro:
  *  Initialises the Allegro library, activating the system driver.
- *
- *  This is non-static because 4.2.0 binaries reference it.  Newer binaries
- *  should only call this through _install_allegro_version_check().
  */
-int _install_allegro(int system_id, int *errno_ptr, int (*atexit_ptr)(void (*func)(void)))
+int install_allegro(int system_id, int *errno_ptr, int (*atexit_ptr)(void (*func)(void)))
 {
    RGB black_rgb = {0, 0, 0, 0};
    char tmp1[64], tmp2[64];
@@ -329,8 +282,6 @@ int _install_allegro(int system_id, int *errno_ptr, int (*atexit_ptr)(void (*fun
       _midi_constructor();
       _mouse_constructor();
       _register_bitmap_file_type_init();
-      _register_sample_file_type_init();
-      _register_font_file_type_init();
    #endif
 
    if (errno_ptr)
@@ -364,9 +315,6 @@ int _install_allegro(int system_id, int *errno_ptr, int (*atexit_ptr)(void (*fun
    /* nasty stuff to set up the config system before the system driver */
    system_driver = _system_driver_list[0].driver;
 
-   /* needed in case set_config_file was called before allegro_init */
-   _reload_config();
-
    reload_config_texts(NULL);
 
    if (system_id == SYSTEM_AUTODETECT)
@@ -392,73 +340,28 @@ int _install_allegro(int system_id, int *errno_ptr, int (*atexit_ptr)(void (*fun
       }
    }
 
-   if (!system_driver)
-      return -1;
+   if (!system_driver) {
+      AL_CONST char *msg = get_config_text("Fatal error: unable to activate the Allegro system");
 
-   /* disable close button */
-   set_close_button_callback(NULL);
+      if (ugetc(allegro_error))
+	 allegro_message(uconvert_ascii("%s\n%s\n", tmp1), msg, allegro_error);
+      else
+	 allegro_message(uconvert_ascii("%s\n", tmp1), msg);
+
+      exit(EXIT_FAILURE);
+   }
 
    /* detect CPU type */
    check_cpu();
 
-   /* set up screensaver policy */
-   _screensaver_policy = get_config_int(uconvert_ascii("system", tmp1),
-                                        uconvert_ascii("disable_screensaver", tmp2),
-                                        FULLSCREEN_DISABLED);
-
    /* install shutdown handler */
    if (_allegro_count == 0) {
       if (atexit_ptr)
-	 atexit_ptr(allegro_exit_stub);
+	 atexit_ptr(allegro_exit);
    }
 
    _allegro_count++;
 
-   TRACE(PREFIX_I "Allegro initialised (instance %d)\n", _allegro_count);
-   return 0;
-}
-
-
-
-/* _install_allegro_version_check:
- *  Initialises the Allegro library, but return with an error if an
- *  incompatible version is found.
- */
-int _install_allegro_version_check(int system_id, int *errno_ptr,
-   int (*atexit_ptr)(void (*func)(void)), int version)
-{
-   int r = _install_allegro(system_id, errno_ptr, atexit_ptr);
-
-   int build_wip = version & 255;
-   int build_ver = version & ~255;
-
-   int version_ok;
-
-   if (r != 0) {
-      /* failed */
-      return r;
-   }
-
-#if ALLEGRO_SUB_VERSION & 1
-   /* This is a WIP runtime, so enforce strict compatibility. */
-   version_ok = version == MAKE_VERSION(ALLEGRO_VERSION, ALLEGRO_SUB_VERSION, ALLEGRO_WIP_VERSION);
-#else
-   /* This is a stable runtime, so the runtime should be at least as new
-    * as the build headers (otherwise we may get a crash, since some
-    * functions may have been used which aren't available in this runtime).
-    */
-   version_ok = (MAKE_VERSION(ALLEGRO_VERSION, ALLEGRO_SUB_VERSION, 0) == build_ver) &&
-      (ALLEGRO_WIP_VERSION >= build_wip);
-#endif
-
-   if (!version_ok) {
-      uszprintf(allegro_error, ALLEGRO_ERROR_SIZE, get_config_text(
-         "The detected dynamic Allegro library (%d.%d.%d) is "
-         "not compatible with this program (%d.%d.%d)."),
-         ALLEGRO_VERSION, ALLEGRO_SUB_VERSION, ALLEGRO_WIP_VERSION,
-         build_ver >> 16, (build_ver >> 8) & 255, build_wip);
-      return -1;
-   }
    return 0;
 }
 
@@ -467,13 +370,10 @@ int _install_allegro_version_check(int system_id, int *errno_ptr,
 /* allegro_exit:
  *  Closes down the Allegro system.
  */
-void allegro_exit(void)
+void allegro_exit()
 {
-   while (exit_func_list) {
-      void (*func)(void) = exit_func_list->funcptr;
-      _remove_exit_func(func);
-      (*func)();
-   }
+   while (exit_func_list)
+      (*(exit_func_list->funcptr))();
 
    if (system_driver) {
       system_driver->exit();
@@ -481,7 +381,7 @@ void allegro_exit(void)
    }
 
    if (_scratch_mem) {
-      _AL_FREE(_scratch_mem);
+      free(_scratch_mem);
       _scratch_mem = NULL;
       _scratch_mem_size = 0;
    }
@@ -494,10 +394,10 @@ void allegro_exit(void)
  */
 void allegro_message(AL_CONST char *msg, ...)
 {
-   char *buf = _AL_MALLOC_ATOMIC(ALLEGRO_MESSAGE_SIZE);
-   char *tmp = _AL_MALLOC_ATOMIC(ALLEGRO_MESSAGE_SIZE);
+   char *buf = malloc(ALLEGRO_MESSAGE_SIZE);
+   char *tmp = malloc(ALLEGRO_MESSAGE_SIZE);
+
    va_list ap;
-   ASSERT(msg);
    va_start(ap, msg);
    uvszprintf(buf, ALLEGRO_MESSAGE_SIZE, msg, ap);
    va_end(ap);
@@ -507,8 +407,8 @@ void allegro_message(AL_CONST char *msg, ...)
    else
       fputs(uconvert(buf, U_CURRENT, tmp, U_ASCII_CP, ALLEGRO_MESSAGE_SIZE), stdout);
 
-   _AL_FREE(buf);
-   _AL_FREE(tmp);
+   free(buf);
+   free(tmp);
 }
 
 
@@ -519,7 +419,6 @@ void allegro_message(AL_CONST char *msg, ...)
 void get_executable_name(char *output, int size)
 {
    ASSERT(system_driver);
-   ASSERT(output);
 
    if (system_driver->get_executable_name) {
       system_driver->get_executable_name(output, size);
@@ -533,23 +432,6 @@ void get_executable_name(char *output, int size)
 
 
 
-/* set_close_button_callback:
- *  Installs a callback function to be called when the close button
- *  of the window or any equivalent device is activated. Returns 0 on
- *  success and -1 on failure (e.g. feature not supported).
- */
-int set_close_button_callback(void (*proc)(void))
-{
-   ASSERT(system_driver);
-
-   if (system_driver->set_close_button_callback)
-      return system_driver->set_close_button_callback(proc);
-
-   return -1;
-}
-
-
-
 /* debug_exit:
  *  Closes the debugging output files.
  */
@@ -603,7 +485,7 @@ void al_assert(AL_CONST char *file, int line)
 	 assert_file = NULL;
 
       if (debug_trace_virgin)
-	 _add_exit_func(debug_exit, "debug_exit");
+	 _add_exit_func(debug_exit);
 
       debug_assert_virgin = FALSE;
    }
@@ -645,8 +527,8 @@ void al_trace(AL_CONST char *msg, ...)
    vsprintf(buf, msg, ap);
    va_end(ap);
 
-   if (_al_trace_handler) {
-      if (_al_trace_handler(buf))
+   if (trace_handler) {
+      if (trace_handler(buf))
 	 return;
    }
 
@@ -659,7 +541,7 @@ void al_trace(AL_CONST char *msg, ...)
 	 trace_file = fopen("allegro.log", "w");
 
       if (debug_assert_virgin)
-	 _add_exit_func(debug_exit, "debug_exit");
+	 _add_exit_func(debug_exit);
 
       debug_trace_virgin = FALSE;
    }
@@ -689,7 +571,7 @@ void register_assert_handler(int (*handler)(AL_CONST char *msg))
  */
 void register_trace_handler(int (*handler)(AL_CONST char *msg))
 {
-   _al_trace_handler = handler;
+   trace_handler = handler;
 }
 
 
@@ -698,7 +580,7 @@ void register_trace_handler(int (*handler)(AL_CONST char *msg))
  *  Wrapper for when a program needs to manipulate memory that has been
  *  allocated by the Allegro DLL.
  */
-void *_al_malloc(size_t size)
+void *_al_malloc(int size)
 {
    return malloc(size);
 }
@@ -720,7 +602,7 @@ void _al_free(void *mem)
  *  Wrapper for when a program needs to manipulate memory that has been
  *  allocated by the Allegro DLL.
  */
-void *_al_realloc(void *mem, size_t size)
+void *_al_realloc(void *mem, int size)
 {
    return realloc(mem, size);
 }
@@ -743,9 +625,8 @@ SYSTEM_DRIVER system_none =
    "Agnostic",
    sys_none_init,
    sys_none_exit,
-   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
-   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
-   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
    sys_no_driver, sys_no_driver, sys_no_driver, sys_no_driver,
    sys_no_driver, sys_no_driver, sys_no_driver
 };
