@@ -14,12 +14,12 @@
  *
  *      Hook functions added by Martijn Versteegh.
  *
- *      Annie Testes lifted several hardcoded length limitations.
- *
  *      See readme.txt for copyright information.
  */
 
 
+#include <string.h>
+
 #include "allegro.h"
 #include "allegro/internal/aintern.h"
 
@@ -62,10 +62,6 @@ static CONFIG_HOOK *config_hook = NULL;
 
 static int config_installed = FALSE;
 
-static char **config_argv = NULL;
-static char *argv_buf = NULL;
-static int argv_buf_size = 0;
-
 
 
 /* flush_config:
@@ -207,14 +203,6 @@ static void config_cleanup(void)
       config_hook = NULL;
    }
 
-   free(config_argv);
-   config_argv = NULL;
-   
-   free(argv_buf);
-   argv_buf = NULL;
-   
-   argv_buf_size = 0;
-
    _remove_exit_func(config_cleanup);
    config_installed = FALSE;
 }
@@ -231,7 +219,7 @@ static void init_config(int loaddata)
    char filename[1024], tmp[128], *cfg_name;
 
    if (!config_installed) {
-      _add_exit_func(config_cleanup, "config_cleanup");
+      _add_exit_func(config_cleanup);
       config_installed = TRUE;
    }
 
@@ -259,18 +247,12 @@ static void init_config(int loaddata)
 
 
 
-/* get_line:
- *  Helper for splitting files up into individual lines. Returns the length
- *  in bytes of the sequence of characters delimited by the first EOL marker
- *  in the array DATA of length LENGTH, and allocates NAME and VAL to record
- *  the name and the value of the config entry respectively; otherwise set
- *  NAME to NULL and returns a copy of the line through VAL if the line was
- *  blank or a comment. Returns -1 and set allegro_errno on failure.
+/* get_line: 
+ *  Helper for splitting files up into individual lines.
  */
-static int get_line(AL_CONST char *data, int length, char **name, char **val)
+static int get_line(AL_CONST char *data, int length, char *name, int name_size, char *val, int val_size)
 {
-   char *buf;
-   int buf_size=256;
+   char buf[512], buf2[512];
    int inpos, outpos, i, j;
    int c, c2, w0;
 
@@ -278,14 +260,7 @@ static int get_line(AL_CONST char *data, int length, char **name, char **val)
    outpos = 0;
    w0 = ucwidth(0);
 
-   buf = malloc(buf_size);
-   if (!buf) {
-     *allegro_errno = ENOMEM;
-     return -1;
-   }
-
-   /* search for an EOL marker */
-   while (inpos<length) {
+   while ((inpos<length) && (outpos<(int)sizeof(buf)-w0)) {
       c = ugetc(data+inpos);
       if ((c == '\r') || (c == '\n')) {
 	 inpos += uwidth(data+inpos);
@@ -297,16 +272,6 @@ static int get_line(AL_CONST char *data, int length, char **name, char **val)
 	 break;
       }
 
-      /* increase the buffer size if needed */
-      if (outpos>=(int)buf_size-w0) {
-	 buf_size *= 2;
-	 buf = _al_sane_realloc(buf, buf_size);
-	 if (!buf) {
-	    *allegro_errno = ENOMEM;
-	    return -1;
-	 }
-      }
-
       outpos += usetc(buf+outpos, c);
       inpos += uwidth(data+inpos);
    }
@@ -325,53 +290,35 @@ static int get_line(AL_CONST char *data, int length, char **name, char **val)
    /* read name string */
    j = 0;
 
-   /* compute name length */
    while ((c) && (!uisspace(c)) && (c != '=') && (c != '#')) {
-      j += ucwidth(c);
+      j += usetc(buf2+j, c);
       i += uwidth(buf+i);
       c = ugetc(buf+i);
    }
 
    if (j) {
       /* got a variable */
-      *name = malloc(j+w0);
-      if (!(*name)) {
-	 *allegro_errno = ENOMEM;
-	 free(buf);
-	 return -1;
-      }
-
-      ustrzcpy(*name, j+w0, buf+i-j);
+      usetc(buf2+j, 0);
+      ustrzcpy(name, name_size, buf2);
 
       while ((c) && ((uisspace(c)) || (c == '='))) {
 	 i += uwidth(buf+i);
 	 c = ugetc(buf+i);
       }
 
-      *val = ustrdup(buf+i);
-      if (!(*val)) {
-	 free(name);
-	 free(buf);
-	 return -1;
-      }
+      ustrzcpy(val, val_size, buf+i);
 
       /* strip trailing spaces */
-      i = ustrlen(*val) - 1;
-      while ((i >= 0) && (uisspace(ugetat(*val, i))))
-	 usetat(*val, i--, 0);
+      i = ustrlen(val) - 1;
+      while ((i >= 0) && (uisspace(ugetat(val, i))))
+	 usetat(val, i--, 0);
    }
    else {
       /* blank line or comment */
-      *name = NULL;
-      *val = ustrdup(buf);
-      if (!(*val)) {
-	 free(buf);
-	 return -1;
-      }
+      usetc(name, 0);
+      ustrzcpy(val, val_size, buf);
    }
 
-   free(buf);
-
    return inpos;
 }
 
@@ -382,9 +329,9 @@ static int get_line(AL_CONST char *data, int length, char **name, char **val)
  */
 static void set_config(CONFIG **config, AL_CONST char *data, int length, AL_CONST char *filename)
 {
+   char name[256], val[256];
    CONFIG_ENTRY **prev, *p;
-   char *name, *val;
-   int ret, pos;
+   int pos;
 
    init_config(FALSE);
 
@@ -394,22 +341,14 @@ static void set_config(CONFIG **config, AL_CONST char *data, int length, AL_CONS
    }
 
    *config = malloc(sizeof(CONFIG));
-   if (!(*config)) {
-      *allegro_errno = ENOMEM;
+   if (!(*config))
       return;
-   }
 
    (*config)->head = NULL;
    (*config)->dirty = FALSE;
 
-   if (filename) {
+   if (filename)
       (*config)->filename = ustrdup(filename);
-      if (!(*config)->filename) {
-	 free(*config);
-	 *config = NULL;
-	 return;
-      }
-   }
    else
       (*config)->filename = NULL;
 
@@ -417,25 +356,18 @@ static void set_config(CONFIG **config, AL_CONST char *data, int length, AL_CONS
    pos = 0;
 
    while (pos < length) {
-      ret = get_line(data+pos, length-pos, &name, &val);
-      if (ret<0) {
-	 free(*config);
-	 *config = NULL;
-	 return;
-      }
-
-      pos += ret;
+      pos += get_line(data+pos, length-pos, name, sizeof(name), val, sizeof(val));
 
       p = malloc(sizeof(CONFIG_ENTRY));
-      if (!p) {
-	 *allegro_errno = ENOMEM;
-	 free(*config);
-	 *config = NULL;
+      if (!p)
 	 return;
-      }
 
-      p->name = name;
-      p->data = val;
+      if (ugetc(name))
+         p->name = ustrdup(name);
+      else
+	 p->name = NULL;
+
+      p->data = ustrdup(val);
 
       p->next = NULL;
       *prev = p;
@@ -458,12 +390,6 @@ static void load_config_file(CONFIG **config, AL_CONST char *filename, AL_CONST
       *config = NULL;
    }
 
-   /* Special case when allegro_init has not been called yet. */
-   if (!system_driver) {
-      set_config(config, NULL, 0, savefile);
-      return;
-   }
-
    length = file_size(filename);
 
    if (length > 0) {
@@ -481,7 +407,7 @@ static void load_config_file(CONFIG **config, AL_CONST char *filename, AL_CONST
 	       tmp2 = malloc(length);
 
 	       if (tmp2)
-		  do_uconvert(tmp, U_UTF8, tmp2, U_CURRENT, length);
+		  do_uconvert(tmp, U_UTF8, tmp2, U_CURRENT, -1);
 
 	       length -= ucwidth(0);
 	    }
@@ -516,7 +442,6 @@ static void load_config_file(CONFIG **config, AL_CONST char *filename, AL_CONST
  */
 void set_config_file(AL_CONST char *filename)
 {
-   ASSERT(filename);
    load_config_file(&config[0], filename, filename);
 }
 
@@ -528,7 +453,6 @@ void set_config_file(AL_CONST char *filename)
  */
 void set_config_data(AL_CONST char *data, int length)
 {
-   ASSERT(data);
    set_config(&config[0], data, length, NULL);
 }
 
@@ -539,14 +463,7 @@ void set_config_data(AL_CONST char *data, int length)
  */
 void override_config_file(AL_CONST char *filename)
 {
-   /* load other configuration file to override settings */
-   if (filename)
-      load_config_file(&config_override, filename, filename);
-   /* destroy the current one */
-   else if (config_override) {
-      destroy_config(config_override);
-      config_override = NULL;
-   }
+   load_config_file(&config_override, filename, NULL);
 }
 
 
@@ -557,7 +474,6 @@ void override_config_file(AL_CONST char *filename)
  */
 void override_config_data(AL_CONST char *data, int length)
 {
-   ASSERT(data);
    set_config(&config_override, data, length, NULL);
 }
 
@@ -916,9 +832,11 @@ int get_config_id(AL_CONST char *section, AL_CONST char *name, int def)
  */
 char **get_config_argv(AL_CONST char *section, AL_CONST char *name, int *argc)
 {
+   #define MAX_ARGV  16
+
+   static char buf[256];
+   static char *argv[MAX_ARGV];
    int pos, ac, q, c;
-   int s_size;
-   int i;
 
    AL_CONST char *s = get_config_string(section, name, NULL);
 
@@ -927,97 +845,44 @@ char **get_config_argv(AL_CONST char *section, AL_CONST char *name, int *argc)
       return NULL;
    }
 
-   /* clean up the old argv that was allocated the last time this function was
-    * called.
-    */
-   free(config_argv);
-   config_argv = NULL;
-
-   /* increase the buffer size if needed */
-   s_size = ustrsizez(s);
-   if (s_size>argv_buf_size) {
-      argv_buf_size = s_size;
-      argv_buf = _al_sane_realloc(argv_buf, argv_buf_size);
-      if (!argv_buf) {
-         *allegro_errno = ENOMEM;
-         *argc = 0;
-         return NULL;
-      }
-   }
-
-   ustrzcpy(argv_buf, argv_buf_size, s);
+   ustrzcpy(buf, sizeof(buf), s);
    pos = 0;
    ac = 0;
 
-   /* tokenize the buffer and count the number of words; every space character
-    * as well as single and double quotes are replaced with zeros; comments * that start with # are also cut off with a 0
-    */
-   c = ugetc(argv_buf);
-   while ((c) && (c != '#')) {
-      /* replace all spaces up to the next word with 0 */
+   c = ugetc(buf);
+
+   while ((ac<MAX_ARGV) && (c) && (c != '#')) {
       while ((c) && (uisspace(c))) {
-	 usetat(argv_buf+pos, 0, 0);
-	 pos += ucwidth(0);
-	 c = ugetc(argv_buf+pos);
+	 pos += ucwidth(c);
+	 c = ugetc(buf+pos);
       }
 
-      /* quit if we reached the end of the buffer or a comment */
       if ((c) && (c != '#')) {
-         /* found another word! */
-         ac++;
+	 if ((c == '\'') || (c == '"')) {
+	    q = c;
+	    pos += ucwidth(c);
+	    c = ugetc(buf+pos);
+	 }
+	 else
+	    q = 0;
 
-         /* cut away quotes by replacing them with 0 */
-         if ((c == '\'') || (c == '"')) {
-            q = c;
-            usetat(argv_buf+pos, 0, 0);
-            pos += ucwidth(0);
-            c = ugetc(argv_buf+pos);
-         }
-         else {
-            q = 0;
-         }
+	 argv[ac++] = buf+pos;
 
-         /* search for the end of the word */
-         while ((c) && ((q) ? (c != q) : (!uisspace(c)))) {
-            pos += ucwidth(c);
-            c = ugetc(argv_buf+pos);
-         }
-      }
-   }
+	 while ((c) && ((q) ? (c != q) : (!uisspace(c)))) {
+	    pos += ucwidth(c);
+	    c = ugetc(buf+pos);
+	 }
 
-   /* now that we know how many words there are in the buffer, allocate enough
-    * space for a list of pointers to them, or return 0 if there are no words
-    */
-   if (ac > 0) {
-      config_argv = malloc(ac*sizeof *config_argv);
-   }
-   else {
-      *argc = 0;
-      return NULL;
-   }
-
-   /* go through the tokenized buffer and assign pointers in argv to point to
-    * the beginning of each individual word
-    */
-   for (i=0,pos=0,c=ugetc(argv_buf); i<ac; i++) {
-      /* find next word */
-      while (!c) {
-         pos += ucwidth(c);
-         c = ugetc(argv_buf+pos);
-      }
-
-      /* assign pointer */
-      config_argv[i] = argv_buf+pos;
-
-      /* find end of the word */
-      while (c) {
-         pos += ucwidth(c);
-         c = ugetc(argv_buf+pos);
+	 if (c) {
+	    usetat(buf+pos, 0, 0);
+	    pos += ucwidth(0);
+	    c = ugetc(buf+pos);
+	 }
       }
    }
 
    *argc = ac;
-   return config_argv;
+   return argv;
 }
 
 
@@ -1085,8 +950,6 @@ void set_config_string(AL_CONST char *section, AL_CONST char *name, AL_CONST cha
    /* decide which config file to use */
    if ((ugetc(name) == '#') || ((ugetc(section_name) == '[') && (ugetat(section_name, 1) == '#')))
       the_config = system_config;
-   else if (config_override)
-      the_config = config_override;
    else
       the_config = config[0];
 
@@ -1229,21 +1092,6 @@ void set_config_id(AL_CONST char *section, AL_CONST char *name, int val)
 
 
 
-/* _reload_config:
- *  Internal helper to reload the configuration from allegro_init, in case
- *  set_config_file was called before allegro_init.
- */
-void _reload_config(void)
-{
-   if (config[0]) {
-      char *name = ustrdup(config[0]->filename);
-      set_config_file(name);
-      free(name);
-   }
-}
-
-
-
 /* reload_config_texts:
  *  Reads in a block of translated system text, looking for either a
  *  user-specified file, a ??text.cfg file, or a language.dat#??TEXT_CFG 
@@ -1303,101 +1151,62 @@ void reload_config_texts(AL_CONST char *new_language)
  */
 AL_CONST char *get_config_text(AL_CONST char *msg)
 {
-   char tmp1[256];
+   char tmp1[256], tmp2[256], name[256];
    AL_CONST char *section = uconvert_ascii("[language]", tmp1);
-   AL_CONST char *umsg;
+   AL_CONST char *umsg = uconvert_ascii(msg, tmp2);
    AL_CONST char *s;
-   AL_CONST char *ret = NULL;
-   char *name;
    CONFIG_HOOK *hook;
    CONFIG_ENTRY *p;
-   int c, pos, size;
-   ASSERT(msg);
+   int c, pos;
 
    init_config(TRUE);
 
-   /* allocate memory and convert message to current encoding format */
-   if (need_uconvert(msg, U_ASCII, U_CURRENT)) {
-      size = uconvert_size(msg, U_ASCII, U_CURRENT);
-      umsg = malloc(size);
-      if (!umsg) {
-	 *allegro_errno = ENOMEM;
-	 return empty_string;
-      }
-
-      name = malloc(size);
-      if (!name) {
-	 free((char *)umsg);  /* remove constness */
-	 *allegro_errno = ENOMEM;
-	 return empty_string;
-      }
-
-      do_uconvert(msg, U_ASCII, (char*)umsg, U_CURRENT, size);
+   /* kludge to make it easier to translate the message */
+   if (strcmp(msg, ALLEGRO_WINDOW_CLOSE_MESSAGE) == 0) {
+      do_uconvert("allegro_window_close_message", U_ASCII, name, U_CURRENT, sizeof(name));
    }
    else {
-      umsg = msg;
-      name = malloc(ustrsizez(msg));
-      if (!name) {
-	 *allegro_errno = ENOMEM;
-	 return empty_string;
+      s = umsg;
+      pos = 0;
+
+      while ((c = ugetxc(&s)) != 0) {
+	 if ((uisspace(c)) || (c == '=') || (c == '#'))
+	    pos += usetc(name+pos, '_');
+	 else
+	    pos += usetc(name+pos, c);
       }
+
+      usetc(name+pos, 0);
    }
 
-   s = umsg;
-   pos = 0;
-
-   while ((c = ugetxc(&s)) != 0) {
-      if ((uisspace(c)) || (c == '=') || (c == '#'))
-	 pos += usetc(name+pos, '_');
-      else
-	 pos += usetc(name+pos, c);
-   }
-
-   usetc(name+pos, 0);
-
    /* check for hooked sections */
    hook = config_hook;
 
    while (hook) {
       if (ustricmp(section, hook->section) == 0) {
-	 if (hook->stringgetter) {
-	    ret = hook->stringgetter(name, umsg);
-	    break;
-	 }
+	 if (hook->stringgetter)
+	    return hook->stringgetter(name, umsg);
       }
-
       hook = hook->next;
    }
 
-   if (!ret) {
-      /* find the string */
-      p = find_config_string(config_override, section, name, NULL);
+   /* find the string */
+   p = find_config_string(config_override, section, name, NULL);
 
-      if (!p) {
-	 p = find_config_string(config[0], section, name, NULL);
+   if (!p) {
+      p = find_config_string(config[0], section, name, NULL);
 
-	 if (!p)
-	    p = find_config_string(config_language, section, name, NULL);
-      }
-
-      if (p) {
-	 ret = (p->data ? p->data : empty_string);
-      }
-      else {
-	 /* no translation, so store off this value in the file */
-	 p = config_language->head;
-	 insert_variable(config_language, NULL, name, umsg);
-	 config_language->head->next = p;
-	 ret = config_language->head->data;
-      }
+      if (!p)
+	 p = find_config_string(config_language, section, name, NULL);
    }
 
-   /* free memory */
-   if (umsg!=msg)
-      free((char*) umsg);  /* remove constness */
+   if (p)
+      return (p->data ? p->data : empty_string);
 
-   free(name);
-
-   return ret;
+   /* no translation, so store off this value in the file */
+   p = config_language->head;
+   insert_variable(config_language, NULL, name, umsg);
+   config_language->head->next = p;
+   return config_language->head->data;
 }
 
