@@ -14,9 +14,6 @@
  *
  *      State saving routines added by Shawn Hargreaves.
  *
- *      Switch callbacks support added by Lorenzo Petrone,
- *      based on code by Stefan Schimanski.
- *
  *      See readme.txt for copyright information.
  */
 
@@ -25,13 +22,17 @@
 #include "allegro/internal/aintern.h"
 
 
+
 #ifdef ALLEGRO_DOS
    static int switch_mode = SWITCH_NONE;
+#elif defined ALLEGRO_WINDOWS
+   static int switch_mode = SWITCH_AMNESIA;
 #else
    static int switch_mode = SWITCH_PAUSE;
 #endif
 
 
+
 /* remember things about the way our bitmaps are set up */
 typedef struct BITMAP_INFORMATION
 {
@@ -42,29 +43,25 @@ typedef struct BITMAP_INFORMATION
    void *acquire, *release;               /* need to bodge the vtable, too */
 } BITMAP_INFORMATION;
 
+
+
 static BITMAP_INFORMATION *info_list = NULL;
 
-
 int _dispsw_status = SWITCH_NONE;
 
-#define MAX_SWITCH_CALLBACKS  8
-static void (*switch_in_cb[MAX_SWITCH_CALLBACKS])(void) = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-static void (*switch_out_cb[MAX_SWITCH_CALLBACKS])(void) = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-
 
 
 /* set_display_switch_mode:
- *  Sets the display switch mode. Returns zero and unregisters
- *  all callbacks on success, returns non-zero on failure.
+ *  Returns zero on success, nonzero on error; unregisters
+ *  all callbacks.
  */
 int set_display_switch_mode(int mode)
 {
-   int ret, i;
+   int retval;
 
    if ((!system_driver))
       return -1;
 
-   /* platforms that don't support switching allow SWITCH_NONE */
    if (!system_driver->set_display_switch_mode) {
       if (mode == SWITCH_NONE)
          return 0;
@@ -72,17 +69,12 @@ int set_display_switch_mode(int mode)
          return -1;
    }
 
-   ret = system_driver->set_display_switch_mode(mode);
-
-   if (ret == 0) {
-      /* unregister all callbacks */
-      for (i=0; i<MAX_SWITCH_CALLBACKS; i++)
-         switch_in_cb[i] = switch_out_cb[i] = NULL;
+   retval = system_driver->set_display_switch_mode(mode);
 
+   if (!retval)
       switch_mode = mode;
-   }
 
-   return ret;
+   return retval;
 }
 
 
@@ -98,84 +90,31 @@ int get_display_switch_mode(void)
 
 
 /* set_display_switch_callback:
- *  Registers a display switch callback. The first parameter indicates
- *  the direction (SWITCH_IN or SWITCH_OUT). Returns zero on success,
- *  non-zero on failure (e.g. feature not supported).
+ *  The first parameter indicates the direction (SWITCH_IN or 
+ *  SWITCH_OUT).  Set `cb' to NULL to turn off the feature. 
+ *  Returns zero on success, non-zero on failure (e.g. feature 
+ *  not supported).
  */
 int set_display_switch_callback(int dir, void (*cb)(void))
 {
-   int i;
-
    if ((dir != SWITCH_IN) && (dir != SWITCH_OUT))
       return -1;
 
-   if ((!system_driver) || (!system_driver->set_display_switch_mode))
+   if ((!system_driver) || (!system_driver->set_display_switch_callback))
       return -1;
 
-   for (i=0; i<MAX_SWITCH_CALLBACKS; i++) {
-      if (dir == SWITCH_IN) {
-	 if (!switch_in_cb[i]) {
-	    switch_in_cb[i] = cb;
-	    return 0;
-	 }
-      }
-      else {
-	 if (!switch_out_cb[i]) {
-	    switch_out_cb[i] = cb;
-	    return 0;
-	 }
-      }
-   }
-
-   return -1;
+   return system_driver->set_display_switch_callback(dir, cb);
 }
 
 
 
 /* remove_display_switch_callback:
- *  Unregisters a display switch callback.
+ *  Pretty much the opposite of the above.
  */
 void remove_display_switch_callback(void (*cb)(void))
 {
-   int i;
-
-   for (i=0; i<MAX_SWITCH_CALLBACKS; i++) {
-      if (switch_in_cb[i] == cb)
-	 switch_in_cb[i] = NULL;
-
-      if (switch_out_cb[i] == cb)
-	 switch_out_cb[i] = NULL;
-   }
-}
-
-
-
-/* _switch_in:
- *  Handles a SWITCH_IN event.
- */
-void _switch_in(void)
-{
-   int i;
-
-   for (i=0; i<MAX_SWITCH_CALLBACKS; i++) {
-      if (switch_in_cb[i])
-	 switch_in_cb[i]();
-   }
-}
-
-
-
-/* _switch_out:
- *  Handles a SWITCH_OUT event.
- */
-void _switch_out(void)
-{
-   int i;
-
-   for (i=0; i<MAX_SWITCH_CALLBACKS; i++) {
-      if (switch_out_cb[i])
-	 switch_out_cb[i]();
-   }
+   if ((system_driver) && (system_driver->remove_display_switch_callback))
+      system_driver->remove_display_switch_callback(cb);
 }
 
 
@@ -333,17 +272,16 @@ static void reconstruct_kids(BITMAP *parent, BITMAP_INFORMATION *info)
  */
 static void fudge_bitmap(BITMAP *b1, BITMAP *b2)
 {
-   int s, x1, y1, x2, y2;
-
-   set_clip_state(b2, FALSE);
+   set_clip(b2, 0, 0, 0, 0);
 
    blit(b1, b2, 0, 0, 0, 0, b1->w, b1->h);
 
-   get_clip_rect(b1, &x1, &y1, &x2, &y2);
-   s = get_clip_state(b1);
+   b2->clip = b1->clip;
 
-   set_clip_rect(b2, x1, y1, x2, y2);
-   set_clip_state(b2, s);
+   b2->cl = b1->cl;
+   b2->cr = b1->cr;
+   b2->ct = b1->ct;
+   b2->cb = b1->cb;
 }
 
 
