@@ -95,8 +95,6 @@ MOUSE_DRIVER mousedrv_mickeys =
    mick_set_range,
    mick_set_speed,
    mick_get_mickeys,
-   NULL,
-   NULL,
    NULL
 };
 
@@ -125,8 +123,6 @@ MOUSE_DRIVER mousedrv_int33 =
    int33_set_range,
    int33_set_speed,
    int33_get_mickeys,
-   NULL,
-   NULL,
    NULL
 };
 
@@ -152,8 +148,6 @@ MOUSE_DRIVER mousedrv_polling =
    int33_set_range,
    int33_set_speed,
    int33_get_mickeys,
-   NULL,
-   NULL,
    NULL
 };
 
@@ -177,8 +171,6 @@ MOUSE_DRIVER mousedrv_winnt =
    int33_set_range,
    int33_set_speed,
    int33_get_mickeys,
-   NULL,
-   NULL,
    NULL
 };
 
@@ -202,8 +194,6 @@ MOUSE_DRIVER mousedrv_win2k =
    mick_set_range,
    mick_set_speed,
    mick_get_mickeys,
-   NULL,
-   NULL,
    NULL
 };
 
@@ -438,7 +428,7 @@ static void mick_lock(void)
 /* mick_init:
  *  Initialises the mickey-mode driver.
  */
-static int mick_init(void)
+static int mick_init()
 {
    if (os_type == OSTYPE_WINNT)
       return -1;
@@ -453,7 +443,7 @@ static int mick_init(void)
 /* win2k_init:
  *  Initialises the win2k driver.
  */
-static int win2k_init(void)
+static int win2k_init()
 {
    /* only for use under Win2k */
    if (os_type != OSTYPE_WINNT)
@@ -469,7 +459,7 @@ static int win2k_init(void)
 /* mick_exit:
  *  Shuts down the mickey-mode driver.
  */
-static void mick_exit(void)
+static void mick_exit()
 {
    __dpmi_regs r;
 
@@ -583,7 +573,7 @@ static void int33_get_mickeys(int *mickeyx, int *mickeyy)
 /* int33_init:
  *  Initialises the int 0x33 driver.
  */
-static int int33_init(void)
+static int int33_init()
 {
    if (os_type == OSTYPE_WINNT)
       return -1;
@@ -599,7 +589,7 @@ static int int33_init(void)
 /* int33_exit:
  *  Shuts down the int 0x33 driver.
  */ 
-static void int33_exit(void)
+static void int33_exit()
 {
    __dpmi_regs r;
 
@@ -624,7 +614,7 @@ static void int33_exit(void)
 /* polling_timer_poll:
  *  Handler for the periodic timer polling mode.
  */
-static void polling_timer_poll(void)
+static void polling_timer_poll()
 {
    __dpmi_regs r;
 
@@ -643,7 +633,7 @@ END_OF_STATIC_FUNCTION(polling_timer_poll);
 /* polling_init:
  *  Initialises the periodic timer driver.
  */
-static int polling_init(void)
+static int polling_init()
 {
    if (os_type == OSTYPE_WINNT)
       return -1;
@@ -659,7 +649,7 @@ static int polling_init(void)
 /* winnt_init:
  *  Initialises the WinNT driver.
  */
-static int winnt_init(void)
+static int winnt_init()
 {
    /* only for use under WinNT */
    if (os_type != OSTYPE_WINNT)
@@ -676,7 +666,7 @@ static int winnt_init(void)
 /* polling_exit:
  *  Shuts down the periodic timer driver.
  */
-static void polling_exit(void)
+static void polling_exit()
 {
    __dpmi_regs r;
 
