@@ -96,7 +96,7 @@ static int fli_mem_pos = 0;            /* position in the memory FLI */
 static FLI_HEADER fli_header;          /* header structure */
 static FLI_FRAME frame_header;         /* frame header structure */
 
-static unsigned char _fli_broken_data[3 * 256]; /* data substituted for broken chunks */
+static char _fli_broken_data[3 * 256]; /* data substituted for broken chunks */
 
 
 
@@ -184,33 +184,20 @@ static void fli_skip(int bytes)
 
 
 /* helpers for reading FLI chunk data */
-#if 0
-/* the "cast expression as lvalue" extension is deprecated in GCC 3.4 */
 #define READ_BYTE_NC(p)    (*((unsigned char *)(p))++)
 #define READ_CHAR_NC(p)    (*((signed char *)(p))++)
-#else
-#define READ_BYTE_NC(p)    (*(unsigned char *)(p)++)
-#define READ_CHAR_NC(p)    (*(signed char *)(p)++)
-#endif
 
-#if (defined ALLEGRO_GCC) && (defined ALLEGRO_LITTLE_ENDIAN) && (!defined ALLEGRO_ARM)
+#if (defined ALLEGRO_GCC) && (defined ALLEGRO_I386)
 
-#if 0
-/* the "cast expression as lvalue" extension is deprecated in GCC 3.4 */
-#define READ_WORD_NC(p)    (*((uint16_t *)(p))++)
-#define READ_SHORT_NC(p)   (*((int16_t *)(p))++)
-#define READ_ULONG_NC(p)   (*((uint32_t *)(p))++)
-#define READ_LONG_NC(p)    (*((int32_t *)(p))++)
-#else
-/* we use the "statement-expression" extension instead */
-#define READ_WORD_NC(p)    ({ uint16_t *__p = (uint16_t *)(p); p+=2; *__p; })
-#define READ_SHORT_NC(p)   ({ int16_t *__p = (int16_t *)(p); p+=2; *__p; })
-#define READ_ULONG_NC(p)   ({ uint32_t *__p = (uint32_t *)(p); p+=4; *__p; })
-#define READ_LONG_NC(p)    ({ int32_t *__p = (int32_t *)(p); p+=4; *__p; })
-#endif
+/* for gcc on i386 */
+#define READ_WORD_NC(p)    (*((unsigned short *)(p))++)
+#define READ_SHORT_NC(p)   (*((signed short *)(p))++)
+#define READ_ULONG_NC(p)   (*((unsigned long *)(p))++)
+#define READ_LONG_NC(p)    (*((signed long *)(p))++)
 
 #else
 
+/* for other compilers/platforms */
 static unsigned short _fli_read_word_nc(unsigned char **p)
 {
    unsigned short t;
@@ -270,7 +257,7 @@ static signed long _fli_read_long_nc(unsigned char **p)
 #define READ_RLE_WORD_NC(p,pos,size)                            \
 {                                                               \
    int c;                                                       \
-   uint16_t *ptr = (uint16_t*) (pos);                           \
+   unsigned short *ptr = (unsigned short*) (pos);               \
    unsigned short v = READ_WORD_NC(p);                          \
 								\
    for (c = 0; c < (size); c++)                                 \
@@ -343,7 +330,7 @@ static void do_fli_256_color(unsigned char *p, int sz)
       if (end > PAL_SIZE)
 	 return;
       else if ((sz -= length * 3) < 0) {
-	 FLI_KLUDGE(p, sz, length * 3);
+	 FLI_KLUDGE((char *)p, sz, length * 3);
       }
 
       fli_pal_dirty_from = MIN(fli_pal_dirty_from, offset);
@@ -409,7 +396,7 @@ static void do_fli_delta(unsigned char *p, int sz)
 	    if ((curr + size * 2) > bitmap_end)
 	       return;
 	    else if ((sz -= size * 2) < 0) {
-	       FLI_KLUDGE(p, sz, size * 2);
+	       FLI_KLUDGE((char *)p, sz, size * 2);
 	    }
 	    READ_BLOCK_NC(p, curr, size*2);
 	    curr += size*2;
@@ -419,7 +406,7 @@ static void do_fli_delta(unsigned char *p, int sz)
 	    if ((curr + size * 2) > bitmap_end)
 	       return;
 	    else if ((sz -= 2) < 0) {
-	       FLI_KLUDGE(p, sz, 2);
+	       FLI_KLUDGE((char *)p, sz, 2);
 	    }
 	    READ_RLE_WORD_NC(p, curr, size);
 	    curr += size*2;
@@ -459,7 +446,7 @@ static void do_fli_color(unsigned char *p, int sz)
       if (end > PAL_SIZE)
 	 return;
       else if ((sz -= length * 3) < 0) {
-	 FLI_KLUDGE(p, sz, length * 3);
+	 FLI_KLUDGE((char *)p, sz, length * 3);
       }
 
       fli_pal_dirty_from = MIN(fli_pal_dirty_from, offset);
@@ -516,7 +503,7 @@ static void do_fli_lc(unsigned char *p, int sz)
 	    if ((curr + size) > bitmap_end)
 	       return;
 	    else if ((sz -= size) < 0) {
-	       FLI_KLUDGE(p, sz, size);
+	       FLI_KLUDGE((char *)p, sz, size);
 	    }
 	    READ_BLOCK_NC(p, curr, size);
 	    curr += size;
@@ -526,7 +513,7 @@ static void do_fli_lc(unsigned char *p, int sz)
 	    if ((curr + size) > bitmap_end)
 	       return;
 	    else if ((sz -= 1) < 0) {
-	       FLI_KLUDGE(p, sz, 1);
+	       FLI_KLUDGE((char *)p, sz, 1);
 	    }
 	    READ_RLE_BYTE_NC(p, curr, size);
 	    curr += size;
@@ -585,7 +572,7 @@ static void do_fli_brun(unsigned char *p, int sz)
 	       if ((curr + size) > bitmap_end)
 		  return;
 	       else if ((sz -= size) < 0) {
-		  FLI_KLUDGE(p, sz, size);
+		  FLI_KLUDGE((char *)p, sz, size);
 	       }
 	       READ_BLOCK_NC(p, curr, size);
 	       curr += size;
@@ -594,7 +581,7 @@ static void do_fli_brun(unsigned char *p, int sz)
 	       if ((curr + size) > bitmap_end)
 		  return;
 	       else if ((sz -= 1) < 0) {
-		  FLI_KLUDGE(p, sz, 1);
+		  FLI_KLUDGE((char *)p, sz, 1);
 	       }
 	       READ_RLE_BYTE_NC(p, curr, size);
 	       curr += size;
@@ -613,7 +600,7 @@ static void do_fli_brun(unsigned char *p, int sz)
 	       if ((curr + size) > bitmap_end)
 		  return;
 	       if ((sz -= size) < 0) {
-		  FLI_KLUDGE(p, sz, size);
+		  FLI_KLUDGE((char *)p, sz, size);
 	       }
 	       READ_BLOCK_NC(p, curr, size);
 	       curr += size;
@@ -622,7 +609,7 @@ static void do_fli_brun(unsigned char *p, int sz)
 	       if ((curr + size) > bitmap_end)
 		  return;
 	       if ((sz -= 1) < 0) {
-		  FLI_KLUDGE(p, sz, 1);
+		  FLI_KLUDGE((char *)p, sz, 1);
 	       }
 	       READ_RLE_BYTE_NC(p, curr, size);
 	       curr += size;
@@ -822,12 +809,6 @@ static void read_frame(void)
       }
 
       p += sz;
-
-      /* alignment */
-      if (sz & 1) {
-	 p++;
-	 frame_size--;
-      }
    }
 
    /* move on to the next frame */
@@ -870,10 +851,9 @@ static int do_play_fli(BITMAP *bmp, int loop, int (*callback)(void))
 
       ret = next_fli_frame(loop);
 
-      while (fli_timer <= 0) {
+      do {
 	 /* wait a bit */
-	 rest(0);
-      }
+      } while (fli_timer <= 0);
    }
 
    close_fli();
@@ -897,9 +877,6 @@ static int do_play_fli(BITMAP *bmp, int loop, int (*callback)(void))
  */
 int play_fli(AL_CONST char *filename, BITMAP *bmp, int loop, int (*callback)(void))
 {
-   ASSERT(filename);
-   ASSERT(bmp);
-   
    if (open_fli(filename) != FLI_OK)
       return FLI_ERROR;
 
@@ -914,9 +891,6 @@ int play_fli(AL_CONST char *filename, BITMAP *bmp, int loop, int (*callback)(voi
  */
 int play_memory_fli(void *fli_data, BITMAP *bmp, int loop, int (*callback)(void))
 {
-   ASSERT(fli_data);
-   ASSERT(bmp);
-   
    if (open_memory_fli(fli_data) != FLI_OK)
       return FLI_ERROR;
 
@@ -987,13 +961,11 @@ static int do_open_fli(void)
  */
 int open_fli(AL_CONST char *filename)
 {
-   ASSERT(filename);
-   
    if (fli_status != FLI_NOT_OPEN)
       return FLI_ERROR;
 
    if (fli_filename) {
-      _AL_FREE(fli_filename);
+      free(fli_filename);
       fli_filename = NULL;
    }
 
@@ -1016,8 +988,6 @@ int open_fli(AL_CONST char *filename)
  */
 int open_memory_fli(void *fli_data)
 {
-   ASSERT(fli_data);
-   
    if (fli_status != FLI_NOT_OPEN)
       return FLI_ERROR;
 
@@ -1032,7 +1002,7 @@ int open_memory_fli(void *fli_data)
 /* close_fli:
  *  Shuts down the FLI player at the end of the file.
  */
-void close_fli(void)
+void close_fli()
 {
    remove_int(fli_timer_callback);
 
@@ -1042,7 +1012,7 @@ void close_fli(void)
    }
 
    if (fli_filename) {
-      _AL_FREE(fli_filename);
+      free(fli_filename);
       fli_filename = NULL;
    }
 
@@ -1098,7 +1068,7 @@ int next_fli_frame(int loop)
  *  Clears the information about which parts of the FLI bitmap and palette
  *  are dirty, after the screen hardware has been updated.
  */
-void reset_fli_variables(void)
+void reset_fli_variables()
 {
    fli_bmp_dirty_from = INT_MAX;
    fli_bmp_dirty_to = INT_MIN;
