@@ -26,14 +26,10 @@
  *      Annie Testes modified it so that buffer overflows cannot occur
  *      anymore.
  *
- *      Eric Botcazou optimized the handling of the extension string.
- *
  *      See readme.txt for copyright information.
  */
 
 
-#include <string.h>
-
 #include "allegro.h"
 #include "allegro/internal/aintern.h"
 
@@ -55,43 +51,19 @@ static char *fs_dlist_getter(int, int *);
 
 #endif
 
-/* Number of entries is limited by available memory
- * Initial capacity is given by FLIST_START_CAPACITY, structure can grow beyond
- * this. Normally keeps the structure in memory between invocations, but it
- * attempts to free memory after processing a directory with more than 
- * FLIST_UPPER_CAPACITY 
- */
-#define FLIST_START_CAPACITY 128
-#define FLIST_UPPER_CAPACITY 2048
+
+#define FLIST_SIZE      2048
 
 typedef struct FLIST
 {
    char dir[1024];
    int size;
-   int capacity;
-   char** name;
+   char *name[FLIST_SIZE];
 } FLIST;
 
 static FLIST *flist = NULL;
 
-
-/* file extensions */
-static char *fext = NULL;     /* tokenized extension string (dynamically allocated)     */
-static char **fext_p = NULL;  /* list of pointers to the tokens (dynamically allocated) */
-static int fext_size = 0;     /* size of the list                                       */
-
-
-/* file attributes (rhsda order) */
-#define ATTRB_MAX     5   /* number of attributes */
-#define ATTRB_DIREC   3   /* index of FA_DIREC    */
-
-typedef enum { ATTRB_ABSENT, ATTRB_UNSET, ATTRB_SET } attrb_state_t;
-
-#define DEFAULT_ATTRB_STATE  { ATTRB_ABSENT, ATTRB_UNSET, ATTRB_UNSET, ATTRB_ABSENT, ATTRB_ABSENT }
-
-static int attrb_flag[ATTRB_MAX] = { FA_RDONLY, FA_HIDDEN, FA_SYSTEM, FA_DIREC, FA_ARCH };
-static attrb_state_t attrb_state[ATTRB_MAX] = DEFAULT_ATTRB_STATE;
-
+static AL_CONST char *fext = NULL;
 
 static char updir[1024];
 
@@ -173,7 +145,7 @@ static int get_x_drive(int index)
    for (i=0; i<26; i++) {
       if (_al_drive_exists(i)) {
 	 c++;
-	 if (c == index)
+	 if (c==index)
 	    return i;
       }
    }
@@ -242,10 +214,12 @@ static int fs_dlist_proc(int msg, DIALOG *d, int c)
       s += usetc(s, OTHER_PATH_SEPARATOR);
       usetc(s, 0);
 
+      scare_mouse();
       object_message(file_selector+FS_FILES, MSG_START, 0);
       object_message(file_selector+FS_FILES, MSG_DRAW, 0);
       object_message(file_selector+FS_EDIT, MSG_START, 0);
       object_message(file_selector+FS_EDIT, MSG_DRAW, 0);
+      unscare_mouse();
 
       return D_O_K;
    }
@@ -277,7 +251,7 @@ static int fs_edit_proc(int msg, DIALOG *d, int c)
    int i;
 
    if (msg == MSG_START) {
-      canonicalize_filename(b, s, sizeof(b));
+      fix_filename_path(b, s, sizeof(b));
       ustrzcpy(s, size, b);
    }
 
@@ -285,7 +259,7 @@ static int fs_edit_proc(int msg, DIALOG *d, int c)
       if ((!ugetc(s)) || (ugetat(s, -1) == DEVICE_SEPARATOR))
 	 ustrzcat(s, size, uconvert_ascii("./", tmp));
 
-      canonicalize_filename(b, s, sizeof(b));
+      fix_filename_path(b, s, sizeof(b));
       ustrzcpy(s, size - ucwidth(OTHER_PATH_SEPARATOR), b);
 
       ch = ugetat(s, -1);
@@ -300,6 +274,7 @@ static int fs_edit_proc(int msg, DIALOG *d, int c)
 	    return D_CLOSE;
       }
 
+      scare_mouse();
       object_message(file_selector+FS_FILES, MSG_START, 0);
       /* did we `cd ..' ? */
       if (ustrlen(updir)) {
@@ -328,6 +303,7 @@ static int fs_edit_proc(int msg, DIALOG *d, int c)
       object_message(file_selector+FS_FILES, MSG_DRAW, 0);
       object_message(d, MSG_START, 0);
       object_message(d, MSG_DRAW, 0);
+      unscare_mouse();
 
       return D_O_K;
    }
@@ -403,84 +379,145 @@ static int ustrfilecmp(AL_CONST char *s1, AL_CONST char *s2)
 /* fs_flist_putter:
  *  Callback routine for for_each_file() to fill the file selector listbox.
  */
-static int fs_flist_putter(AL_CONST char *str, int attrib, void *check_attrib)
+static void fs_flist_putter(AL_CONST char *str, int attrib, int param)
 {
-   char *s, *ext, *name;
-   int c, c2;
+   char ext_tokens[32];
+   char *s, *ext, *tok, *name, *last;
+   char tmp[512], tmp2[32];
+   int c, c2, i, k, sign;
+
+   /* attribute flags (rhsda order)
+    * 0 = not required, 1 = must be set, -1 = must be unset
+    */
+   int attr_flag[5+5] = {
+      0, -1, -1, 0, 0,
+      FA_RDONLY, FA_HIDDEN, FA_SYSTEM, FA_DIREC, FA_ARCH
+   };
+
+   c = usetc(ext_tokens, ' ');
+   c += usetc(ext_tokens+c, ',');
+   c += usetc(ext_tokens+c, ';');
+   usetc(ext_tokens+c, 0);
 
    s = get_filename(str);
    fix_filename_case(s);
 
-   if (!(attrib & FA_DIREC)) {
-      /* Check if file extension matches. */
-      if (fext_p) {
-	 ext = get_extension(s);
-	 for (c=0; c<fext_size; c++) {
-	    if (ustricmp(ext, fext_p[c]) == 0)
-	       goto Next;
-	 }
-	 return 0;
+   if (fext) {
+      ustrzcpy(tmp, sizeof(tmp), fext);
+      ustrtok_r(tmp, ext_tokens, &last);
+      c = (ustrtok_r(NULL, ext_tokens, &last) ? 1 : 0);
+      if (!c) {
+	 if (!ustrchr(fext, '/'))
+	    c = 1;
       }
 
-    Next:
-      /* Check if file attributes match. */
-      if (check_attrib) {
-	 for (c=0; c<ATTRB_MAX; c++) {
-	    if ((attrb_state[c] == ATTRB_SET) && (!(attrib & attrb_flag[c])))
-	       return 0;
-	    if ((attrb_state[c] == ATTRB_UNSET) && (attrib & attrb_flag[c]))
-	       return 0;
-         }
+      if (c && (!(attrib & FA_DIREC))) {
+	 ustrzcpy(tmp, sizeof(tmp), fext);
+	 ext = get_extension(s);
+	 tok = ustrtok_r(tmp, ext_tokens, &last);
+
+	 while (tok) {
+	    if (ustricmp(ext, tok) == 0)
+	       break;
+
+	    tok = ustrtok_r(NULL, ext_tokens, &last);
+	 }
+
+	 if (!tok)
+	    return;
+      }
+
+      c = usetc(ext_tokens, ' ');
+      c += usetc(ext_tokens+c, ',');
+      c += usetc(ext_tokens+c, ';');
+      c += usetc(ext_tokens+c, '/');
+      usetc(ext_tokens+c, 0);
+
+      ustrzcpy(tmp, sizeof(tmp), fext);
+      tok = ustrchr(tmp, '/');
+
+      if (tok)
+	 tok = ustrtok_r(tok, ext_tokens, &last);
+
+      if (tok) {
+	 sign = 1;
+	 c = usetc(tmp2, 'r');
+	 c += usetc(tmp2+c, 'h');
+	 c += usetc(tmp2+c, 's');
+	 c += usetc(tmp2+c, 'd');
+	 c += usetc(tmp2+c, 'a');
+	 c += usetc(tmp2+c, '+');
+	 c += usetc(tmp2+c, '-');
+	 usetc(tmp2+c, 0);
+
+	 /* scan the string */
+	 i = 0;
+	 while ((c = utolower(ugetat(tok, i)))) {
+	    k = 0;
+	    while ((c2 = ugetat(tmp2, k))!=0) {
+	       if (c == c2) {
+		  if (k<5) {
+		     attr_flag[k] = sign;
+		     break;
+		  }
+		  else
+		     sign = (k==5) ? 1 : -1;
+	       }
+	       k++;
+	    }
+	    i++;
+	 }
       }
    }
 
-   if (((ugetc(s) != '.') || (ugetat(s, 1)))) {
-      int size = ustrsizez(s) + ((attrib & FA_DIREC) ? ucwidth(OTHER_PATH_SEPARATOR) : 0);
-      name = malloc(size);
+   /* check if file attributes match */
+   if (!(attr_flag[3+5] & attrib)) {
+      /* if not a directory, we check all attributes except FA_DIREC */
+      for (c=0; c<5; c++) {
+	 if (c == 3)
+	    continue;
+	 if ((attr_flag[c] == 1) && (!(attrib & attr_flag[c+5])))
+	    return;
+	 if ((attr_flag[c] == -1) && (attrib & attr_flag[c+5]))
+	    return;
+      }
+   }
+   else {
+      /* if a directory, we check only FA_DIREC */
+      if (attr_flag[3] == -1)
+	 return;
+   }
+
+   if ((flist->size < FLIST_SIZE) && ((ugetc(s) != '.') || (ugetat(s, 1)))) {
+      name = malloc(ustrsizez(s) + ((attrib & FA_DIREC) ? ucwidth(OTHER_PATH_SEPARATOR) : 0));
       if (!name)
-	 return -1;
+	 return;
 
-      ustrzcpy(name, size, s);
-      if (attrib & FA_DIREC)
-	 put_backslash(name);
-
-      /* Sort alphabetically with directories first. */
       for (c=0; c<flist->size; c++) {
 	 if (ugetat(flist->name[c], -1) == OTHER_PATH_SEPARATOR) {
 	    if (attrib & FA_DIREC)
-	       if (ustrfilecmp(name, flist->name[c]) < 0)
+	       if (ustrfilecmp(s, flist->name[c]) < 0)
 		  break;
 	 }
 	 else {
 	    if (attrib & FA_DIREC)
 	       break;
-	    if (ustrfilecmp(name, flist->name[c]) < 0)
+	    if (ustrfilecmp(s, flist->name[c]) < 0)
 	       break;
 	 }
       }
-      /* Do we need to allocate more space in the structure? */
-      /* This doubles the capacity of the array each time, */
-      /* which gives 'linear' compexity */
-      if (flist->size == flist->capacity) {
-         flist->capacity *= 2;
-	 flist->name = _al_sane_realloc(flist->name, sizeof(char *) * flist->capacity);
-	 if (flist->name == NULL) {
-	    *allegro_error = ENOMEM;
-	    /* Stop the enumeration by returning non-zero */
-	    return -1;
-	 }
-      }
 
-      /* Shift in preparation for inserting the new entry. */
       for (c2=flist->size; c2>c; c2--)
 	 flist->name[c2] = flist->name[c2-1];
 
-      /* Insert the new entry. */
       flist->name[c] = name;
+      ustrcpy(flist->name[c], s);  /* ustrzcpy() not needed */
+
+      if (attrib & FA_DIREC)
+	 put_backslash(flist->name[c]);
+
       flist->size++;
    }
-
-   return 0;
 }
 
 
@@ -501,23 +538,6 @@ static char *fs_flist_getter(int index, int *list_size)
 
 
 
-/* build_attrb_flag:
- *  Returns the cumulative flag for all attributes in state STATE.
- */
-static int build_attrb_flag(attrb_state_t state)
-{
-   int i, flag = 0;
-
-   for (i = 0; i < ATTRB_MAX; i++) {
-      if (attrb_state[i] == state)
-	 flag |= attrb_flag[i];
-   }
-  
-   return flag;
-}
-
-
-
 /* fs_flist_proc:
  *  Dialog procedure for the file selector list.
  */
@@ -539,48 +559,21 @@ static int fs_flist_proc(int msg, DIALOG *d, int c)
 	    *allegro_errno = ENOMEM;
 	    return D_CLOSE; 
 	 }
-	 flist->capacity = FLIST_START_CAPACITY;
-	 flist->name = malloc(flist->capacity * sizeof(char *));
-	 if (!flist->name) {
-	    *allegro_errno = ENOMEM;
-	    return D_CLOSE;
-         }
       }
       else {
-	 for (i=0; i<flist->size; i++) {
-	    if (flist->name[i]) {
+	 for (i=0; i<flist->size; i++)
+	    if (flist->name[i])
 	       free(flist->name[i]);
-	       /* PH add: maybe avoid multiple frees */
-	       flist->name[i] = NULL;
-	    }
-	 }
-	 /* Maybe shrink the structure */
-	 if (flist->capacity > FLIST_UPPER_CAPACITY) {
-	    flist->capacity = FLIST_UPPER_CAPACITY;
-	    flist->name = _al_sane_realloc(flist->name, sizeof(char *) * flist->capacity);
-	    if (!flist) {
-	       /* Oops! Should never happen, I hope */
-	       *allegro_errno = ENOMEM;
-	       return D_CLOSE;
-	    }
-	 }
       }
 
       flist->size = 0;
 
       replace_filename(flist->dir, s, uconvert_ascii("*.*", tmp), sizeof(flist->dir));
 
-      /* The semantics of the attributes passed to file_select_ex() is
-       * different from that of for_each_file_ex() in one case: when
-       * the 'd' attribute is not mentioned in the set of characters,
-       * the other attributes are not taken into account for directories,
-       * i.e the directories are all included. So we can't filter with
-       * for_each_file_ex() in that case.
-       */
-      if (attrb_state[ATTRB_DIREC] == ATTRB_ABSENT)
-	 for_each_file_ex(flist->dir, 0 /* accept all dirs */, FA_LABEL, fs_flist_putter, (void *)1UL /* check */);
-      else
-	 for_each_file_ex(flist->dir, build_attrb_flag(ATTRB_SET), build_attrb_flag(ATTRB_UNSET) | FA_LABEL, fs_flist_putter, (void *)0UL /* don't check */);
+      for_each_file(flist->dir, FA_RDONLY | FA_DIREC | FA_ARCH | FA_HIDDEN | FA_SYSTEM, fs_flist_putter, 0);
+
+      if (*allegro_errno)
+	 alert(NULL, get_config_text("Disk error"), NULL, get_config_text("OK"), NULL, 13, 0);
 
       usetc(get_filename(flist->dir), 0);
       d->d1 = d->d2 = 0;
@@ -592,7 +585,6 @@ static int fs_flist_proc(int msg, DIALOG *d, int c)
 	 for (i=0; i<flist->size; i++)
 	    if (flist->name[i])
 	       free(flist->name[i]);
-	 free(flist->name);
 	 free(flist);
 	 flist = NULL;
       }
@@ -624,8 +616,10 @@ static int fs_flist_proc(int msg, DIALOG *d, int c)
       else {
 	 usetc(updir, 0);
       }
+      scare_mouse();
       object_message(file_selector+FS_EDIT, MSG_START, 0);
       object_message(file_selector+FS_EDIT, MSG_DRAW, 0);
+      unscare_mouse();
 
       if (ret == D_CLOSE)
 	 return object_message(file_selector+FS_EDIT, MSG_KEY, 0);
@@ -636,89 +630,6 @@ static int fs_flist_proc(int msg, DIALOG *d, int c)
 
 
 
-/* parse_extension_string:
- *  Parses the extension string, possibly containing attribute characters.
- */
-static void parse_extension_string(AL_CONST char *ext)
-{
-   attrb_state_t state;
-   char ext_tokens[32], attrb_char[32];
-   char *last, *p, *attrb_p;
-   int c, c2, i;
-
-   fext = ustrdup(ext);
-   if (!fext)
-      return;
-
-   /* Tokenize the extension string and record the pointers to the
-    * beginning of each token in a dynamically growing array.
-    * ???? We rely on the implementation of ustrtok_r() which writes
-    * null characters in the string to delimit the tokens. Yuck.
-    */
-   c = usetc(ext_tokens, ' ');
-   c += usetc(ext_tokens+c, ',');
-   c += usetc(ext_tokens+c, ';');
-   usetc(ext_tokens+c, 0);
-
-   p = ustrtok_r(fext, ext_tokens, &last);
-   if (!ugetc(p))
-      return;
-
-   i = 0;
-   fext_size = 0;
-   fext_p = NULL;
-   attrb_p = NULL;
-
-   do {
-      /* Set of attribute characters. */
-      if (ugetc(p) == '/') {
-	 attrb_p = p + ucwidth('/');
-	 continue;
-      }
-
-      /* Dynamically grow the array if needed. */
-      if (i >= fext_size) {
-	 fext_size = (fext_size ? fext_size*2 : 2);
-	 fext_p = (char **)_al_sane_realloc(fext_p, fext_size * sizeof(char *));
-      }
-
-      /* Record a pointer to the beginning of the token. */
-      fext_p[i++] = p;
-
-   } while ((p = ustrtok_r(NULL, ext_tokens, &last)));
-
-   /* This is the meaningful size now. */
-   fext_size = i;
-
-   if (attrb_p) {
-      state = ATTRB_SET;
-      c = usetc(attrb_char, 'r');
-      c += usetc(attrb_char+c, 'h');
-      c += usetc(attrb_char+c, 's');
-      c += usetc(attrb_char+c, 'd');
-      c += usetc(attrb_char+c, 'a');
-      c += usetc(attrb_char+c, '+');
-      c += usetc(attrb_char+c, '-');
-      usetc(attrb_char+c, 0);
-
-      /* Scan the string. */
-      while ((c = utolower(ugetx(&attrb_p)))) {
-	 p = attrb_char;
-	 for (i = 0; (c2 = ugetx(&p)); i++) {
-	    if (c == c2) {
-	       if (i < ATTRB_MAX)
-		  attrb_state[i] = state;
-	       else
-		  state = (i == ATTRB_MAX) ? ATTRB_SET : ATTRB_UNSET;
-	       break;
-	    }
-	 }
-      }
-   }
-}    
-
-
-     
 /* stretch_dialog:
  *  Stretch the dialog horizontally and vertically to the specified
  *   size and the font in use.
@@ -741,8 +652,8 @@ static void stretch_dialog(DIALOG *d, int width, int height)
     
       d[FS_FRAME].w   = width;
       d[FS_FRAME].x   = 0;
-      d[FS_MESSAGE].w = width - 2;
-      d[FS_MESSAGE].x = 1;
+      d[FS_MESSAGE].w = 1;
+      d[FS_MESSAGE].x = width/2;
       d[FS_EDIT].w    = d[FS_FRAME].w - 2*hpad - 1;
       d[FS_EDIT].x    = hpad;
       d[FS_CANCEL].w  = 10*font_w + 1;
@@ -791,8 +702,8 @@ static void stretch_dialog(DIALOG *d, int width, int height)
     
       d[FS_FRAME].w   = width;
       d[FS_FRAME].x   = 0;
-      d[FS_MESSAGE].w = width - 2;
-      d[FS_MESSAGE].x = 1;
+      d[FS_MESSAGE].w = 1;
+      d[FS_MESSAGE].x = width/2;
       d[FS_EDIT].w    = d[FS_FRAME].w - 2*hpad - 1;
       d[FS_EDIT].x    = hpad;
       d[FS_FILES].w   = d[FS_FRAME].w - 2*hpad;
@@ -841,16 +752,9 @@ static void stretch_dialog(DIALOG *d, int width, int height)
  */
 int file_select_ex(AL_CONST char *message, char *path, AL_CONST char *ext, int size, int width, int height)
 {
-   static attrb_state_t default_attrb_state[ATTRB_MAX] = DEFAULT_ATTRB_STATE;
    int ret;
-   char *p, *backup;
+   char *p;
    char tmp[32];
-   ASSERT(message);
-   ASSERT(path);
-
-   backup = ustrdup(path);
-   if (!backup)
-      return FALSE;
 
    if (width == OLD_FILESEL_WIDTH)
       width = 305;
@@ -876,13 +780,7 @@ int file_select_ex(AL_CONST char *message, char *path, AL_CONST char *ext, int s
    file_selector[FS_EDIT].dp = path;
    file_selector[FS_OK].dp = (void*)get_config_text("OK");
    file_selector[FS_CANCEL].dp = (void*)get_config_text("Cancel");
-
-   /* Set default attributes. */
-   memcpy(attrb_state, default_attrb_state, sizeof(default_attrb_state));
-
-   /* Parse extension string. */
-   if (ext && ugetc(ext))
-      parse_extension_string(ext);
+   fext = ext;
 
    if (!ugetc(path)) {
 
@@ -912,35 +810,28 @@ int file_select_ex(AL_CONST char *message, char *path, AL_CONST char *ext, int s
    set_dialog_color(file_selector, gui_fg_color, gui_bg_color);
    ret = popup_dialog(file_selector, FS_EDIT);
 
-   if (fext) {
-      free(fext);
-      fext = NULL;
-   }
-
-   if (fext_p) {
-      free(fext_p);
-      fext_p = NULL;
-   }
-
-   if (ret == FS_CANCEL) {
-      ustrcpy(path, backup);
-      free(backup);
+   if ((ret == FS_CANCEL) || (!ugetc(get_filename(path))))
       return FALSE;
-   }
 
-   free(backup);
-
-   if (ugetc(get_filename(path))) {
-      p = get_extension(path);
-      if ((!ugetc(p)) && (ext) && (ugetc(ext)) && (!ustrpbrk(ext, uconvert_ascii(" ,;", tmp)))) {
-         size -= ((long)p - (long)path + ucwidth('.'));
-         if (size >= uwidth_max(U_CURRENT) + ucwidth(0)) {  /* do not end with '.' */
-            p += usetc(p, '.');
-            ustrzcpy(p, size, ext);
-         }
+   p = get_extension(path);
+   if ((!ugetc(p)) && (ext) && (!ustrpbrk(ext, uconvert_ascii(" ,;", tmp)))) {
+      size -= ((long)p - (long)path + ucwidth('.'));
+      if (size >= uwidth_max(U_CURRENT) + ucwidth(0)) {  /* do not end with '.' */
+         p += usetc(p, '.');
+         ustrzcpy(p, size, ext);
       }
    }
 
-   return TRUE;
+   return TRUE; 
+}
+
+
+
+/* file_select:
+ *  The good old file selector.
+ */
+int file_select(AL_CONST char *message, char *path, AL_CONST char *ext)
+{
+   return file_select_ex(message, path, ext, 1024, OLD_FILESEL_WIDTH, OLD_FILESEL_HEIGHT);
 }
 
