@@ -16,8 +16,6 @@
  *
  *      Bresenham arc routine by Romano Signorelli.
  *
- *      Cohen-Sutherland line clipping by Jon Rafkind.
- *
  *      See readme.txt for copyright information.
  */
 
@@ -146,7 +144,7 @@ void xor_mode(int on)
 /* solid_mode:
  *  Shortcut function for selecting solid drawing mode.
  */
-void solid_mode(void)
+void solid_mode()
 {
    drawing_mode(DRAW_MODE_SOLID, NULL, 0, 0);
 }
@@ -166,7 +164,7 @@ void clear_bitmap(BITMAP *bitmap)
 /* vsync:
  *  Waits for a retrace.
  */
-void vsync(void)
+void vsync()
 {
    ASSERT(gfx_driver);
 
@@ -181,7 +179,6 @@ void vsync(void)
  */
 void set_color(int index, AL_CONST RGB *p)
 {
-   ASSERT(index >= 0 && index < PAL_SIZE);
    set_palette_range((struct RGB *)p-index, index, index, FALSE);
 }
 
@@ -204,9 +201,6 @@ void set_palette_range(AL_CONST PALETTE p, int from, int to, int vsync)
 {
    int c;
 
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE)
-
    for (c=from; c<=to; c++) {
       _current_palette[c] = p[c];
 
@@ -229,7 +223,7 @@ void set_palette_range(AL_CONST PALETTE p, int from, int to, int vsync)
 /* previous palette, so the image loaders can restore it when they are done */
 int _got_prev_current_palette = FALSE;
 PALETTE _prev_current_palette;
-static int prev_palette_color[PAL_SIZE];
+static int prev_palette_color[256];
 
 
 
@@ -243,20 +237,20 @@ void select_palette(AL_CONST PALETTE p)
 {
    int c;
 
-   for (c=0; c<PAL_SIZE; c++) {
+   for (c=0; c<256; c++) {
       _prev_current_palette[c] = _current_palette[c];
-      _current_palette[c] = p[c];
-   }
-
-   if (_color_depth != 8) {
-      for (c=0; c<PAL_SIZE; c++) {
-	 prev_palette_color[c] = palette_color[c];
-	 palette_color[c] = makecol(_rgb_scale_6[p[c].r], _rgb_scale_6[p[c].g], _rgb_scale_6[p[c].b]);
-      }
+      prev_palette_color[c] = palette_color[c];
    }
 
    _got_prev_current_palette = TRUE;
 
+   for (c=0; c<256; c++) {
+      _current_palette[c] = p[c];
+
+      if (_color_depth != 8)
+	 palette_color[c] = makecol(_rgb_scale_6[p[c].r], _rgb_scale_6[p[c].g], _rgb_scale_6[p[c].b]);
+   }
+
    _current_palette_changed = 0xFFFFFFFF & ~(1<<(_color_depth-1));
 }
 
@@ -265,19 +259,17 @@ void select_palette(AL_CONST PALETTE p)
 /* unselect_palette:
  *  Restores palette settings from before the last call to select_palette().
  */
-void unselect_palette(void)
+void unselect_palette()
 {
    int c;
 
-   for (c=0; c<PAL_SIZE; c++)
+   for (c=0; c<256; c++) {
       _current_palette[c] = _prev_current_palette[c];
 
-   if (_color_depth != 8) {
-      for (c=0; c<PAL_SIZE; c++)
+      if (_color_depth != 8)
 	 palette_color[c] = prev_palette_color[c];
    }
 
-   ASSERT(_got_prev_current_palette == TRUE);
    _got_prev_current_palette = FALSE;
 
    _current_palette_changed = 0xFFFFFFFF & ~(1<<(_color_depth-1));
@@ -302,7 +294,7 @@ static int *palette_expansion_table(int bpp)
    }
 
    if (_current_palette_changed & (1<<(bpp-1))) {
-      for (c=0; c<PAL_SIZE; c++) {
+      for (c=0; c<256; c++) {
 	 table[c] = makecol_depth(bpp,
 				  _rgb_scale_6[_current_palette[c].r], 
 				  _rgb_scale_6[_current_palette[c].g], 
@@ -330,7 +322,7 @@ void generate_332_palette(PALETTE pal)
 {
    int c;
 
-   for (c=0; c<PAL_SIZE; c++) {
+   for (c=0; c<256; c++) {
       pal[c].r = ((c>>5)&7) * 63/7;
       pal[c].g = ((c>>2)&7) * 63/7;
       pal[c].b = (c&3) * 63/3;
@@ -350,8 +342,6 @@ void generate_332_palette(PALETTE pal)
  */
 void get_color(int index, RGB *p)
 {
-   ASSERT(index >= 0 && index < PAL_SIZE);
-   ASSERT(p);
    get_palette_range(p-index, index, index);
 }
 
@@ -374,9 +364,6 @@ void get_palette_range(PALETTE p, int from, int to)
 {
    int c;
 
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE);
-
    if ((system_driver) && (system_driver->read_hardware_palette))
       system_driver->read_hardware_palette();
 
@@ -396,10 +383,6 @@ void fade_interpolate(AL_CONST PALETTE source, AL_CONST PALETTE dest, PALETTE ou
 {
    int c;
 
-   ASSERT(pos >= 0 && pos <= 64);
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE);
-
    for (c=from; c<=to; c++) { 
       output[c].r = ((int)source[c].r * (63-pos) + (int)dest[c].r * pos) / 64;
       output[c].g = ((int)source[c].g * (63-pos) + (int)dest[c].g * pos) / 64;
@@ -419,10 +402,6 @@ void fade_from_range(AL_CONST PALETTE source, AL_CONST PALETTE dest, int speed,
    PALETTE temp;
    int c, start, last;
 
-   ASSERT(speed > 0 && speed <= 64);
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE);
-
    for (c=0; c<PAL_SIZE; c++)
       temp[c] = source[c];
 
@@ -458,9 +437,6 @@ void fade_from_range(AL_CONST PALETTE source, AL_CONST PALETTE dest, int speed,
  */
 void fade_in_range(AL_CONST PALETTE p, int speed, int from, int to)
 {
-   ASSERT(speed > 0 && speed <= 64);
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE);
    fade_from_range(black_palette, p, speed, from, to);
 }
 
@@ -475,9 +451,6 @@ void fade_in_range(AL_CONST PALETTE p, int speed, int from, int to)
 void fade_out_range(int speed, int from, int to)
 {
    PALETTE temp;
-   ASSERT(speed > 0 && speed <= 64);
-   ASSERT(from >= 0 && from < PAL_SIZE);
-   ASSERT(to >= 0 && to < PAL_SIZE);
 
    get_palette(temp);
    fade_from_range(temp, black_palette, speed, from, to);
@@ -491,7 +464,6 @@ void fade_out_range(int speed, int from, int to)
  */
 void fade_from(AL_CONST PALETTE source, AL_CONST PALETTE dest, int speed)
 {
-   ASSERT(speed > 0 && speed <= 64);
    fade_from_range(source, dest, speed, 0, PAL_SIZE-1);
 }
 
@@ -503,7 +475,6 @@ void fade_from(AL_CONST PALETTE source, AL_CONST PALETTE dest, int speed)
  */
 void fade_in(AL_CONST PALETTE p, int speed)
 {
-   ASSERT(speed > 0 && speed <= 64);
    fade_in_range(p, speed, 0, PAL_SIZE-1);
 }
 
@@ -515,7 +486,6 @@ void fade_in(AL_CONST PALETTE p, int speed)
  */
 void fade_out(int speed)
 {
-   ASSERT(speed > 0 && speed <= 64);
    fade_out_range(speed, 0, PAL_SIZE-1);
 }
 
@@ -524,7 +494,7 @@ void fade_out(int speed)
 /* rect:
  *  Draws an outline rectangle.
  */
-void _soft_rect(BITMAP *bmp, int x1, int y1, int x2, int y2, int color)
+void rect(BITMAP *bmp, int x1, int y1, int x2, int y2, int color)
 {
    int t;
 
@@ -650,13 +620,13 @@ void do_line(BITMAP *bmp, int x1, int y1, int x2, int y2, int d, void (*proc)(BI
 	 proc(bmp, x, y, d);                                                 \
 									     \
 	 if (dd sec_cond 0) {                                                \
-	    sec_c = sec_c sec_sign 1;                                        \
+	    sec_c sec_sign##= 1;                                             \
 	    dd += i2;                                                        \
 	 }                                                                   \
 	 else                                                                \
 	    dd += i1;                                                        \
 									     \
-	 pri_c = pri_c pri_sign 1;                                           \
+	 pri_c pri_sign##= 1;                                                \
       }                                                                      \
    }
 
@@ -704,8 +674,6 @@ void do_line(BITMAP *bmp, int x1, int y1, int x2, int y2, int d, void (*proc)(BI
 	 }
       }
    }
-
-   #undef DO_LINE
 }
 
 
@@ -768,137 +736,6 @@ void _normal_line(BITMAP *bmp, int x1, int y1, int x2, int y2, int color)
 
 
 
-/* _fast_line:
- *  Draws a line from x1, y1 to x2, y2, using putpixel() to do the work.
- *  This is an implementation of the Cohen-Sutherland line clipping algorithm.
- *  Loops over the line until it can be either trivially rejected or trivially
- *  accepted. If it is neither rejected nor accepted, subdivide it into two
- *  segments, one of which can be rejected.
- */
-void _fast_line(BITMAP *bmp, int x1, int y1, int x2, int y2, int color)
-{
-   int code0, code1;
-   int outcode;
-   int x, y;
-   int xmax, xmin, ymax, ymin;
-   int done = 0, accept = 0;
-   int clip_orig;
-   ASSERT(bmp);
-
-   if ((clip_orig = bmp->clip) != 0) {  /* save clipping state */
-      #define TOP     0x8
-      #define BOTTOM  0x4
-      #define LEFT    0x2
-      #define RIGHT   0x1
-
-      #define COMPCLIP(code, x, y)  \
-      {                             \
-	 code = 0;                  \
-	 if (y < ymin)              \
-	    code |= TOP;            \
-	 else if (y > ymax)         \
-	    code |= BOTTOM;         \
-	 if (x < xmin)              \
-	    code |= LEFT;           \
-	 else if (x > xmax)         \
-	    code |= RIGHT;          \
-      }
-
-      xmin = bmp->cl;
-      xmax = bmp->cr-1;
-      ymin = bmp->ct;
-      ymax = bmp->cb-1;
-
-      COMPCLIP(code0, x1, y1);
-      COMPCLIP(code1, x2, y2);
-
-      do {
-
-	 if (!(code0 | code1)) {
-	    /* Trivially accept. */
-	    accept = done = 1;
-	 }
-	 else if (code0 & code1) {
-	    /* Trivially reject. */
-	    done = 1;
-	 }
-	 else {
-	    /* Didn't reject or accept, so do some calculations. */
-	    outcode = code0 ? code0 : code1;  /* pick one endpoint */
-
-	    if (outcode & TOP) {
-	       if (y2 == y1)
-		  x = x1;
-	       else
-		  x = x1 + (x2 - x1) * (ymin - y1) / (y2 - y1);
-	       y = ymin;
-	    }
-	    else if (outcode & BOTTOM) {
-	       if (y2 == y1)
-		  x = x1;
-	       else
-		  x = x1 + (x2 - x1) * (ymax - y1) / (y2 - y1);
-	       y = ymax;
-	    }
-	    else if (outcode & LEFT) {
-	       if (x2 == x1)
-		  y = y1;
-	       else
-		  y = y1 + (y2 - y1) * (xmin - x1) / (x2 - x1);
-	       x = xmin;
-	    }
-	    else {  /* outcode & RIGHT */
-	       if (x2 == x1)
-		  y = y1;
-	       else
-		  y = y1 + (y2 - y1) * (xmax - x1) / (x2 - x1);
-	       x = xmax;
-	    }
-
-	    if (outcode == code0) {
-	       x1 = x;
-	       y1 = y;
-	       COMPCLIP(code0, x1, y1);
-	    }
-	    else {
-	       x2 = x;
-	       y2 = y;
-	       COMPCLIP(code1, x2, y2);
-	    }
-	 }
-      } while (!done);
-
-      #undef COMPCLIP
-      #undef TOP
-      #undef BOTTOM
-      #undef LEFT
-      #undef RIGHT
-
-      if (!accept)
-	 return;
-
-      /* We have already done the clipping, no need to do it again. */
-      bmp->clip = FALSE;
-   }
-
-   if (x1 == x2) {
-      bmp->vtable->vline(bmp, x1, y1, y2, color);
-   }
-   else if (y1 == y2) {
-      bmp->vtable->hline(bmp, x1, y1, x2, color);
-   }
-   else {
-      acquire_bitmap(bmp);
-      do_line(bmp, x1, y1, x2, y2, color, bmp->vtable->putpixel);
-      release_bitmap(bmp);
-   }
-
-   /* Restore original clipping state. */
-   bmp->clip = clip_orig;
-}
-
-
-
 /* do_circle:
  *  Helper function for the circle drawing routines. Calculates the points
  *  in a circle of radius r around point x, y, and calls the specified 
@@ -961,10 +798,9 @@ void do_circle(BITMAP *bmp, int x, int y, int radius, int d, void (*proc)(BITMAP
 /* circle:
  *  Draws a circle.
  */
-void _soft_circle(BITMAP *bmp, int x, int y, int radius, int color)
+void circle(BITMAP *bmp, int x, int y, int radius, int color)
 {
    int clip, sx, sy, dx, dy;
-   ASSERT(bmp);
 
    if (bmp->clip) {
       sx = x-radius-1;
@@ -997,7 +833,7 @@ void _soft_circle(BITMAP *bmp, int x, int y, int radius, int color)
 /* circlefill:
  *  Draws a filled circle.
  */
-void _soft_circlefill(BITMAP *bmp, int x, int y, int radius, int color)
+void circlefill(BITMAP *bmp, int x, int y, int radius, int color)
 {
    int cx = 0;
    int cy = radius;
@@ -1005,7 +841,6 @@ void _soft_circlefill(BITMAP *bmp, int x, int y, int radius, int color)
    int d_e = 3;
    int d_se = -2 * radius + 5;
    int clip, sx, sy, dx, dy;
-   ASSERT(bmp);
 
    if (bmp->clip) {
       sx = x-radius-1;
@@ -1174,10 +1009,9 @@ void do_ellipse(BITMAP *bmp, int x, int y, int rx, int ry, int d, void (*proc)(B
 /* ellipse:
  *  Draws an ellipse.
  */
-void _soft_ellipse(BITMAP *bmp, int x, int y, int rx, int ry, int color)
+void ellipse(BITMAP *bmp, int x, int y, int rx, int ry, int color)
 {
    int clip, sx, sy, dx, dy;
-   ASSERT(bmp);
 
    if (bmp->clip) {
       sx = x-rx-1;
@@ -1210,14 +1044,13 @@ void _soft_ellipse(BITMAP *bmp, int x, int y, int rx, int ry, int color)
 /* ellipsefill:
  *  Draws a filled ellipse.
  */
-void _soft_ellipsefill(BITMAP *bmp, int x, int y, int rx, int ry, int color)
+void ellipsefill(BITMAP *bmp, int x, int y, int rx, int ry, int color)
 {
    int ix, iy;
    int a, b, c, d;
    int da, db, dc, dd;
    int na, nb, nc, nd;
    int clip, sx, sy, dx, dy;
-   ASSERT(bmp);
 
    if (bmp->clip) {
       sx = x-rx-1;
@@ -1537,9 +1370,8 @@ void do_arc(BITMAP *bmp, int x, int y, fixed ang1, fixed ang2, int r, int d, voi
 /* arc:
  *  Draws an arc.
  */
-void _soft_arc(BITMAP *bmp, int x, int y, fixed ang1, fixed ang2, int r, int color)
+void arc(BITMAP *bmp, int x, int y, fixed ang1, fixed ang2, int r, int color)
 {
-   ASSERT(bmp);
    acquire_bitmap(bmp);
 
    do_arc(bmp, x, y, ang1, ang2, r, color, bmp->vtable->putpixel);
