@@ -70,19 +70,19 @@ int _blender_col_32 = 0;
 
 int _blender_alpha = 0;                /* for truecolor translucent drawing */
 
-int _rgb_r_shift_15 = 0;               /* truecolor pixel format */
-int _rgb_g_shift_15 = 5;
-int _rgb_b_shift_15 = 10;
-int _rgb_r_shift_16 = 0;
-int _rgb_g_shift_16 = 5;
-int _rgb_b_shift_16 = 11;
-int _rgb_r_shift_24 = 0;
-int _rgb_g_shift_24 = 8;
-int _rgb_b_shift_24 = 16;
-int _rgb_r_shift_32 = 0;
-int _rgb_g_shift_32 = 8;
-int _rgb_b_shift_32 = 16;
-int _rgb_a_shift_32 = 24;
+int _rgb_r_shift_15 = DEFAULT_RGB_R_SHIFT_15;     /* truecolor pixel format */
+int _rgb_g_shift_15 = DEFAULT_RGB_G_SHIFT_15;
+int _rgb_b_shift_15 = DEFAULT_RGB_B_SHIFT_15;
+int _rgb_r_shift_16 = DEFAULT_RGB_R_SHIFT_16;
+int _rgb_g_shift_16 = DEFAULT_RGB_G_SHIFT_16;
+int _rgb_b_shift_16 = DEFAULT_RGB_B_SHIFT_16;
+int _rgb_r_shift_24 = DEFAULT_RGB_R_SHIFT_24;
+int _rgb_g_shift_24 = DEFAULT_RGB_G_SHIFT_24;
+int _rgb_b_shift_24 = DEFAULT_RGB_B_SHIFT_24;
+int _rgb_r_shift_32 = DEFAULT_RGB_R_SHIFT_32;
+int _rgb_g_shift_32 = DEFAULT_RGB_G_SHIFT_32;
+int _rgb_b_shift_32 = DEFAULT_RGB_B_SHIFT_32;
+int _rgb_a_shift_32 = DEFAULT_RGB_A_SHIFT_32;
 
 
 /* lookup table for scaling 5 bit colors up to 8 bits */
@@ -490,7 +490,7 @@ static int get_config_gfx_driver(char *gfx_card, int check_mode, int require_win
 int set_gfx_mode(int card, int w, int h, int v_w, int v_h)
 {
    static int allow_config = TRUE;
-   extern void blit_end();
+   extern void blit_end(void);
    _DRIVER_INFO *driver_list;
    int tried = FALSE;
    char buf[ALLEGRO_ERROR_SIZE], tmp[64];
@@ -577,6 +577,12 @@ int set_gfx_mode(int card, int w, int h, int v_w, int v_h)
       gfx_capabilities = 0;
    }
 
+   /* We probably don't want to do this because it makes
+    * Allegro "forget" the color layout of previously set
+    * graphics modes. But it should be retained if bitmaps
+    * created in those modes are to be used in the new mode.
+    */
+#if 0
    /* restore default truecolor pixel format */
    _rgb_r_shift_15 = 0; 
    _rgb_g_shift_15 = 5;
@@ -591,6 +597,7 @@ int set_gfx_mode(int card, int w, int h, int v_w, int v_h)
    _rgb_g_shift_32 = 8;
    _rgb_b_shift_32 = 16;
    _rgb_a_shift_32 = 24;
+#endif
 
    gfx_capabilities = 0;
 
@@ -681,6 +688,9 @@ int set_gfx_mode(int card, int w, int h, int v_w, int v_h)
 	 gfx_capabilities |= GFX_CAN_TRIPLE_BUFFER;
    }
 
+   clear_bitmap(screen);
+
+   /* set up the default colors */
    for (c=0; c<256; c++)
       _palette_color8[c] = c;
 
@@ -697,8 +707,6 @@ int set_gfx_mode(int card, int w, int h, int v_w, int v_h)
       gui_bg_color = makecol(255, 255, 255);
    }
 
-   clear_bitmap(screen);
-
    if (_al_linker_mouse)
       _al_linker_mouse->set_mouse_etc();
 
@@ -898,6 +906,8 @@ BITMAP *create_sub_bitmap(BITMAP *parent, int x, int y, int width, int height)
    BITMAP *bitmap;
    int i;
 
+   ASSERT((width > 0) && (height > 0));
+
    if (!parent) 
       return NULL;
 
