@@ -589,7 +589,7 @@ int d_icon_proc(int msg, DIALOG *d, int c)
  */
 int d_keyboard_proc(int msg, DIALOG *d, int c)
 {
-   int (*proc)();
+   int (*proc)(void);
    int ret = D_O_K;
 
    switch (msg) {
@@ -1323,17 +1323,17 @@ int d_text_list_proc(int msg, DIALOG *d, int c)
 		  thisitem = (*(getfuncptr)d->dp)(i, NULL);
 		  failure = FALSE;
 
-		  if ((int)d->dp3 < ustrlen(thisitem)) {
-		     for (a=0; a<(int)d->dp3; a++) {
+		  if ((int)((unsigned long)d->dp3) < ustrlen(thisitem)) {
+		     for (a=0; a < (int)((unsigned long)d->dp3); a++) {
 			if (utolower(ugetat(thisitem, a)) != utolower(ugetat(selected, a))) {
 			   failure = TRUE;
 			   break;
 			}
 		     }
 
-		     if ((!failure) && (utolower(ugetat(thisitem, (int)d->dp3)) == utolower(c))) {
+		     if ((!failure) && (utolower(ugetat(thisitem, (int)(unsigned long)d->dp3)) == utolower(c))) {
 			d->d1 = i;
-			d->dp3 = (void *)((int)d->dp3 + 1);
+			d->dp3 = (void *)((unsigned long)d->dp3 + 1);
 
 			if (sel) {
 			   for (i=0; i<listsize; i++)
