@@ -26,10 +26,6 @@
 #include "allegro/internal/aintern.h"
 #include "opcodes.h"
 
-#ifdef ALLEGRO_WINDOWS
-   #include "winalleg.h"   /* For VirtualProtect */
-#endif     /* ifdef ALLEGRO_WINDOWS */
-
 
 
 /* helper macro for generating stretchers in each color depth */
@@ -276,9 +272,6 @@ static void free_stretchers(void)
  */
 static void do_stretch_blit(BITMAP *source, BITMAP *dest, int source_x, int source_y, int source_width, int source_height, int dest_x, int dest_y, int dest_width, int dest_height, int masked)
 {
- #ifdef ALLEGRO_WINDOWS
-   DWORD old_protect;
- #endif     /* ifdef ALLEGRO_WINDOWS */
    fixed sx, sy, sxd, syd;
    void *prev_scratch_mem;
    int prev_scratch_mem_size;
@@ -287,12 +280,6 @@ static void do_stretch_blit(BITMAP *source, BITMAP *dest, int source_x, int sour
    char flags;
    int i;
 
-   /* vtable hook */   
-   if (source->vtable->do_stretch_blit) {
-      source->vtable->do_stretch_blit(source, dest, source_x, source_y, source_width, source_height, dest_x, dest_y, dest_width, dest_height, masked);
-      return;
-   }
-
    /* trivial reject for zero sizes */
    if ((source_width <= 0) || (source_height <= 0) || 
        (dest_width <= 0) || (dest_height <= 0))
@@ -381,7 +368,7 @@ static void do_stretch_blit(BITMAP *source, BITMAP *dest, int source_x, int sour
    /* make sure all allocated memory is freed atexit */
    if (stretcher_virgin) {
       stretcher_virgin = FALSE;
-      _add_exit_func(free_stretchers, "free_stretchers");
+      _add_exit_func(free_stretchers);
    }
 
    prev_scratch_mem = _scratch_mem;
@@ -395,7 +382,7 @@ static void do_stretch_blit(BITMAP *source, BITMAP *dest, int source_x, int sour
       compiler_pos = make_stretcher(0, sx, sxd, dest_width, masked, dest->vtable->color_depth);
    }
 
- #ifdef GFX_HAS_VGA
+ #ifdef GFX_MODEX
 
    else { 
       int plane, d;
@@ -428,15 +415,10 @@ static void do_stretch_blit(BITMAP *source, BITMAP *dest, int source_x, int sour
       dest_x >>= 2;
    }
 
- #endif     /* ifdef GFX_HAS_VGA */
+ #endif     /* ifdef GFX_MODEX */
 
    COMPILER_RET();
 
- #ifdef ALLEGRO_WINDOWS
-   /* Play nice with Windows executable memory protection */
-   VirtualProtect(_scratch_mem, _scratch_mem_size, PAGE_EXECUTE_READWRITE, &old_protect);
- #endif     /* ifdef ALLEGRO_WINDOWS */
-
    /* call the stretcher */
    _do_stretch(source, dest, _scratch_mem, sx>>16, sy, syd, 
 	       dest_x, dest_y, dest_height, dest->vtable->color_depth);
@@ -484,3 +466,4 @@ void stretch_sprite(BITMAP *bmp, BITMAP *sprite, int x, int y, int w, int h)
 {
    do_stretch_blit(sprite, bmp, 0, 0, sprite->w, sprite->h, x, y, w, h, 1); 
 }
+
