@@ -48,14 +48,6 @@
 #define FB_VBLANK_STICKY 0
 #endif
 
-
-
-#define PREFIX_I                "al-fbcon INFO: "
-#define PREFIX_W                "al-fbcon WARNING: "
-#define PREFIX_E                "al-fbcon ERROR: "
-
-
-
 static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth);
 static int fb_open_device(void);
 static void fb_exit(BITMAP *b);
@@ -87,7 +79,6 @@ GFX_DRIVER gfx_fbcon =
    NULL,                         /* no drawing mode hook */
    fb_save,
    fb_restore,
-   NULL,    // AL_METHOD(void, set_blender_mode, (int mode, int r, int g, int b, int a));
    NULL,                         /* no fetch mode hook */
    0, 0,
    TRUE,
@@ -141,15 +132,12 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
    if (((!w) && (!h)) || _safe_gfx_mode_change) {
       w = orig_mode.xres;
       h = orig_mode.yres;
-      TRACE(PREFIX_I "User didn't ask for a resolution, and we are trying "
-	    "to set a safe mode, so I will try resolution %dx%d\n", w, h);
    }
 
    if (_safe_gfx_mode_change) tries = -1;
    else tries = 0;
    
    for (; tries<3; tries++) {
-      TRACE(PREFIX_I "...try number %d...\n", tries);
       my_mode = orig_mode;
 
       switch (tries) {
@@ -258,15 +246,12 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
    }
 
    /* oops! */
-   if (_safe_gfx_mode_change) {
+   if (_safe_gfx_mode_change)
       set_color_depth(original_color_depth);
-      TRACE(PREFIX_I "Restoring color depth %d\n", original_color_depth);
-   }
       
    ioctl(fbfd, FBIOPUT_VSCREENINFO, &orig_mode);
    close(fbfd);
    ustrzcpy(allegro_error, ALLEGRO_ERROR_SIZE, get_config_text("Framebuffer resolution not available"));
-   TRACE(PREFIX_E "Resolution %dx%d not available...\n", w, h);
    return NULL;
 
    got_a_nice_mode:
@@ -277,8 +262,6 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
       ioctl(fbfd, FBIOPUT_VSCREENINFO, &orig_mode);
       close(fbfd);
       ustrzcpy(allegro_error, ALLEGRO_ERROR_SIZE, get_config_text("Can't map framebuffer"));
-      TRACE(PREFIX_E "Couldn't map framebuffer for %dx%d. Restored old "
-	    "resolution.\n", w, h);
       return NULL;
    }
 
@@ -288,7 +271,7 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
 
    gfx_fbcon.vid_mem = fix_info.smem_len;
 
-   stride = fix_info.line_length;
+   stride = my_mode.xres_virtual * BYTES_PER_PIXEL(color_depth);
    v_w = my_mode.xres_virtual;
    v_h = my_mode.yres_virtual;
    p = fbaddr;
@@ -306,7 +289,6 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
       ioctl(fbfd, FBIOPUT_VSCREENINFO, &orig_mode);
       munmap(fbaddr, fix_info.smem_len);
       close(fbfd);
-      TRACE(PREFIX_E "Couldn't make bitmap `b', sorry.\n");
       return NULL;
    }
 
@@ -402,7 +384,6 @@ static BITMAP *fb_init(int w, int h, int v_w, int v_h, int color_depth)
       memset(fbaddr, 0, gfx_fbcon.vid_mem);
 
    fb_save_cmap();    /* Maybe we should fill in our default palette too... */
-   TRACE(PREFIX_I "Got a bitmap %dx%dx%d\n", b->w, b->h, bitmap_color_depth(b));
    return b;
 }
 
@@ -426,16 +407,16 @@ static int fb_open_device(void)
       p = getenv("FRAMEBUFFER");
 
       if ((p) && (p[0])) {
-	 _al_sane_strncpy(fname, p, sizeof(fname));
+	 strncpy(fname, p, sizeof(fname)-1);
+	 fname[sizeof(fname)-1] = 0;
       }
       else
-	 _al_sane_strncpy(fname, "/dev/fb0", 1024);
+	 strcpy(fname, "/dev/fb0");
    }
 
    /* open the framebuffer device */
    if ((fbfd = open(fname, O_RDWR)) < 0) {
       uszprintf(allegro_error, ALLEGRO_ERROR_SIZE, get_config_text("Can't open framebuffer %s"), uconvert_ascii(fname, tmp1));
-      TRACE(PREFIX_E "Couldn't open %s\n", fname);
       return 1;
    }
 
@@ -443,11 +424,9 @@ static int fb_open_device(void)
    if ((ioctl(fbfd, FBIOGET_FSCREENINFO, &fix_info) != 0) ||
        (ioctl(fbfd, FBIOGET_VSCREENINFO, &orig_mode) != 0)) {
       ustrzcpy(allegro_error, ALLEGRO_ERROR_SIZE, get_config_text("Framebuffer ioctl() failed"));
-      TRACE(PREFIX_E "ioctl() failed\n");
       return 2;
    }
 
-   TRACE(PREFIX_I "fb device %s opened successfully.\n", fname);
    return 0;
 }
 
@@ -458,7 +437,6 @@ static int fb_open_device(void)
  */
 static void fb_exit(BITMAP *b)
 {
-   TRACE(PREFIX_I "Unsetting video mode.\n");
    ioctl(fbfd, FBIOPUT_VSCREENINFO, &orig_mode);
    fb_restore_cmap();
 
@@ -473,7 +451,7 @@ static void fb_exit(BITMAP *b)
 /* fb_save:
  *  Saves the graphics state.
  */
-static void fb_save(void)
+static void fb_save()
 {
    ioctl(fbfd, FBIOPUT_VSCREENINFO, &orig_mode);
 }
@@ -483,7 +461,7 @@ static void fb_save(void)
 /* fb_restore:
  *  Restores the graphics state.
  */
-static void fb_restore(void)
+static void fb_restore()
 {
    ioctl(fbfd, FBIOPUT_VSCREENINFO, &my_mode);
 
@@ -505,28 +483,12 @@ static int fb_scroll(int x, int y)
 
    ret = ioctl(fbfd, FBIOPAN_DISPLAY, &my_mode);
 
-   if (_wait_for_vsync) {
-      /* On a lot of graphics hardware the scroll registers don't
-       * take effect until the start of the next frame, so when you do a
-       * scroll you want to make sure you've waited at least until then.
-       * If you have reliable vsyncing, one call to vysnc is enough,
-       * but if you don't then the first call waits some time between 0
-       * and 1/60th of a second, and since it's not really synced to the
-       * retrace, this may or may not include an actual retrace. However,
-       * by making a second call, we then wait for a full 1/60th of a second
-       * after the first call, and this is sure to include a retrace,
-       * assuming the refresh rate is at least 60Hz. Sometimes overall
-       * we'll have waited past two retraces, or even more if the refresh
-       * rate is much higher than the fake vblank timer frequency, but
-       * it's still better than sometimes missing the retrace completely.
-       */
-      fb_vsync();
+   fb_vsync();
 
-    #ifdef FBIOGET_VBLANK
-      if (!vblank_flags)
-    #endif
-         fb_vsync();
-   }
+ #ifdef FBIOGET_VBLANK
+   if (!vblank_flags)
+ #endif
+      fb_vsync();
 
    return (ret) ? -1 : 0;
 }
@@ -600,7 +562,6 @@ static void fb_set_palette(AL_CONST RGB *p, int from, int to, int vsync)
    unsigned short r[256], g[256], b[256];
    struct fb_cmap cmap;
    int i;
-   ASSERT(p);
 
    cmap.start = from;
    cmap.len = to-from+1;
@@ -758,8 +719,8 @@ static char *get_line (FILE *file)
 {
    static char buffer[1024];
    char *ch;
-   ASSERT (file);
 
+   ASSERT (file);
    if (!fgets (buffer, sizeof (buffer), file))
       return 0;
 
@@ -937,7 +898,6 @@ static void set_default_timings (void)
 static int update_timings(struct fb_var_screeninfo *mode)
 {
    struct timings *t;
-   ASSERT(mode);
 
    set_default_timings();
    t = _fb_get_timings (mode->xres, mode->yres);
