@@ -22,20 +22,17 @@
 /* list the available drivers */
 _DRIVER_INFO _linux_gfx_driver_list[] =
 {
-#ifdef ALLEGRO_LINUX_FBCON
+#if (defined ALLEGRO_LINUX_FBCON) && (!defined ALLEGRO_WITH_MODULES)
    {  GFX_FBCON,    &gfx_fbcon,    TRUE  },
 #endif
 #ifdef ALLEGRO_LINUX_VBEAF
    {  GFX_VBEAF,    &gfx_vbeaf,    TRUE  },
 #endif
-#ifdef ALLEGRO_LINUX_VGA
+#if (defined ALLEGRO_LINUX_VGA) && (!defined ALLEGRO_WITH_MODULES)
    {  GFX_VGA,      &gfx_vga,      TRUE  },
    {  GFX_MODEX,    &gfx_modex,    TRUE  },
 #endif
-#ifdef ALLEGRO_LINUX_GGI
-   {  GFX_GGI,      &gfx_ggi,      FALSE },
-#endif
-#ifdef ALLEGRO_LINUX_SVGALIB
+#if (defined ALLEGRO_LINUX_SVGALIB) && (!defined ALLEGRO_WITH_MODULES)
    {  GFX_SVGALIB,  &gfx_svgalib,  FALSE },
 #endif
    {  0,            NULL,          0     }
