@@ -72,7 +72,6 @@ GFX_DRIVER gfx_svgalib =
    NULL,                         /* no drawing mode hook */
    svga_save,
    svga_restore,
-   NULL,                        /* AL_METHOD(void, set_blender_mode, (int mode, int r, int g, int b, int a)); */
    NULL,			 /* svga_fetch_mode_list disabled */
    0, 0,
    TRUE,
@@ -95,7 +94,8 @@ static int last_line;
 
 #ifdef ALLEGRO_MODULE
 
-int _module_has_registered_via_atexit = 0;
+/* If this is non-zero, this module won't be unloaded.  */
+int _module_dont_unload_me_dirty_hack = 0;
 
 #endif
 
@@ -106,9 +106,6 @@ int _module_has_registered_via_atexit = 0;
  */
 unsigned long _svgalib_read_line(BITMAP *bmp, int line)
 {
-   ASSERT(bmp);
-   ASSERT(line>=0 && line<bmp->h);
-
    return (unsigned long) (bmp->line[line]);
 }
 
@@ -119,11 +116,7 @@ unsigned long _svgalib_read_line(BITMAP *bmp, int line)
  */
 unsigned long _svgalib_write_line(BITMAP *bmp, int line)
 {
-   int new_line;
-   ASSERT(bmp);
-   ASSERT(line>=0 && line<bmp->h);
-
-   new_line = line + bmp->y_ofs;
+   int new_line = line + bmp->y_ofs;
    if ((new_line != last_line) && (last_line >= 0))
       vga_drawscansegment(screen_buffer + last_line * bytes_per_line, 0, last_line, bytes_per_line);
    last_line = new_line;
@@ -137,8 +130,6 @@ unsigned long _svgalib_write_line(BITMAP *bmp, int line)
  */
 void _svgalib_unwrite_line(BITMAP *bmp)
 {
-   ASSERT(bmp);
-
    if (last_line >= 0) {
       vga_drawscanline(last_line, screen_buffer + last_line * bytes_per_line);
       last_line = -1;
@@ -200,7 +191,7 @@ static int safe_vga_setmode(int num, int tio)
    /* A side-effect of vga_setmode() is that it will register an
     * atexit handler.  See umodules.c for this problem.
     */
-   _module_has_registered_via_atexit = 1;
+   _module_dont_unload_me_dirty_hack = 1;
 #endif
 
    tcsetattr(__al_linux_console_fd, TCSANOW, &termio);
@@ -235,8 +226,6 @@ static int get_depth(int ncolors, int bytesperpixel)
 static int mode_ok(vga_modeinfo *info, int w, int h, int v_w, int v_h, 
 		   int color_depth)
 {
-   ASSERT(info);
-
    return ((color_depth == get_depth(info->colors, info->bytesperpixel))
 	   && (((info->width == w) && (info->height == h))
 	       || ((w == 0) && (h == 0)))
@@ -537,8 +526,7 @@ static int svga_scroll(int x, int y)
     * the documentation says it should be there. -- PW  */
 
    /* wait for a retrace */
-   if (_wait_for_vsync)
-      vga_waitretrace();
+   vga_waitretrace();
 
    return 0;
 }
@@ -561,10 +549,6 @@ static void svga_vsync(void)
 static void svga_set_palette(AL_CONST RGB *p, int from, int to, int vsync)
 {
    int i;
-   ASSERT(p);
-   ASSERT(from>=0 && from<=255);
-   ASSERT(to>=0 && to<=255);
-   ASSERT(from<=to);
 
    if (vsync)
       vga_waitretrace();
