@@ -14,8 +14,6 @@
  *
  *      Pause and seek functions by George Foot.
  *
- *      get_midi_length by Elias Pschernig.
- *
  *      See readme.txt for copyright information.
  */
 
@@ -31,9 +29,6 @@
 /* maximum number of layers in a single voice */
 #define MIDI_LAYERS  4
 
-/* how often the midi callback gets called maximally / second */
-#define MIDI_TIMER_FREQUENCY 40
-
 
 typedef struct MIDI_TRACK                       /* a track in the MIDI file */
 {
@@ -81,9 +76,7 @@ typedef struct PATCH_TABLE                      /* GM -> external synth */
 } PATCH_TABLE;
 
 
-volatile long midi_pos = -1;                    /* current position in MIDI file */
-volatile long midi_time = 0;                    /* current position in seconds */
-static volatile long midi_timers;               /* current position in allegro-timer-ticks */
+volatile long midi_pos = -1;                    /* position in MIDI file */
 static long midi_pos_counter;                   /* delta for midi_pos */
 
 volatile long _midi_tick = 0;                   /* counter for killing notes */
@@ -136,7 +129,6 @@ void (*midi_sysex_callback)(AL_CONST unsigned char *data, int length) = NULL;
 void lock_midi(MIDI *midi)
 {
    int c;
-   ASSERT(midi);
 
    LOCK_DATA(midi, sizeof(MIDI));
 
@@ -161,13 +153,12 @@ MIDI *load_midi(AL_CONST char *filename)
    PACKFILE *fp;
    MIDI *midi;
    int num_tracks;
-   ASSERT(filename);
 
    fp = pack_fopen(filename, F_READ);        /* open the file */
    if (!fp)
       return NULL;
 
-   midi = _AL_MALLOC(sizeof(MIDI));              /* get some memory */
+   midi = malloc(sizeof(MIDI));              /* get some memory */
    if (!midi) {
       pack_fclose(fp);
       return NULL;
@@ -178,26 +169,7 @@ MIDI *load_midi(AL_CONST char *filename)
       midi->track[c].len = 0;
    }
 
-   pack_fread(buf, 4, fp); /* read midi header */
-
-   /* Is the midi inside a .rmi file? */
-   if (memcmp(buf, "RIFF", 4) == 0) { /* check for RIFF header */
-      pack_mgetl(fp);
-
-      while (!pack_feof(fp)) {
-         pack_fread(buf, 4, fp); /* RMID chunk? */
-         if (memcmp(buf, "RMID", 4) == 0) break;
-
-         pack_fseek(fp, pack_igetl(fp)); /* skip to next chunk */
-      }
-
-      if (pack_feof(fp)) goto err;
-
-      pack_mgetl(fp);
-      pack_mgetl(fp);
-      pack_fread(buf, 4, fp); /* read midi header */
-   }
-
+   pack_fread(buf, 4, fp);                   /* read midi header */
    if (memcmp(buf, "MThd", 4))
       goto err;
 
@@ -222,7 +194,7 @@ MIDI *load_midi(AL_CONST char *filename)
       data = pack_mgetl(fp);                 /* length of track chunk */
       midi->track[c].len = data;
 
-      midi->track[c].data = _AL_MALLOC_ATOMIC(data); /* allocate memory */
+      midi->track[c].data = malloc(data);    /* allocate memory */
       if (!midi->track[c].data)
 	 goto err;
 					     /* finally, read track data */
@@ -257,12 +229,12 @@ void destroy_midi(MIDI *midi)
       for (c=0; c<MIDI_TRACKS; c++) {
 	 if (midi->track[c].data) {
 	    UNLOCK_DATA(midi->track[c].data, midi->track[c].len);
-	    _AL_FREE(midi->track[c].data);
+	    free(midi->track[c].data);
 	 }
       }
 
       UNLOCK_DATA(midi, sizeof(MIDI));
-      _AL_FREE(midi);
+      free(midi);
    }
 }
 
@@ -602,23 +574,6 @@ END_OF_STATIC_FUNCTION(all_notes_off);
 
 
 
-/* all_sound_off:
- *  Turns off sound.
- */
-static void all_sound_off(int channel)
-{
-   if (midi_driver->raw_midi) {
-      midi_driver->raw_midi(0xB0+channel);
-      midi_driver->raw_midi(120);
-      midi_driver->raw_midi(0);
-      return;
-   }
-}
-
-END_OF_STATIC_FUNCTION(all_sound_off);
-
-
-
 /* reset_controllers:
  *  Resets volume, pan, pitch bend, etc, to default positions.
  */
@@ -627,12 +582,6 @@ static void reset_controllers(int channel)
    midi_channel[channel].new_volume = 128;
    midi_channel[channel].new_pitch_bend = 0x2000;
 
-   if (midi_driver->raw_midi) {
-      midi_driver->raw_midi(0xB0+channel);
-      midi_driver->raw_midi(121);
-      midi_driver->raw_midi(0);
-   }
-
    switch (channel % 3) {
       case 0:  midi_channel[channel].pan = ((channel/3) & 1) ? 60 : 68; break;
       case 1:  midi_channel[channel].pan = 104; break;
@@ -724,10 +673,6 @@ static void process_controller(int channel, int ctrl, int data)
 	 }
 	 break;
 
-      case 120:                                 /* all sound off */
-	 all_sound_off(channel);
-	 break;
-
       case 121:                                 /* reset all controllers */
 	 reset_controllers(channel);
 	 break;
@@ -739,14 +684,6 @@ static void process_controller(int channel, int ctrl, int data)
       case 127:                                 /* poly mode on */
 	 all_notes_off(channel);
 	 break;
-
-      default:
-	 if (midi_driver->raw_midi) {
-	    midi_driver->raw_midi(0xB0+channel);
-	    midi_driver->raw_midi(ctrl);
-	    midi_driver->raw_midi(data);
-	 }
-	 break;
    }
 }
 
@@ -907,17 +844,14 @@ static void midi_player(void)
       return;
 
    if (midi_semaphore) {
-      midi_timer_speed += BPS_TO_TIMER(MIDI_TIMER_FREQUENCY);
-      install_int_ex(midi_player, BPS_TO_TIMER(MIDI_TIMER_FREQUENCY));
+      midi_timer_speed += BPS_TO_TIMER(40);
+      install_int_ex(midi_player, BPS_TO_TIMER(40));
       return;
    }
 
    midi_semaphore = TRUE;
    _midi_tick++;
 
-   midi_timers += midi_timer_speed;
-   midi_time = midi_timers / TIMERS_PER_SECOND;
-
    do_it_all_again:
 
    for (c=0; c<MIDI_VOICES; c++)
@@ -995,10 +929,8 @@ static void midi_player(void)
 	    goto do_it_all_again;
 	 }
 	 else {
-	    for (c=0; c<16; c++) {
+	    for (c=0; c<16; c++)
 	       all_notes_off(c);
-	       all_sound_off(c);
-	    }
 	    prepare_to_play(midifile);
 	    goto do_it_all_again;
 	 }
@@ -1011,8 +943,8 @@ static void midi_player(void)
    }
 
    /* reprogram the timer */
-   if (midi_timer_speed < BPS_TO_TIMER(MIDI_TIMER_FREQUENCY))
-      midi_timer_speed = BPS_TO_TIMER(MIDI_TIMER_FREQUENCY);
+   if (midi_timer_speed < BPS_TO_TIMER(40))
+      midi_timer_speed = BPS_TO_TIMER(40);
 
    if (!midi_seeking) 
       install_int_ex(midi_player, midi_timer_speed);
@@ -1109,7 +1041,6 @@ static int load_patches(MIDI *midi)
    unsigned char running_status, event;
    long l;
    int c;
-   ASSERT(midi);
 
    for (c=0; c<128; c++)                        /* initialise to unused */
       patches[c] = drums[c] = FALSE;
@@ -1210,7 +1141,6 @@ static int load_patches(MIDI *midi)
 static void prepare_to_play(MIDI *midi)
 {
    int c;
-   ASSERT(midi);
 
    for (c=0; c<16; c++)
       reset_controllers(c);
@@ -1219,8 +1149,6 @@ static void prepare_to_play(MIDI *midi)
 
    midifile = midi;
    midi_pos = 0;
-   midi_timers = 0;
-   midi_time = 0;
    midi_pos_counter = 0;
    midi_speed = TIMERS_PER_SECOND / 2 / midifile->divisions;   /* 120 bpm */
    midi_new_speed = -1;
@@ -1268,10 +1196,8 @@ int play_midi(MIDI *midi, int loop)
 
    remove_int(midi_player);
 
-   for (c=0; c<16; c++) {
+   for (c=0; c<16; c++)
       all_notes_off(c);
-      all_sound_off(c);
-   }
 
    if (midi) {
       if (!midi_loaded_patches)
@@ -1324,7 +1250,7 @@ int play_looped_midi(MIDI *midi, int loop_start, int loop_end)
 /* stop_midi:
  *  Stops whatever MIDI file is currently playing.
  */
-void stop_midi(void)
+void stop_midi()
 {
    play_midi(NULL, FALSE);
 }
@@ -1336,7 +1262,7 @@ END_OF_FUNCTION(stop_midi);
 /* midi_pause:
  *  Pauses the currently playing MIDI file.
  */
-void midi_pause(void)
+void midi_pause()
 {
    int c;
 
@@ -1345,10 +1271,8 @@ void midi_pause(void)
 
    remove_int(midi_player);
 
-   for (c=0; c<16; c++) {
+   for (c=0; c<16; c++)
       all_notes_off(c);
-      all_sound_off(c);
-   }
 }
 
 END_OF_FUNCTION(midi_pause);
@@ -1358,7 +1282,7 @@ END_OF_FUNCTION(midi_pause);
 /* midi_resume:
  *  Resumes playing a paused MIDI file.
  */
-void midi_resume(void)
+void midi_resume() 
 {
    if (!midifile)
       return;
@@ -1483,21 +1407,6 @@ END_OF_FUNCTION(midi_seek);
 
 
 
-/* get_midi_length:
- *  Returns the length, in seconds, of the specified midi. This will stop any
- *  currently playing midi. Don't call it too often, since it simulates playing
- *  all of the midi to get the time even if the midi contains tempo changes.
- */
-int get_midi_length(MIDI *midi)
-{
-    play_midi(midi, 0);
-    while (midi_pos < 0); /* Without this, midi_seek won't work. */
-    midi_seek(INT_MAX);
-    return midi_time;
-}
-
-
-
 /* midi_out:
  *  Inserts MIDI command bytes into the output stream, in realtime.
  */
@@ -1506,7 +1415,6 @@ void midi_out(unsigned char *data, int length)
    unsigned char *pos = data;
    unsigned char running_status = 0;
    long timer = 0;
-   ASSERT(data);
 
    midi_semaphore = TRUE;
    _midi_tick++;
@@ -1524,7 +1432,7 @@ void midi_out(unsigned char *data, int length)
 /* load_midi_patches:
  *  Tells the MIDI driver to preload the entire sample set.
  */
-int load_midi_patches(void)
+int load_midi_patches()
 {
    char patches[128], drums[128];
    int c, ret;
@@ -1550,8 +1458,6 @@ int load_midi_patches(void)
 static void midi_lock_mem(void)
 {
    LOCK_VARIABLE(midi_pos);
-   LOCK_VARIABLE(midi_time);
-   LOCK_VARIABLE(midi_timers);
    LOCK_VARIABLE(midi_pos_counter);
    LOCK_VARIABLE(_midi_tick);
    LOCK_VARIABLE(midifile);
@@ -1583,7 +1489,6 @@ static void midi_lock_mem(void)
    LOCK_FUNCTION(_midi_allocate_voice);
    LOCK_FUNCTION(midi_note_on);
    LOCK_FUNCTION(all_notes_off);
-   LOCK_FUNCTION(all_sound_off);
    LOCK_FUNCTION(reset_controllers);
    LOCK_FUNCTION(update_controllers);
    LOCK_FUNCTION(process_controller);
