@@ -17,9 +17,6 @@
 
 
 #include "allegro.h"
-
-#ifdef GFX_HAS_VGA
-
 #include "allegro/internal/aintern.h"
 #include "allegro/internal/aintvga.h"
 
@@ -32,7 +29,7 @@ int _crtc = 0x3D4;
 /* _vga_regs_init:
  *  Initialiases the VGA register access functions.
  */
-void _vga_regs_init(void)
+void _vga_regs_init()
 {
    LOCK_VARIABLE(_crtc);
 
@@ -47,7 +44,7 @@ void _vga_regs_init(void)
 /* _vga_vsync:
  *  Waits for the start of a vertical retrace.
  */
-void _vga_vsync(void)
+void _vga_vsync()
 {
    _vsync_out_v();
    _vsync_in();
@@ -91,4 +88,3 @@ void _vga_set_palette_range(AL_CONST PALETTE p, int from, int to, int vsync)
 }
 
 
-#endif /* GFX_HAS_VGA */
