@@ -48,10 +48,10 @@ void register_bitmap_file_type(AL_CONST char *ext, BITMAP *(*load)(AL_CONST char
    if (strlen(aext) == 0) return;
 
    if (!iter) 
-      iter = bitmap_type_list = _AL_MALLOC(sizeof(struct BITMAP_TYPE_INFO));
+      iter = bitmap_type_list = malloc(sizeof(struct BITMAP_TYPE_INFO));
    else {
       for (iter = bitmap_type_list; iter->next; iter = iter->next);
-      iter = iter->next = _AL_MALLOC(sizeof(struct BITMAP_TYPE_INFO));
+      iter = iter->next = malloc(sizeof(struct BITMAP_TYPE_INFO));
    }
 
    if (iter) {
@@ -71,7 +71,6 @@ BITMAP *load_bitmap(AL_CONST char *filename, RGB *pal)
 {
    char tmp[32], *aext;
    BITMAP_TYPE_INFO *iter;
-   ASSERT(filename);
 
    aext = uconvert_toascii(get_extension(filename), tmp);
    
@@ -95,14 +94,12 @@ int save_bitmap(AL_CONST char *filename, BITMAP *bmp, AL_CONST RGB *pal)
 {
    char tmp[32], *aext;
    BITMAP_TYPE_INFO *iter;
-   ASSERT(filename);
-   ASSERT(bmp);
 
    aext = uconvert_toascii(get_extension(filename), tmp);
 
    for (iter = bitmap_type_list; iter; iter = iter->next) {
       if (stricmp(iter->ext, aext) == 0) {
-	 if (iter->save)
+	 if (iter->load)
 	    return iter->save(filename, bmp, pal);
 	 return 1;
       }
@@ -125,7 +122,6 @@ int save_bitmap(AL_CONST char *filename, BITMAP *bmp, AL_CONST RGB *pal)
 BITMAP *_fixup_loaded_bitmap(BITMAP *bmp, PALETTE pal, int bpp)
 {
    BITMAP *b2;
-   ASSERT(bmp);
 
    b2 = create_bitmap_ex(bpp, bmp->w, bmp->h);
    if (!b2) {
@@ -141,14 +137,14 @@ BITMAP *_fixup_loaded_bitmap(BITMAP *bmp, PALETTE pal, int bpp)
       else
 	 pal = _current_palette;
 
-      rgb_map = _AL_MALLOC(sizeof(RGB_MAP));
+      rgb_map = malloc(sizeof(RGB_MAP));
       if (rgb_map != NULL)
 	 create_rgb_table(rgb_map, pal, NULL);
 
       blit(bmp, b2, 0, 0, 0, 0, bmp->w, bmp->h);
 
       if (rgb_map != NULL)
-	 _AL_FREE(rgb_map);
+	 free(rgb_map);
       rgb_map = old_map;
    }
    else if (bitmap_color_depth(bmp) == 8) {
@@ -176,8 +172,8 @@ static void register_bitmap_file_type_exit(void)
 
    while (iter) {
       next = iter->next;
-      _AL_FREE(iter->ext);
-      _AL_FREE(iter);
+      free(iter->ext);
+      free(iter);
       iter = next;
    }
    
@@ -203,8 +199,7 @@ void _register_bitmap_file_type_init(void)
 {
    char buf[32];
 
-   _add_exit_func(register_bitmap_file_type_exit,
-		  "register_bitmap_file_type_exit");
+   _add_exit_func(register_bitmap_file_type_exit);
 
    register_bitmap_file_type(uconvert_ascii("bmp", buf), load_bmp, save_bmp);
    register_bitmap_file_type(uconvert_ascii("lbm", buf), load_lbm, NULL);
@@ -240,8 +235,8 @@ void _register_bitmap_file_type_init(void)
 
       while (iter) {
          next = iter->next;
-         _AL_FREE(iter->ext);
-         _AL_FREE(iter);
+         free(iter->ext);
+         free(iter);
          iter = next;
       }
    
