@@ -250,32 +250,6 @@ static void rle_tga_read16(unsigned short *b, int w, PACKFILE *f)
  *  of at least 256 RGB structures).
  */
 BITMAP *load_tga(AL_CONST char *filename, RGB *pal)
-{
-   PACKFILE *f;
-   BITMAP *bmp;
-   ASSERT(filename);
-
-   f = pack_fopen(filename, F_READ);
-   if (!f)
-      return NULL;
-
-   bmp = load_tga_pf(f, pal);
-
-   pack_fclose(f);
-
-   return bmp;
-}
-
-
-
-/* load_tga_pf:
- *  Like load_tga, but starts loading from the current place in the PACKFILE
- *  specified. If successful the offset into the file will be left just after
- *  the image data. If unsuccessful the offset into the file is unspecified,
- *  i.e. you must either reset the offset to some known place or close the
- *  packfile. The packfile is not closed by this function.
- */
-BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
 {
    unsigned char image_id[256], image_palette[256][3];
    unsigned char id_length, palette_type, image_type, palette_entry_size;
@@ -283,12 +257,13 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
    short unsigned int first_color, palette_colors;
    short unsigned int left, top, image_width, image_height;
    unsigned int c, i, y, yc;
+   unsigned short *s;
    int dest_depth;
    int compressed;
+   PACKFILE *f;
    BITMAP *bmp;
    PALETTE tmppal;
    int want_palette = TRUE;
-   ASSERT(f);
 
    /* we really need a palette */
    if (!pal) {
@@ -296,6 +271,10 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
       pal = tmppal;
    }
 
+   f = pack_fopen(filename, F_READ);
+   if (!f)
+      return NULL;
+
    id_length = pack_getc(f);
    palette_type = pack_getc(f);
    image_type = pack_getc(f);
@@ -311,33 +290,27 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
 
    pack_fread(image_id, id_length, f);
 
-   if (palette_type == 1) {
+   for (i = 0; i < palette_colors; i++) {
 
-      for (i = 0; i < palette_colors; i++) {
+      switch (palette_entry_size) {
 
-	 switch (palette_entry_size) {
+	 case 16: 
+	    c = pack_igetw(f);
+	    image_palette[i][0] = (c & 0x1F) << 3;
+	    image_palette[i][1] = ((c >> 5) & 0x1F) << 3;
+	    image_palette[i][2] = ((c >> 10) & 0x1F) << 3;
+	    break;
 
-	    case 16: 
-	       c = pack_igetw(f);
-	       image_palette[i][0] = (c & 0x1F) << 3;
-	       image_palette[i][1] = ((c >> 5) & 0x1F) << 3;
-	       image_palette[i][2] = ((c >> 10) & 0x1F) << 3;
-	       break;
-
-	    case 24:
-	    case 32:
-	       image_palette[i][0] = pack_getc(f);
-	       image_palette[i][1] = pack_getc(f);
-	       image_palette[i][2] = pack_getc(f);
-	       if (palette_entry_size == 32)
-		  pack_getc(f);
-	       break;
-	 }
+	 case 24:
+	 case 32:
+	    image_palette[i][0] = pack_getc(f);
+	    image_palette[i][1] = pack_getc(f);
+	    image_palette[i][2] = pack_getc(f);
+	    if (palette_entry_size == 32)
+	       pack_getc(f);
+	    break;
       }
    }
-   else if (palette_type != 0) {
-      return NULL;
-   }
 
    /* Image type:
     *    0 = no image data
@@ -352,6 +325,7 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
    image_type &= 7;
 
    if ((image_type < 1) || (image_type > 3)) {
+      pack_fclose(f);
       return NULL;
    }
 
@@ -360,6 +334,7 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
       case 1:
 	 /* paletted image */
 	 if ((palette_type != 1) || (bpp != 8)) {
+	    pack_fclose(f);
 	    return NULL;
 	 }
 
@@ -382,6 +357,7 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
 	    dest_depth = _color_load_depth(bpp, (bpp == 32));
 	 }
 	 else {
+	    pack_fclose(f);
 	    return NULL;
 	 }
 	 break;
@@ -389,6 +365,7 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
       case 3:
 	 /* grayscale image */
 	 if ((palette_type != 0) || (bpp != 8)) {
+	    pack_fclose(f);
 	    return NULL;
 	 }
 
@@ -398,20 +375,20 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
 	     pal[i].b = i>>2;
 	 }
 
-	 dest_depth = _color_load_depth(bpp, FALSE);
+	 dest_depth = _color_depth;
 	 break;
 
       default:
+	 pack_fclose(f);
 	 return NULL;
    }
 
    bmp = create_bitmap_ex(bpp, image_width, image_height);
    if (!bmp) {
+      pack_fclose(f);
       return NULL;
    }
 
-   *allegro_errno = 0;
-
    for (y=image_height; y; y--) {
       yc = (descriptor_bits & 0x20) ? image_height-y : y-1;
 
@@ -448,6 +425,8 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
       }
    }
 
+   pack_fclose(f);
+
    if (*allegro_errno) {
       destroy_bitmap(bmp);
       return NULL;
@@ -470,66 +449,17 @@ BITMAP *load_tga_pf(PACKFILE *f, RGB *pal)
 
 
 
-/* bitmap_has_alpha:
- *  Checks whether this bitmap has an alpha channel.
- */
-static int bitmap_has_alpha(BITMAP *bmp)
-{
-   int x, y, c;
-
-   if (bitmap_color_depth(bmp) != 32)
-      return FALSE;
-
-   for (y = 0; y < bmp->h; y++) {
-      for (x = 0; x < bmp->w; x++) {
-	 c = getpixel(bmp, x, y);
-	 if (geta32(c))
-	    return TRUE;
-      }
-   }
-
-   return FALSE;
-}
-
-
-
 /* save_tga:
  *  Writes a bitmap into a TGA file, using the specified palette (this
  *  should be an array of at least 256 RGB structures).
  */
 int save_tga(AL_CONST char *filename, BITMAP *bmp, AL_CONST RGB *pal)
-{
-   PACKFILE *f;
-   int ret;
-   ASSERT(filename);
-
-   f = pack_fopen(filename, F_WRITE);
-   if (!f)
-      return -1;
-
-   ret = save_tga_pf(f, bmp, pal);
-
-   pack_fclose(f);
-
-   return ret;
-}
-
-
-
-/* save_tga_pf:
- *  Like save_tga but writes into the PACKFILE given instead of a new file.
- *  The packfile is not closed after writing is completed. On success the
- *  offset into the file is left after the TGA file just written. On failure
- *  the offset is left at the end of whatever incomplete data was written.
- */
-int save_tga_pf(PACKFILE *f, BITMAP *bmp, AL_CONST RGB *pal)
 {
    unsigned char image_palette[256][3];
    int x, y, c, r, g, b;
    int depth;
+   PACKFILE *f;
    PALETTE tmppal;
-   ASSERT(f);
-   ASSERT(bmp);
 
    if (!pal) {
       get_palette(tmppal);
@@ -541,7 +471,9 @@ int save_tga_pf(PACKFILE *f, BITMAP *bmp, AL_CONST RGB *pal)
    if (depth == 15)
       depth = 16;
 
-   *allegro_errno = 0;
+   f = pack_fopen(filename, F_WRITE);
+   if (!f)
+      return *allegro_errno;
 
    pack_putc(0, f);                          /* id length (no id saved) */
    pack_putc((depth == 8) ? 1 : 0, f);       /* palette type */
@@ -554,7 +486,7 @@ int save_tga_pf(PACKFILE *f, BITMAP *bmp, AL_CONST RGB *pal)
    pack_iputw(bmp->w, f);                    /* width */
    pack_iputw(bmp->h, f);                    /* height */
    pack_putc(depth, f);                      /* bits per pixel */
-   pack_putc(bitmap_has_alpha (bmp) ? 8 : 0, f); /* descriptor (bottom to top, 8-bit alpha) */
+   pack_putc(0, f);                          /* descriptor (bottom to top) */
 
    if (depth == 8) {
       for (y=0; y<256; y++) {
@@ -640,10 +572,8 @@ int save_tga_pf(PACKFILE *f, BITMAP *bmp, AL_CONST RGB *pal)
       #endif
    }
 
-   if (*allegro_errno)
-      return -1;
-   else
-      return 0;
+   pack_fclose(f);
+   return *allegro_errno;
 }
 
 
