@@ -18,17 +18,13 @@
 
 #include "allegro.h"
 
-#if (defined ALLEGRO_WITH_ARTSDIGI) && ((!defined ALLEGRO_WITH_MODULES) || (defined ALLEGRO_MODULE))
+#if (defined DIGI_ARTS) && ((!defined ALLEGRO_WITH_MODULES) || (defined ALLEGRO_MODULE))
 
 #include "allegro/internal/aintern.h"
 #include "allegro/platform/aintunix.h"
 
 #include <artsc.h>
 
-#ifdef ALLEGRO_MODULE
-int _module_has_registered_via_atexit = 0;
-#endif
-
 static int _al_arts_bits, _al_arts_rate, _al_arts_stereo;
 #define _al_arts_signed (TRUE)
 
@@ -104,7 +100,7 @@ DIGI_DRIVER digi_arts =
 /* _al_arts_buffer_size:
  *  Returns the current DMA buffer size, for use by the audiostream code.
  */
-static int _al_arts_buffer_size(void)
+static int _al_arts_buffer_size()
 {
    return _al_arts_bufsize / (_al_arts_bits / 8) / (_al_arts_stereo ? 2 : 1);
 }
@@ -122,7 +118,7 @@ static void _al_arts_update(int threaded)
       if (arts_write(_al_arts_stream, _al_arts_bufdata, _al_arts_bufsize)
 	  < _al_arts_bufsize)
 	 break;
-      _mix_some_samples((uintptr_t) _al_arts_bufdata, 0, _al_arts_signed);
+      _mix_some_samples((unsigned long) _al_arts_bufdata, 0, _al_arts_signed);
    }
 }
 
@@ -182,14 +178,6 @@ static int _al_arts_init(int input, int voices)
       return -1;
    }
 
-#ifdef ALLEGRO_MODULE
-   /* A side-effect of arts_init() is that it will register an
-    * atexit handler.  See umodules.c for this problem.
-    * ??? this seems to be the case only for recent versions.
-    */
-   _module_has_registered_via_atexit = 1;
-#endif
-
    /* Make a copy of the global sound settings.  */
    _al_arts_bits = (_sound_bits == 8) ? 8 : 16;
    _al_arts_stereo = (_sound_stereo) ? 1 : 0;
@@ -237,7 +225,7 @@ static int _al_arts_init(int input, int voices)
       goto error;
    }
 
-   _mix_some_samples((uintptr_t) _al_arts_bufdata, 0, _al_arts_signed);
+   _mix_some_samples((unsigned long) _al_arts_bufdata, 0, _al_arts_signed);
 
    /* Add audio interrupt.  */
    _unix_bg_man->register_func(_al_arts_update);
@@ -286,16 +274,10 @@ static void _al_arts_exit(int input)
    free(_al_arts_bufdata);
    _al_arts_bufdata = NULL;
 
-   /* Do not call the cleanup routines if we are being
-    * called by the exit mechanism because they may have
-    * already been called by it (see above).
-    */
-   if (!_allegro_in_exit) {
-      arts_close_stream(_al_arts_stream);
-      _al_arts_stream = NULL;
+   arts_close_stream(_al_arts_stream);
+   _al_arts_stream = NULL;
 
-      arts_free();
-   }
+   arts_free();
 }
 
 
