@@ -15,38 +15,44 @@
  *      See readme.txt for copyright information.
  */
 
-/* libc should use 64-bit for file sizes when possible */
-#define _FILE_OFFSET_BITS 64
 
 #include <stdio.h>
 #include <string.h>
+#include <sys/stat.h>
 
 #include "allegro.h"
 #include "allegro/internal/aintern.h"
 
-#ifdef ALLEGRO_HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif
 
-#ifdef ALLEGRO_HAVE_DIRENT_H
+#ifdef HAVE_DIRENT_H
    #include <sys/types.h>
    #include <dirent.h>
    #define NAMLEN(dirent) (strlen((dirent)->d_name))
 #else
-   /* Apparently all new systems have `dirent.h'. */
-   #error ALLEGRO_HAVE_DIRENT_H not defined
+   #define dirent direct
+   #define NAMLEN(dirent) ((dirent)->d_namlen)
+   #ifdef HAVE_SYS_NDIR_H
+      #include <sys/ndir.h>
+   #endif
+   #ifdef HAVE_SYS_DIR_H
+      #include <sys/dir.h>
+   #endif
+   #ifdef HAVE_NDIR_H
+      #include <ndir.h>
+   #endif
 #endif
 
-#ifdef ALLEGRO_HAVE_SYS_TIME_H
-  #include <sys/time.h>
-#endif
-#ifdef ALLEGRO_HAVE_TIME_H
-  #include <time.h>
+#ifdef TIME_WITH_SYS_TIME
+   #include <sys/time.h>
+   #include <time.h>
+#else
+   #ifdef HAVE_SYS_TIME_H
+      #include <sys/time.h>
+   #else
+      #include <time.h>
+   #endif
 #endif
 
-#define PREFIX_I "al-unix INFO: "
-
-#define PREFIX_I "al-unix INFO: "
 
 
 /* _al_file_isok:
@@ -60,15 +66,15 @@ int _al_file_isok(AL_CONST char *filename)
 
 
 
-/* _al_file_size_ex:
+/* _al_file_size:
  *  Measures the size of the specified file.
  */
-uint64_t _al_file_size_ex(AL_CONST char *filename)
+long _al_file_size(AL_CONST char *filename)
 {
    struct stat s;
    char tmp[1024];
 
-   if (stat(uconvert(filename, U_CURRENT, tmp, U_UTF8, sizeof(tmp)), &s) != 0) {
+   if (stat(uconvert_toascii(filename, tmp), &s) != 0) {
       *allegro_errno = errno;
       return 0;
    }
@@ -86,7 +92,7 @@ time_t _al_file_time(AL_CONST char *filename)
    struct stat s;
    char tmp[1024];
 
-   if (stat(uconvert(filename, U_CURRENT, tmp, U_UTF8, sizeof(tmp)), &s) != 0) {
+   if (stat(uconvert_toascii(filename, tmp), &s) != 0) {
       *allegro_errno = errno;
       return 0;
    }
@@ -156,7 +162,7 @@ static int ff_match(AL_CONST char *s1, AL_CONST char *s2)
    /* handle NULL arguments */
    if ((!s1) && (!s2)) {
       if (data) {
-         _AL_FREE(data);
+         free(data);
          data = NULL;
       }
 
@@ -167,13 +173,13 @@ static int ff_match(AL_CONST char *s1, AL_CONST char *s2)
 
    /* allocate larger working area if necessary */
    if (data && (size < strlen(s2))) {
-      _AL_FREE(data);
+      free(data);
       data = NULL;
    }
 
    if (!data) {
       size = strlen(s2);
-      data = _AL_MALLOC(sizeof(struct FF_MATCH_DATA) * size * 2 + 1);
+      data = malloc(sizeof(struct FF_MATCH_DATA) * size * 2 + 1);
       if (!data)
          return 0;
    }
@@ -294,7 +300,6 @@ struct FF_DATA
    char dirname[FF_MAXPATHLEN];
    char pattern[FF_MAXPATHLEN];
    int attrib;
-   uint64_t size;
 };
 
 
@@ -310,55 +315,56 @@ int al_findfirst(AL_CONST char *pattern, struct al_ffblk *info, int attrib)
    char tmp[1024];
    char *p;
 
-   /* allocate ff_data structure */
-   ff_data = _AL_MALLOC(sizeof(struct FF_DATA));
-   if (!ff_data) {
-      *allegro_errno = ENOMEM;
-      return -1;
-   }
-
-   memset(ff_data, 0, sizeof *ff_data);
-   info->ff_data = (void *) ff_data;
-
    /* if the pattern contains no wildcard, we use stat() */
-   if (!ustrpbrk(pattern, uconvert("?*", U_ASCII, tmp, U_CURRENT, sizeof(tmp)))) {
+   if (!ustrpbrk(pattern, uconvert_ascii("?*", tmp))) {
+      info->ff_data = NULL;
+
       /* start the search */
       errno = *allegro_errno = 0;
 
-      if (stat(uconvert(pattern, U_CURRENT, tmp, U_UTF8, sizeof(tmp)), &s) == 0) {
+      if (stat(uconvert_toascii(pattern, tmp), &s) == 0) {
          /* get file attributes */
-         actual_attrib = ff_get_attrib(ff_get_filename(uconvert(pattern, U_CURRENT, tmp, U_UTF8, sizeof(tmp))), &s);
+         actual_attrib = ff_get_attrib(ff_get_filename(uconvert_toascii(pattern, tmp)), &s);
 
          /* does it match ? */
          if ((actual_attrib & ~attrib) == 0) {
             info->attrib = actual_attrib;
             info->time = s.st_mtime;
-            info->size = s.st_size; /* overflows at 2GB */
-            ff_data->size = s.st_size;
+            info->size = s.st_size;
             ustrzcpy(info->name, sizeof(info->name), get_filename(pattern));
             return 0;
          }
       }
 
-       _AL_FREE(ff_data);
-      info->ff_data = NULL;
       *allegro_errno = (errno ? errno : ENOENT);
       return -1;
    }
 
+   /* allocate ff_data structure */
+   ff_data = malloc(sizeof(struct FF_DATA));
+
+   if (!ff_data) {
+      *allegro_errno = ENOMEM;
+      return -1;
+   }
+
+   /* attach it to the info structure */
+   info->ff_data = (void *) ff_data;
+
+   /* initialize it */
    ff_data->attrib = attrib;
 
-   do_uconvert(pattern, U_CURRENT, ff_data->dirname, U_UTF8, sizeof(ff_data->dirname));
+   do_uconvert(pattern, U_CURRENT, ff_data->dirname, U_ASCII, sizeof(ff_data->dirname));
    p = ff_get_filename(ff_data->dirname);
-   _al_sane_strncpy(ff_data->pattern, p, sizeof(ff_data->pattern));
+   strncpy(ff_data->pattern, p, sizeof(ff_data->pattern));
    if (p == ff_data->dirname)
-      _al_sane_strncpy(ff_data->dirname, "./", FF_MAXPATHLEN);
+      strcpy(ff_data->dirname, "./");
    else
       *p = 0;
 
    /* nasty bodge, but gives better compatibility with DOS programs */
    if (strcmp(ff_data->pattern, "*.*") == 0)
-      _al_sane_strncpy(ff_data->pattern, "*", FF_MAXPATHLEN);
+      strcpy(ff_data->pattern, "*");
 
    /* start the search */
    errno = *allegro_errno = 0;
@@ -367,7 +373,7 @@ int al_findfirst(AL_CONST char *pattern, struct al_ffblk *info, int attrib)
 
    if (!ff_data->dir) {
       *allegro_errno = (errno ? errno : ENOENT);
-      _AL_FREE(ff_data);
+      free(ff_data);
       info->ff_data = NULL;
       return -1;
    }
@@ -394,10 +400,8 @@ int al_findnext(struct al_ffblk *info)
    struct stat s;
    struct FF_DATA *ff_data = (struct FF_DATA *) info->ff_data;
 
-   ASSERT(ff_data);
-
    /* if the pattern contained no wildcard */
-   if (!ff_data->dir)
+   if (!ff_data)
       return -1;
 
    while (TRUE) {
@@ -416,7 +420,7 @@ int al_findnext(struct al_ffblk *info)
          strncat(tempname, entry->d_name, NAMLEN(entry));
 
       if (ff_match(tempname, ff_data->pattern)) {
-         _al_sane_strncpy(filename, ff_data->dirname, FF_MAXPATHLEN);
+         strcpy(filename, ff_data->dirname);
          ff_put_backslash(filename, sizeof(filename));
          strncat(filename, tempname, sizeof(filename) - strlen(filename) - 1);
 
@@ -437,10 +441,9 @@ int al_findnext(struct al_ffblk *info)
 
    info->attrib = attrib;
    info->time = s.st_mtime;
-   info->size = s.st_size; /* overflows at 2GB */
-   ff_data->size = s.st_size;
+   info->size = s.st_size;
 
-   do_uconvert(tempname, U_UTF8, info->name, U_CURRENT, sizeof(info->name));
+   do_uconvert(tempname, U_ASCII, info->name, U_CURRENT, sizeof(info->name));
 
    return 0;
 }
@@ -455,10 +458,8 @@ void al_findclose(struct al_ffblk *info)
    struct FF_DATA *ff_data = (struct FF_DATA *) info->ff_data;
 
    if (ff_data) {
-      if (ff_data->dir) {
-         closedir(ff_data->dir);
-      }
-      _AL_FREE(ff_data);
+      closedir(ff_data->dir);
+      free(ff_data);
       info->ff_data = NULL;
 
       /* to avoid leaking memory */
@@ -476,49 +477,8 @@ void _al_getdcwd(int drive, char *buf, int size)
    char tmp[1024];
 
    if (getcwd(tmp, sizeof(tmp)))
-      do_uconvert(tmp, U_UTF8, buf, U_CURRENT, size);
+      do_uconvert(tmp, U_ASCII, buf, U_CURRENT, size);
    else
       usetc(buf, 0);
 }
 
-
-
-/* _al_ffblk_get_size:
- *  Returns the size out of an _al_ffblk structure.
- */
-uint64_t al_ffblk_get_size(struct al_ffblk *info)
-{
-   struct FF_DATA *ff_data;
-   ASSERT(info);
-   ff_data = (struct FF_DATA *) info->ff_data;
-   ASSERT(ff_data);
-   return ff_data->size;
-}
-
-
-
-void _unix_guess_file_encoding(void)
-{
-   char const *encoding = "unknown";
-   char *locale = getenv("LC_ALL");
-
-   if (!locale || !locale[0]) {
-      locale = getenv("LC_CTYPE");
-      if (!locale || !locale[0])
-         locale = getenv("LANG");
-   }
-
-   if (locale) {
-      if (strstr(locale, "utf8") ||
-          strstr(locale, "UTF-8") ||
-          strstr(locale, "utf-8") ||
-          strstr(locale, "UTF8")) {
-         /* Note: UTF8 is default anyway. */
-         set_file_encoding(U_UTF8);
-         encoding = "UTF8";
-      }
-      /* TODO: detect other encodings, and support them in Allegro */
-   }
-
-   TRACE(PREFIX_I "Assumed libc encoding is %s.\n", encoding);
-}
