@@ -39,15 +39,35 @@ static void gfx_directx_switch_out(void)
 
 
 
+/* gfx_directx_restore:
+ *  Restores all the video and system bitmaps.
+ */
+void gfx_directx_restore(void)
+{
+   BMP_EXTRA_INFO *item = directx_bmp_list;
+
+   _enter_gfx_critical();
+
+   while (item) {
+      IDirectDrawSurface2_Restore(item->surf);
+      item = item->next;
+   }
+
+   _exit_gfx_critical();
+}
+
+
+
 /* gfx_directx_lock:
  *  Locks the surface and prepares the lines array of the bitmap.
  */
 void gfx_directx_lock(BITMAP *bmp)
 {
-   DDRAW_SURFACE *surf;
+   LPDIRECTDRAWSURFACE2 surf;
+   BMP_EXTRA_INFO *bmp_extra;
    BITMAP *parent;
    HRESULT hr;
-   DDSURFACEDESC ddsurf_desc;
+   DDSURFACEDESC surf_desc;
    int pitch;
    unsigned char *data;
    int y;
@@ -80,44 +100,31 @@ void gfx_directx_lock(BITMAP *bmp)
          gfx_directx_switch_out();
 
       /* this is a real bitmap, so can be locked directly */
-      surf = DDRAW_SURFACE_OF(bmp);
-      surf->lock_nesting++;
+      bmp_extra = BMP_EXTRA(bmp);
+      bmp_extra->lock_nesting++;
 
       if (!(bmp->id & BMP_ID_LOCKED)) {
-         /* try to lock surface */
 	 bmp->id |= BMP_ID_LOCKED;
-	 surf->flags &= ~DDRAW_SURFACE_LOST;
+	 bmp_extra->flags &= ~BMP_FLAG_LOST;
 
-	 ddsurf_desc.dwSize = sizeof(DDSURFACEDESC);
-	 ddsurf_desc.dwFlags = 0;
+	 /* try to lock surface */
+	 surf = bmp_extra->surf;
 
-	 hr = IDirectDrawSurface2_Lock(surf->id, NULL, &ddsurf_desc,
-                                    DDLOCK_WAIT | DDLOCK_SURFACEMEMORYPTR, NULL);
+	 surf_desc.dwSize = sizeof(surf_desc);
+	 surf_desc.dwFlags = 0;
 
-	 /* If the surface has been lost, try to restore all surfaces
-	  * and, on success, try again to lock the surface.
-	  */
-	 if (hr == DDERR_SURFACELOST) {
-	    if (restore_all_ddraw_surfaces() == 0) {
-	       ddsurf_desc.dwSize = sizeof(DDSURFACEDESC);
-	       ddsurf_desc.dwFlags = 0;
-
-	       hr = IDirectDrawSurface2_Lock(surf->id, NULL, &ddsurf_desc,
-                                          DDLOCK_WAIT | DDLOCK_SURFACEMEMORYPTR, NULL);
-	    }
-	 }
+	 hr = IDirectDrawSurface2_Lock(surf, NULL, &surf_desc,
+                                       DDLOCK_WAIT | DDLOCK_SURFACEMEMORYPTR, NULL); 
 
 	 if (FAILED(hr)) {
-	    _TRACE("Can't lock surface (%x)\n", hr);
-
 	    /* lock failed, use pseudo surface memory */
-	    surf->flags |= DDRAW_SURFACE_LOST;
+	    bmp_extra->flags |= BMP_FLAG_LOST;
 	    data = pseudo_surf_mem;
 	    pitch = 0;
 	 } 
 	 else {
-	    data = ddsurf_desc.lpSurface;
-	    pitch = ddsurf_desc.lPitch;
+	    data = surf_desc.lpSurface;
+	    pitch = surf_desc.lPitch;
 	 }
 
 	 /* prepare line array */
@@ -140,7 +147,7 @@ void gfx_directx_lock(BITMAP *bmp)
  */
 void gfx_directx_autolock(BITMAP *bmp)
 {
-   DDRAW_SURFACE *surf;
+   BMP_EXTRA_INFO *bmp_extra;
    BITMAP *parent;
    int pitch;
    unsigned char *data;
@@ -171,13 +178,13 @@ void gfx_directx_autolock(BITMAP *bmp)
    }
    else {
       /* this is a real bitmap, so can be locked directly */
-      surf = DDRAW_SURFACE_OF(bmp);
+      bmp_extra = BMP_EXTRA(bmp);
 
-      if (surf->lock_nesting) {
+      if (bmp_extra->lock_nesting) {
 	 /* re-locking after a hwaccel, so don't change nesting state */
 	 gfx_directx_lock(bmp);
-	 surf->lock_nesting--;
-	 _exit_gfx_critical();
+	 bmp_extra->lock_nesting--;
+         _exit_gfx_critical();
       }
       else {
 	 /* locking for the first time */
@@ -194,9 +201,8 @@ void gfx_directx_autolock(BITMAP *bmp)
  */
 void gfx_directx_unlock(BITMAP *bmp)
 {
-   DDRAW_SURFACE *surf;
+   BMP_EXTRA_INFO *bmp_extra;
    BITMAP *parent;
-   HRESULT hr;
 
    if (bmp->id & BMP_ID_SUB) {
       /* recurse when unlocking sub-bitmaps */
@@ -207,26 +213,15 @@ void gfx_directx_unlock(BITMAP *bmp)
    }
    else {
       /* regular bitmaps can be unlocked directly */
-      surf = DDRAW_SURFACE_OF(bmp);
+      bmp_extra = BMP_EXTRA(bmp);
 
-      if (surf->lock_nesting > 0) {
-	 surf->lock_nesting--;
+      if (bmp_extra->lock_nesting > 0) {
+	 bmp_extra->lock_nesting--;
 
-         if ((!surf->lock_nesting) && (bmp->id & BMP_ID_LOCKED)) {
-            if (!(surf->flags & DDRAW_SURFACE_LOST)) {
+         if ((!bmp_extra->lock_nesting) && (bmp->id & BMP_ID_LOCKED)) {
+            if (!(bmp_extra->flags & BMP_FLAG_LOST)) {
 	       /* only unlock if it doesn't use pseudo video memory */
-	       hr = IDirectDrawSurface2_Unlock(surf->id, NULL);
-
-	       /* If the surface has been lost, try to restore all surfaces
-	        * and, on success, try again to unlock the surface.
-	        */
-	       if (hr == DDERR_SURFACELOST) {
-	          if (restore_all_ddraw_surfaces() == 0)
-	             hr = IDirectDrawSurface2_Unlock(surf->id, NULL);
-	       }
-
-	       if (FAILED(hr))
-	          _TRACE("Can't unlock surface (%x)\n", hr);
+	       IDirectDrawSurface2_Unlock(bmp_extra->surf, NULL);
             }
 
             bmp->id &= ~BMP_ID_LOCKED;
@@ -245,8 +240,7 @@ void gfx_directx_unlock(BITMAP *bmp)
  */
 void gfx_directx_release_lock(BITMAP *bmp)
 {
-   DDRAW_SURFACE *surf;
-   HRESULT hr;
+   BMP_EXTRA_INFO *bmp_extra;
 
    /* handle display switch */
    if (!app_foreground)
@@ -259,22 +253,11 @@ void gfx_directx_release_lock(BITMAP *bmp)
    }
 
    if (bmp->id & BMP_ID_LOCKED) {
-      surf = DDRAW_SURFACE_OF(bmp);
+      bmp_extra = (BMP_EXTRA_INFO *)bmp->extra;
 
-      if (!(surf->flags & DDRAW_SURFACE_LOST)) {
+      if (!(bmp_extra->flags & BMP_FLAG_LOST)) {
 	 /* only unlock if it doesn't use pseudo video memory */
-	 hr = IDirectDrawSurface2_Unlock(surf->id, NULL);
-
-	 /* If the surface has been lost, try to restore all surfaces
-	  * and, on success, try again to unlock the surface.
-	  */
-	 if (hr == DDERR_SURFACELOST) {
-	    if (restore_all_ddraw_surfaces() == 0)
-	       hr = IDirectDrawSurface2_Unlock(surf->id, NULL);
-	 }
-
-	 if (FAILED(hr))
-	    _TRACE("Can't release lock (%x)\n", hr);
+	 IDirectDrawSurface2_Unlock(bmp_extra->surf, NULL);
       }
 
       bmp->id &= ~BMP_ID_LOCKED;
