@@ -47,7 +47,8 @@ _DRIVER_INFO _timer_driver_list[] =
 static int tim_win32_high_perf_init(void);
 static int tim_win32_low_perf_init(void);
 static void tim_win32_exit(void);
-static void tim_win32_rest(unsigned int time, AL_METHOD(void, callback, (void)));
+static int can_simulate_retrace(void);
+static void win32_rest(long time, AL_METHOD(void, callback, (void)));
 
 
 TIMER_DRIVER timer_win32_high_perf =
@@ -58,8 +59,10 @@ TIMER_DRIVER timer_win32_high_perf =
    "Win32 high performance timer",
    tim_win32_high_perf_init,
    tim_win32_exit,
-   NULL, NULL, NULL, NULL, NULL, NULL,
-   tim_win32_rest
+   NULL, NULL, NULL, NULL,
+   can_simulate_retrace,
+   NULL,
+   win32_rest
 };
 
 
@@ -71,13 +74,19 @@ TIMER_DRIVER timer_win32_low_perf =
    "Win32 low performance timer",
    tim_win32_low_perf_init,
    tim_win32_exit,
-   NULL, NULL, NULL, NULL, NULL, NULL,
-   tim_win32_rest
+   NULL, NULL, NULL, NULL,
+   can_simulate_retrace,
+   NULL,
+   win32_rest
 };
 
 
 static HANDLE timer_thread = NULL;       /* dedicated timer thread      */
 static HANDLE timer_stop_event = NULL;   /* thread termination event    */
+static long timer_delay = 0;             /* how long between interrupts */
+static int timer_semaphore = FALSE;      /* reentrant interrupt ?       */
+static long vsync_counter;               /* retrace position counter    */
+static long vsync_speed;                 /* retrace speed               */
 
 /* high performance driver */
 static LARGE_INTEGER counter_freq;
@@ -92,8 +101,79 @@ static LARGE_INTEGER counter_per_msec;
 
 
 
+/* set_sync_timer_freq:
+ *  sets the speed of the retrace counter.
+ */
+void set_sync_timer_freq(int freq)
+{
+   vsync_speed = BPS_TO_TIMER(freq);
+}
+
+
+
+/* tim_win32_handle_timer_tick:
+ *  called by the driver to handle a tick.
+ */
+static int tim_win32_handle_timer_tick(int interval)
+{
+   long d;
+   int i;
+   long new_delay = 0x8000;
+
+   timer_delay += interval;
+
+   /* reentrant interrupt ? */
+   if (timer_semaphore)
+      return 0x2000;
+
+   timer_semaphore = TRUE;
+   d = timer_delay;
+
+   /* deal with retrace synchronisation */
+   vsync_counter -= d;
+
+   if (vsync_counter <= 0) {
+      vsync_counter += vsync_speed;
+      retrace_count++;
+      if (retrace_proc)
+	 retrace_proc();
+   }
+
+   if (vsync_counter < new_delay)
+      new_delay = vsync_counter;
+
+   /* process the user callbacks */
+   for (i = 0; i < MAX_TIMERS; i++) {
+      if (((_timer_queue[i].proc) || (_timer_queue[i].param_proc)) && (_timer_queue[i].speed > 0)) {
+	 _timer_queue[i].counter -= d;
+
+	 while ((_timer_queue[i].counter <= 0) && ((_timer_queue[i].proc) || (_timer_queue[i].param_proc)) && (_timer_queue[i].speed > 0)) {
+	    _timer_queue[i].counter += _timer_queue[i].speed;
+	    if (_timer_queue[i].param_proc)
+	       _timer_queue[i].param_proc(_timer_queue[i].param);
+	    else
+	       _timer_queue[i].proc();
+	 }
+
+	 if ((_timer_queue[i].counter > 0) && (_timer_queue[i].counter < new_delay))
+	    new_delay = _timer_queue[i].counter;
+      }
+   }
+
+   timer_delay -= d;
+   timer_semaphore = FALSE;
+
+   /* fudge factor to prevent interrupts from coming too close to each other */
+   if (new_delay < MSEC_TO_TIMER(1))
+      new_delay = MSEC_TO_TIMER(1);
+
+   return new_delay;
+}
+
+
+
 /* tim_win32_high_perf_thread:
- *  Thread loop function for the high performance driver.
+ *  thread loop function for the high performance driver.
  */
 static void tim_win32_high_perf_thread(void *unused)
 {
@@ -103,14 +183,11 @@ static void tim_win32_high_perf_thread(void *unused)
    LARGE_INTEGER prev_tick;
    LARGE_INTEGER diff_counter;
 
-   /* init thread */
-   thread_init();
-
    /* get initial counter */
    QueryPerformanceCounter(&prev_tick);
 
    while (TRUE) {
-      if (!app_foreground) {
+      if (WaitForSingleObject(_foreground_event, 0) == WAIT_TIMEOUT) {
 	 /* restart counter if the thread was blocked */
 	 if (thread_switch_out())
 	    QueryPerformanceCounter(&prev_tick);
@@ -126,21 +203,19 @@ static void tim_win32_high_perf_thread(void *unused)
       prev_tick.QuadPart = curr_counter.QuadPart;
 
       /* call timer proc */
-      delay = _handle_timer_tick(COUNTER_TO_TIMER(diff_counter.QuadPart));
+      delay = tim_win32_handle_timer_tick(COUNTER_TO_TIMER(diff_counter.QuadPart));
 
       /* wait calculated time */
       result = WaitForSingleObject(timer_stop_event, TIMER_TO_MSEC(delay));
-      if (result != WAIT_TIMEOUT) {
-	 thread_exit();
+      if (result != WAIT_TIMEOUT)
 	 return;
-      }
    }
 }
 
 
 
 /* tim_win32_low_perf_thread:
- *  Thread loop function for the low performance driver.
+ *  thread loop function for the low performance driver.
  */
 static void tim_win32_low_perf_thread(void *unused)
 {
@@ -150,14 +225,11 @@ static void tim_win32_low_perf_thread(void *unused)
    DWORD curr_time;  /* in milliseconds */
    DWORD diff_time;
 
-   /* init thread */
-   thread_init();
-
    /* get initial time */
    prev_time = timeGetTime();
 
    while (TRUE) {
-      if (!app_foreground) {
+      if (WaitForSingleObject(_foreground_event, 0) == WAIT_TIMEOUT) {
 	 /* restart time if the thread was blocked */
 	 if (thread_switch_out())
 	    prev_time = timeGetTime();
@@ -173,21 +245,19 @@ static void tim_win32_low_perf_thread(void *unused)
       prev_time = curr_time;
 
       /* call timer proc */
-      delay = _handle_timer_tick(MSEC_TO_TIMER(diff_time));
+      delay = tim_win32_handle_timer_tick(MSEC_TO_TIMER(diff_time));
 
       /* wait calculated time */
       result = WaitForSingleObject(timer_stop_event, TIMER_TO_MSEC(delay));
-      if (result != WAIT_TIMEOUT) {
-	 thread_exit();
+      if (result != WAIT_TIMEOUT)
 	 return;
-      }
    }
 }
 
 
 
 /* tim_win32_high_perf_init:
- *  Initializes the high performance driver.
+ *  initializes the high performance driver.
  */
 static int tim_win32_high_perf_init(void)
 {
@@ -214,7 +284,7 @@ static int tim_win32_high_perf_init(void)
 
 
 /* tim_win32_low_perf_init:
- *  Initializes the low performance driver.
+ *  initializes the low performance driver.
  */
 static int tim_win32_low_perf_init(void)
 {
@@ -233,7 +303,6 @@ static int tim_win32_low_perf_init(void)
 
 
 /* tim_win32_exit:
- *  Shuts down either timer driver.
  */
 static void tim_win32_exit(void)
 {
@@ -249,13 +318,21 @@ static void tim_win32_exit(void)
 
 
 
-/* tim_win32_rest:
- *  Rests the specified amount of milliseconds.
+/* can_simulate_retrace:
  */
-static void tim_win32_rest(unsigned int time, AL_METHOD(void, callback, (void)))
+static int can_simulate_retrace(void)
 {
-   unsigned int start;
-   unsigned int ms = time;
+   return 0;
+}
+
+
+
+/* win32_rest:
+ */
+static void win32_rest(long time, AL_METHOD(void, callback, (void)))
+{
+   unsigned long start;
+   unsigned long ms = time;
 
    if (callback) {
       start = timeGetTime();
