@@ -339,9 +339,11 @@ int piano_proc(int msg, DIALOG *d, int c)
       case MSG_CLICK:
 	 d->d1 = (mouse_x - d->x) / 12;
 
-	 set_clip_rect(screen, d->x+d->d1*12-6, d->y, d->x+d->d1*12+18, d->y+d->h);
+	 show_mouse(NULL);
+	 set_clip(screen, d->x+d->d1*12-6, d->y, d->x+d->d1*12+18, d->y+d->h);
 	 object_message(d, MSG_DRAW, 0);
-	 set_clip_rect(screen, 0, 0, SCREEN_W-1, SCREEN_H-1);
+	 set_clip(screen, 0, 0, SCREEN_W-1, SCREEN_H-1);
+	 show_mouse(screen);
 
 	 pitch = 36 + d->d1;
 	 delay = 0;
@@ -374,10 +376,12 @@ int piano_proc(int msg, DIALOG *d, int c)
 	 } while ((mouse_b) && (d->d1 == (mouse_x - d->x) / 12));
 
 	 if (d->d1 >= 0) {
-	    set_clip_rect(screen, d->x+d->d1*12-6, d->y, d->x+d->d1*12+18, d->y+d->h);
+	    show_mouse(NULL);
+	    set_clip(screen, d->x+d->d1*12-6, d->y, d->x+d->d1*12+18, d->y+d->h);
 	    d->d1 = -1;
 	    object_message(d, MSG_DRAW, 0);
-	    set_clip_rect(screen, 0, 0, SCREEN_W-1, SCREEN_H-1);
+	    set_clip(screen, 0, 0, SCREEN_W-1, SCREEN_H-1);
+	    show_mouse(screen);
 	 }
 	 break;
 
@@ -426,8 +430,7 @@ DIALOG thedialog[] =
 
 int main(void)
 {
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
    install_keyboard();
    install_mouse();
    install_timer();
@@ -448,7 +451,7 @@ int main(void)
 
    #ifdef MIDI_DIGMID
       if (midi_driver->id == MIDI_DIGMID)
-	 textout_centre_ex(screen, font, "Loading patch set...", SCREEN_W/2, SCREEN_H/2, 255, 0);
+	 textout_centre(screen, font, "Loading patch set...", SCREEN_W/2, SCREEN_H/2, 255);
    #endif
 
    load_midi_patches();
