@@ -64,8 +64,7 @@ int main(int argc, char *argv[])
    int h = 200;
    int c, ret;
 
-   if (allegro_init() != 0)
-      return 1;
+   allegro_init();
 
    if (argc < 2) {
       usage();
