@@ -18,7 +18,7 @@
  */
 
 
-#define ALLEGRO_USE_CONSOLE
+#define USE_CONSOLE
 
 #include <stdio.h>
 #include <string.h>
@@ -235,8 +235,6 @@ static void usage(void)
 /* unused callback for datedit.c */
 int datedit_ask(AL_CONST char *fmt, ...) { return 0; }
 
-/* unused callback for datedit.c */
-int datedit_select(AL_CONST char *(*list_getter)(int index, int *list_size), AL_CONST char *fmt, ...) { return 0; }
 
 
 /* callback for outputting messages */
@@ -412,7 +410,7 @@ static void scan_patches(MIDI *midi, char *patches, char *drums)
 
 
 /* reads a MIDI file to see what patches it requires */
-static int read_midi(AL_CONST char *filename, int attrib, void *param)
+static void read_midi(AL_CONST char *filename, int attrib, int param)
 {
    char patches[128], drums[128];
    char fname[256];
@@ -427,8 +425,8 @@ static int read_midi(AL_CONST char *filename, int attrib, void *param)
    midi = load_midi(fname);
    if (!midi) {
       fprintf(stderr, "Error reading %s\n", fname);
-      err = 1;
-      return -1;
+      errno = err = 1;
+      return;
    }
 
    scan_patches(midi, patches, drums);
@@ -456,7 +454,6 @@ static int read_midi(AL_CONST char *filename, int attrib, void *param)
    }
 
    destroy_midi(midi);
-   return 0;
 }
 
 
@@ -473,7 +470,7 @@ static void mem_write8(int val)
 {
    if (mem_size >= mem_alloced) {
       mem_alloced += 4096;
-      mem = _AL_REALLOC(mem, mem_alloced);
+      mem = _al_realloc(mem, mem_alloced);
    }
 
    mem[mem_size] = val;
@@ -518,7 +515,7 @@ static void mem_write_block(void *data, int size)
 {
    if (mem_size+size > mem_alloced) {
       mem_alloced = (mem_alloced + size + 4095) & ~4095;
-      mem = _AL_REALLOC(mem, mem_alloced);
+      mem = _al_realloc(mem, mem_alloced);
    }
 
    memcpy(mem+mem_size, data, size);
@@ -532,7 +529,7 @@ static void mem_write_file(PACKFILE *f, int size)
 {
    if (mem_size+size > mem_alloced) {
       mem_alloced = (mem_alloced + size + 4095) & ~4095;
-      mem = _AL_REALLOC(mem, mem_alloced);
+      mem = _al_realloc(mem, mem_alloced);
    }
 
    pack_fread(mem+mem_size, size, f);
@@ -542,10 +539,10 @@ static void mem_write_file(PACKFILE *f, int size)
 
 
 /* imports data from a GUS patch file */
-static DATAFILE *grab_patch(int type, AL_CONST char *filename, DATAFILE_PROPERTY **prop, int depth)
+static void *grab_patch(AL_CONST char *filename, long *size, int x, int y, int w, int h, int depth)
 {
    PACKFILE *f;
-   int64_t sz = file_size_ex(filename);
+   long sz = file_size(filename);
    char buf[256];
    int inst, layer, sample, i;
    int data_size, data_size_pos;
@@ -565,13 +562,13 @@ static DATAFILE *grab_patch(int type, AL_CONST char *filename, DATAFILE_PROPERTY
 
    if (!opt_8bit) {
       /* raw copy of the disk file */
-      mem = _AL_MALLOC(sz);
+      mem = _al_malloc(sz);
 
       pack_fread(mem, sz, f);
       pack_fclose(f);
 
       if (errno) {
-	 _AL_FREE(mem);
+	 _al_free(mem);
 	 return NULL;
       }
 
@@ -588,7 +585,8 @@ static DATAFILE *grab_patch(int type, AL_CONST char *filename, DATAFILE_PROPERTY
 	 }
       }
 
-      return datedit_construct(type, mem, sz, prop);
+      *size = sz;
+      return mem;
    }
 
    /* have to parse the file to adjust the sample format */
@@ -734,11 +732,12 @@ static DATAFILE *grab_patch(int type, AL_CONST char *filename, DATAFILE_PROPERTY
    pack_fclose(f);
 
    if (errno) {
-      _AL_FREE(mem);
+      _al_free(mem);
       return NULL;
    }
 
-   return datedit_construct(type, mem, mem_size, prop);
+   *size = mem_size;
+   return mem;
 }
 
 
@@ -776,7 +775,6 @@ static int parse_string(char *buf, char *argv[])
 static void add_gus_patches(void)
 {
    char dir[256], file[256], buf[256], filename[256];
-   DATEDIT_GRAB_PARAMETERS params;
    PACKFILE *f;
    DATAFILE *d;
    char *argv[16];
@@ -816,19 +814,8 @@ static void add_gus_patches(void)
       if (buf[i] == '\\')
 	 buf[i] = '/';
 
-   params.datafile = NULL;  /* only with absolute filenames */
-   params.filename = buf;
-   params.name = "default_cfg";
-   params.type = DAT_DATA;
-   /* params.x = */
-   /* params.y = */
-   /* params.w = */
-   /* params.h = */
-   /* params.colordepth = */
-   params.relative = FALSE;  /* required (see above) */
-
    printf("Grabbing %s\n", buf);
-   d = datedit_grabnew(datafile, &params);
+   d = datedit_grabnew(datafile, buf, "default_cfg", "DATA", -1, -1, -1, -1, -1);
    if (!d) {
       errno = err = 1;
       return;
@@ -900,11 +887,8 @@ static void add_gus_patches(void)
 			break;
 
 		  if (datafile[j].type == DAT_END) {
-		     params.filename = filename;
-		     params.name = argv[1];
-		     params.type = DAT_PATCH;
 		     printf("Grabbing %s\n", filename);
-		     d = datedit_grabnew(datafile, &params);
+		     d = datedit_grabnew(datafile, filename, argv[1], "PAT", -1, -1, -1, -1, -1);
 		  }
 		  else
 		     d = datafile;
@@ -1888,7 +1872,6 @@ static void print_sf_string(FILE *f, char *title)
 static void add_soundfont_patches(void)
 {
    RIFF_CHUNK file, chunk, subchunk;
-   DATEDIT_GRAB_PARAMETERS params;
    DATAFILE *d;
    FILE *f;
    time_t now;
@@ -1896,7 +1879,7 @@ static void add_soundfont_patches(void)
    char tm[80];
    int i;
 
-   #ifdef ALLEGRO_HAVE_MKSTEMP
+   #ifdef HAVE_MKSTEMP
 
       int tmp_fd;
 
@@ -1942,18 +1925,7 @@ static void add_soundfont_patches(void)
 
    fclose(f);
 
-   params.datafile = NULL;  /* only with absolute filenames */
-   params.filename = buf;
-   params.name = "default_cfg";
-   params.type = DAT_DATA;
-   /* params.x = */
-   /* params.y = */
-   /* params.w = */
-   /* params.h = */
-   /* params.colordepth = */
-   params.relative = FALSE;  /* required (see above) */
-
-   d = datedit_grabnew(datafile, &params);
+   d = datedit_grabnew(datafile, buf, "default_cfg", "DATA", -1, -1, -1, -1, -1);
 
    delete_file(buf);
 
@@ -2309,8 +2281,7 @@ int main(int argc, char *argv[])
 {
    int c;
 
-   if (install_allegro(SYSTEM_NONE, &errno, atexit) != 0)
-       return 1;
+   install_allegro(SYSTEM_NONE, &errno, atexit);
    datedit_init();
 
    for (c=0; c<128; c++)
@@ -2429,9 +2400,12 @@ int main(int argc, char *argv[])
       need_patches[0] = TRUE;    /* always load the piano */
 
       for (c=0; c<opt_numnames; c++) {
-	 if (for_each_file_ex(opt_namelist[c], 0, ~(FA_ARCH | FA_RDONLY), read_midi, NULL) <= 0) {
+	 if (for_each_file(opt_namelist[c], FA_ARCH | FA_RDONLY, read_midi, 0) <= 0) {
 	    fprintf(stderr, "Error: %s not found\n", opt_namelist[c]);
 	    err = 1;
+	 }
+	 if (errno) {
+	    err = 1;
 	    break;
 	 }
       }
@@ -2455,7 +2429,7 @@ int main(int argc, char *argv[])
 	 printf("\n");
       }
 
-      datafile = _AL_MALLOC(sizeof(DATAFILE));
+      datafile = _al_malloc(sizeof(DATAFILE));
       datafile->dat = NULL;
       datafile->type = DAT_END;
       datafile->size = 0;
@@ -2467,16 +2441,7 @@ int main(int argc, char *argv[])
 	 add_gus_patches();
 
       if (!err) {
-	 DATEDIT_SAVE_DATAFILE_OPTIONS options;
-
-	 options.pack = opt_compression;
-	 options.strip = 1;
-	 options.sort = 1;
-	 options.verbose = (opt_veryverbose || (opt_verbose && opt_compression));
-	 options.write_msg = TRUE;
-	 options.backup = FALSE;
-
-	 if (!datedit_save_datafile(datafile, opt_datafile, NULL, &options, NULL))
+	 if (!datedit_save_datafile(datafile, opt_datafile, 1, opt_compression, (opt_veryverbose || (opt_verbose && opt_compression)), TRUE, FALSE, NULL))
 	    err = 1;
       }
 
@@ -2515,4 +2480,4 @@ int main(int argc, char *argv[])
    return err;
 }
 
-END_OF_MAIN()
+END_OF_MAIN();
