@@ -399,7 +399,9 @@ static int gg_text_proc(int msg, DIALOG *d, int c)
 	 else
 	    d->flags |= D_DISABLED;
 
+	 show_mouse(NULL);
 	 object_message(d, MSG_DRAW, 0);
+	 show_mouse(screen);
       }
 
       return D_O_K;
@@ -423,7 +425,9 @@ static int gg_edit_proc(int msg, DIALOG *d, int c)
 	 else
 	    d->flags |= D_DISABLED;
 
+	 show_mouse(NULL);
 	 object_message(d, MSG_DRAW, 0);
+	 show_mouse(screen);
       }
 
       return D_O_K;
@@ -605,7 +609,7 @@ static int griddler(void)
 
    if (selitem) {
       grabber_sel_palette(grabber_palette);
-      grabber_modified(TRUE);
+      grabber_modified(1);
    }
    else
       alert("No grid found - nothing grabbed!", NULL, NULL, "Hmm...", NULL, 13, 0);
@@ -670,7 +674,7 @@ static int do_autocropper(DATAFILE *dat, int *param, int param2)
       datedit_set_property(dat, DAT_YCRP, buf);
    }
    
-   grabber_modified(TRUE);
+   grabber_modified(1);
 
    return D_REDRAW;
 }
